@@ -66,7 +66,7 @@ public interface Broker<X extends Broker<X>> extends ConfiguredObject<X>, EventL
     String BROKER_STATISTICS_REPORING_PERIOD = "broker.statisticsReportingPeriod";
 
     String NETWORK_BUFFER_SIZE = "qpid.broker.networkBufferSize";
-    // network buffer should at least hold a SSL/TLS frame which in jdk1.8 is 33305 bytes
+    // network buffer should at least hold a SSL/TLS frame which in jdk 17 is 33305 bytes
     int MINIMUM_NETWORK_BUFFER_SIZE = 64 * 1024;
     @ManagedContextDefault(name = NETWORK_BUFFER_SIZE)
     int DEFAULT_NETWORK_BUFFER_SIZE = 256 * 1024;
@@ -93,7 +93,7 @@ public interface Broker<X extends Broker<X>> extends ConfiguredObject<X>, EventL
     long DEFAULT_COMPACT_MEMORY_INTERVAL = 1000L;
 
     @ManagedContextDefault(name = CHANNEL_FLOW_CONTROL_ENFORCEMENT_TIMEOUT)
-    long DEFAULT_CHANNEL_FLOW_CONTROL_ENFORCEMENT_TIMEOUT = 5000l;
+    long DEFAULT_CHANNEL_FLOW_CONTROL_ENFORCEMENT_TIMEOUT = 5000L;
 
     @ManagedContextDefault(name = STORE_FILESYSTEM_MAX_USAGE_PERCENT)
     int DEFAULT_FILESYSTEM_MAX_USAGE_PERCENT = 90;
@@ -107,19 +107,19 @@ public interface Broker<X extends Broker<X>> extends ConfiguredObject<X>, EventL
     @ManagedContextDefault(name = BROKER_MSG_AUTH)
     boolean DEFAULT_BROKER_MSG_AUTH = false;
 
-    @ManagedContextDefault(name = CommonProperties.QPID_SECURITY_TLS_PROTOCOL_WHITE_LIST)
-    String DEFAULT_SECURITY_TLS_PROTOCOL_WHITE_LIST =
-            "[\"" + CommonProperties.QPID_SECURITY_TLS_PROTOCOL_WHITE_LIST_DEFAULT.replace("\\", "\\\\") + "\"]";
+    @ManagedContextDefault(name = CommonProperties.QPID_SECURITY_TLS_PROTOCOL_ALLOW_LIST)
+    String DEFAULT_SECURITY_TLS_PROTOCOL_ALLOW_LIST =
+            "[\"" + CommonProperties.QPID_SECURITY_TLS_PROTOCOL_ALLOW_LIST_DEFAULT.replace("\\", "\\\\") + "\"]";
 
-    @ManagedContextDefault(name = CommonProperties.QPID_SECURITY_TLS_PROTOCOL_BLACK_LIST)
-    String DEFAULT_SECURITY_TLS_PROTOCOL_BLACK_LIST =
-            "[\"" + CommonProperties.QPID_SECURITY_TLS_PROTOCOL_BLACK_LIST_DEFAULT.replace("\\", "\\\\") + "\"]";
+    @ManagedContextDefault(name = CommonProperties.QPID_SECURITY_TLS_PROTOCOL_DENY_LIST)
+    String DEFAULT_SECURITY_TLS_PROTOCOL_DENY_LIST =
+            "[\"" + CommonProperties.QPID_SECURITY_TLS_PROTOCOL_DENY_LIST_DEFAULT.replace("\\", "\\\\") + "\"]";
 
-    @ManagedContextDefault(name = CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_WHITE_LIST)
-    String DEFAULT_SECURITY_TLS_CIPHER_SUITE_WHITE_LIST = "[]";
+    @ManagedContextDefault(name = CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_ALLOW_LIST)
+    String DEFAULT_SECURITY_TLS_CIPHER_SUITE_ALLOW_LIST = "[]";
 
-    @ManagedContextDefault(name = CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_BLACK_LIST)
-    String DEFAULT_SECURITY_TLS_CIPHER_SUITE_BLACK_LIST = "[]";
+    @ManagedContextDefault(name = CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_DENY_LIST)
+    String DEFAULT_SECURITY_TLS_CIPHER_SUITE_DENY_LIST = "[]";
 
     @ManagedContextDefault(name = QPID_DOCUMENTATION_URL)
     String DEFAULT_DOCUMENTATION_URL = "http://qpid.apache.org/releases/qpid-broker-j-${qpid.version}/book/";
@@ -201,7 +201,8 @@ public interface Broker<X extends Broker<X>> extends ConfiguredObject<X>, EventL
             units = StatisticUnit.BYTES,
             label = "Inbound",
             description = "Total size of all messages received by the Broker.",
-            metricName = "inbound_bytes_count")
+            metricName = "inbound_bytes_count",
+            resettable = true)
     long getBytesIn();
 
     @SuppressWarnings("unused")
@@ -209,7 +210,8 @@ public interface Broker<X extends Broker<X>> extends ConfiguredObject<X>, EventL
             units = StatisticUnit.BYTES,
             label = "Outbound",
             description = "Total size of all messages delivered by the Broker.",
-            metricName = "outbound_bytes_count")
+            metricName = "outbound_bytes_count",
+            resettable = true)
     long getBytesOut();
 
     @SuppressWarnings("unused")
@@ -217,7 +219,8 @@ public interface Broker<X extends Broker<X>> extends ConfiguredObject<X>, EventL
             units = StatisticUnit.MESSAGES,
             label = "Inbound",
             description = "Total number of messages received by the Broker.",
-            metricName = "inbound_messages_count")
+            metricName = "inbound_messages_count",
+            resettable = true)
     long getMessagesIn();
 
     @SuppressWarnings("unused")
@@ -225,7 +228,8 @@ public interface Broker<X extends Broker<X>> extends ConfiguredObject<X>, EventL
             units = StatisticUnit.MESSAGES,
             label = "Outbound",
             description = "Total number of messages delivered by the Broker.",
-            metricName = "outbound_messages_count")
+            metricName = "outbound_messages_count",
+            resettable = true)
     long getMessagesOut();
 
 
@@ -234,7 +238,8 @@ public interface Broker<X extends Broker<X>> extends ConfiguredObject<X>, EventL
             units = StatisticUnit.MESSAGES,
             label = "Transacted Inbound",
             description = "Total number of messages delivered by the Broker within a transaction.",
-            metricName = "inbound_transacted_messages_count")
+            metricName = "inbound_transacted_messages_count",
+            resettable = true)
     long getTransactedMessagesIn();
 
     @SuppressWarnings("unused")
@@ -242,9 +247,13 @@ public interface Broker<X extends Broker<X>> extends ConfiguredObject<X>, EventL
             units = StatisticUnit.MESSAGES,
             label = "Transacted Outbound",
             description = "Total number of messages received by the Broker within a transaction.",
-            metricName = "outbound_transacted_messages_count")
+            metricName = "outbound_transacted_messages_count",
+            resettable = true)
     long getTransactedMessagesOut();
 
+    @ManagedOperation(description = "Resets broker statistics", changesConfiguredObjectState = true)
+    void resetStatistics();
+
     @ManagedOperation(nonModifying = true,
             description = "Initiates an orderly shutdown of the Broker.",
             changesConfiguredObjectState = false)
@@ -332,7 +341,8 @@ public interface Broker<X extends Broker<X>> extends ConfiguredObject<X>, EventL
             units = StatisticUnit.BYTES,
             label = "Maximum recorded size of inbound messages",
             description = "Maximum size of messages published into the Broker since start-up.",
-            metricName = "inbound_message_size_high_watermark")
+            metricName = "inbound_message_size_high_watermark",
+            resettable = true)
     long getInboundMessageSizeHighWatermark();
 
     @ManagedOperation(nonModifying = true,
