@@ -35,7 +35,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.UUID;
-import java.util.concurrent.Callable;
+import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.ExecutionException;
@@ -50,11 +50,6 @@ import java.util.regex.Pattern;
 import javax.security.auth.Subject;
 import javax.security.auth.login.AccountNotFoundException;
 
-import com.google.common.util.concurrent.FutureCallback;
-import com.google.common.util.concurrent.Futures;
-import com.google.common.util.concurrent.ListenableFuture;
-import com.google.common.util.concurrent.MoreExecutors;
-import com.google.common.util.concurrent.SettableFuture;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -66,7 +61,6 @@ import org.apache.qpid.server.configuration.updater.TaskExecutor;
 import org.apache.qpid.server.configuration.updater.TaskExecutorImpl;
 import org.apache.qpid.server.logging.messages.BrokerMessages;
 import org.apache.qpid.server.model.port.AmqpPort;
-import org.apache.qpid.server.model.preferences.Preference;
 import org.apache.qpid.server.model.preferences.UserPreferences;
 import org.apache.qpid.server.model.preferences.UserPreferencesImpl;
 import org.apache.qpid.server.plugin.QpidServiceLoader;
@@ -154,7 +148,7 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
 
         if (parent.isManagementMode())
         {
-            Map<String,Object> authManagerAttrs = new HashMap<String, Object>();
+            Map<String,Object> authManagerAttrs = new HashMap<>();
             authManagerAttrs.put(NAME,"MANAGEMENT_MODE_AUTHENTICATION");
             authManagerAttrs.put(ID, UUID.randomUUID());
             SimpleAuthenticationManager authManager = new SimpleAuthenticationManager(authManagerAttrs, this);
@@ -164,7 +158,7 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
         }
         else
         {
-            _accessControl =  new CompoundAccessControl(Collections.<AccessControl<?>>emptyList(), Result.ALLOWED);
+            _accessControl =  new CompoundAccessControl(List.of(), Result.ALLOWED);
         }
 
         QpidServiceLoader qpidServiceLoader = new QpidServiceLoader();
@@ -321,34 +315,26 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
     }
 
     @StateTransition( currentState = State.UNINITIALIZED, desiredState = State.ACTIVE )
-    private ListenableFuture<Void> activate()
+    private CompletableFuture<Void> activate()
     {
         if(_parent.isManagementMode())
         {
-            return doAfter(_managementModeAuthenticationProvider.openAsync(),
-                    new Runnable()
-                    {
-                        @Override
-                        public void run()
-                        {
-                            performActivation();
-                        }
-                    });
+            return _managementModeAuthenticationProvider.openAsync().thenRunAsync(this::performActivation, getTaskExecutor());
         }
         else
         {
             performActivation();
-            return Futures.immediateFuture(null);
+            return CompletableFuture.completedFuture(null);
         }
     }
 
     @SuppressWarnings("unused")
     @StateTransition( currentState = {State.ACTIVE, State.ERRORED}, desiredState = State.STOPPED )
-    private ListenableFuture<Void> doStop()
+    private CompletableFuture<Void> doStop()
     {
         stopPreferenceTaskExecutor();
         closePreferenceStore();
-        return Futures.immediateFuture(null);
+        return CompletableFuture.completedFuture(null);
     }
 
     private void closePreferenceStore()
@@ -471,21 +457,8 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
 
             _lastDisposalCounter = QpidByteBuffer.getPooledBufferDisposalCounter();
 
-            ListenableFuture<Void> result = compactMemoryInternal();
-            addFutureCallback(result, new FutureCallback<Void>()
-            {
-                @Override
-                public void onSuccess(final Void result)
-                {
-                    scheduleDirectMemoryCheck();
-                }
-
-                @Override
-                public void onFailure(final Throwable t)
-                {
-                    scheduleDirectMemoryCheck();
-                }
-            }, MoreExecutors.directExecutor());
+            CompletableFuture<Void> result = compactMemoryInternal()
+                    .whenComplete((result1, error) -> scheduleDirectMemoryCheck());
         }
         else
         {
@@ -666,42 +639,31 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
         return children;
     }
 
-    private ListenableFuture<VirtualHostNode> createVirtualHostNodeAsync(Map<String, Object> attributes)
+    private CompletableFuture<VirtualHostNode> createVirtualHostNodeAsync(Map<String, Object> attributes)
             throws AccessControlException, IllegalArgumentException
     {
 
-        return doAfter(getObjectFactory().createAsync(VirtualHostNode.class, attributes, this),
-                       new CallableWithArgument<ListenableFuture<VirtualHostNode>, VirtualHostNode>()
-                       {
-                           @Override
-                           public ListenableFuture<VirtualHostNode> call(final VirtualHostNode virtualHostNode)
-                                   throws Exception
-                           {
-                               // permission has already been granted to create the virtual host
-                               // disable further access check on other operations, e.g. create exchange
-                               Subject.doAs(getSubjectWithAddedSystemRights(),
-                                            new PrivilegedAction<Object>()
-                                            {
-                                                @Override
-                                                public Object run()
-                                                {
-                                                    virtualHostNode.start();
-                                                    return null;
-                                                }
-                                            });
-                               return Futures.immediateFuture(virtualHostNode);
-                           }
-                       });
+        return getObjectFactory().createAsync(VirtualHostNode.class, attributes, this).thenApplyAsync((virtualHostNode) ->
+        {
+            // permission has already been granted to create the virtual host
+            // disable further access check on other operations, e.g. create exchange
+            Subject.doAs(getSubjectWithAddedSystemRights(), (PrivilegedAction<Object>) () ->
+            {
+                ((VirtualHostNode) virtualHostNode).start();
+                return null;
+            });
+            return virtualHostNode;
+        }, getTaskExecutor());
     }
 
     @SuppressWarnings("unchecked")
     @Override
-    protected <C extends ConfiguredObject> ListenableFuture<C> addChildAsync(final Class<C> childClass,
+    protected <C extends ConfiguredObject> CompletableFuture<C> addChildAsync(final Class<C> childClass,
                                                                           final Map<String, Object> attributes)
     {
         if (childClass == VirtualHostNode.class)
         {
-            return (ListenableFuture<C>) createVirtualHostNodeAsync(attributes);
+            return (CompletableFuture<C>) createVirtualHostNodeAsync(attributes);
         }
         else
         {
@@ -710,7 +672,7 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
     }
 
     @Override
-    protected ListenableFuture<Void> beforeClose()
+    protected CompletableFuture<Void> beforeClose()
     {
         try
         {
@@ -726,7 +688,7 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
     }
 
     @Override
-    protected ListenableFuture<Void> onClose()
+    protected CompletableFuture<Void> onClose()
     {
         if (_assignTargetSizeSchedulingFuture != null)
         {
@@ -755,14 +717,14 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
                 task.run();
             }
         }
-        return Futures.immediateFuture(null);
+        return CompletableFuture.completedFuture(null);
 
     }
 
     @Override
     public UserPreferences createUserPreferences(final ConfiguredObject<?> object)
     {
-        return new UserPreferencesImpl(_preferenceTaskExecutor, object, _preferenceStore, Collections.<Preference>emptySet());
+        return new UserPreferencesImpl(_preferenceTaskExecutor, object, _preferenceStore, Set.of());
     }
 
     private void updateAccessControl()
@@ -1010,26 +972,13 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
     @Override
     public void restart()
     {
-        Subject.doAs(getSystemTaskSubject("Broker"), new PrivilegedAction<Void>()
+        Subject.doAs(getSystemTaskSubject("Broker"), (PrivilegedAction<Void>) () ->
         {
-            @Override
-            public Void run()
-            {
-                final SystemConfig<?> systemConfig = (SystemConfig) getParent();
-                // This is deliberately asynchronous as the HTTP thread will be interrupted by restarting
-                doAfter(systemConfig.setAttributesAsync(Collections.<String,Object>singletonMap(ConfiguredObject.DESIRED_STATE,
-                                                                                                State.STOPPED)),
-                        new Callable<ListenableFuture<Void>>()
-                        {
-                            @Override
-                            public ListenableFuture<Void> call() throws Exception
-                            {
-                                return systemConfig.setAttributesAsync(Collections.<String,Object>singletonMap(ConfiguredObject.DESIRED_STATE, State.ACTIVE));
-                            }
-                        });
-
-                return null;
-            }
+            final SystemConfig<?> systemConfig = (SystemConfig) getParent();
+            // This is deliberately asynchronous as the HTTP thread will be interrupted by restarting
+            systemConfig.setAttributesAsync(Map.of(ConfiguredObject.DESIRED_STATE, State.STOPPED))
+                    .thenRunAsync(() -> systemConfig.setAttributesAsync(Map.of(ConfiguredObject.DESIRED_STATE, State.ACTIVE)), getTaskExecutor());
+            return null;
         });
 
     }
@@ -1093,9 +1042,9 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
 
         // remove Preferences from all ConfiguredObjects
         Subject userSubject = new Subject(true,
-                                          Collections.singleton(new AuthenticatedPrincipal(new UsernamePrincipal(username, origin))),
-                                          Collections.EMPTY_SET,
-                                          Collections.EMPTY_SET);
+                                          Set.of(new AuthenticatedPrincipal(new UsernamePrincipal(username, origin))),
+                                          Set.of(),
+                                          Set.of());
         java.util.Queue<ConfiguredObject<?>> configuredObjects = new LinkedList<>();
         configuredObjects.add(BrokerImpl.this);
         while (!configuredObjects.isEmpty())
@@ -1111,14 +1060,10 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
                 }
             }
 
-            Subject.doAs(userSubject, new PrivilegedAction<Void>()
+            Subject.doAs(userSubject, (PrivilegedAction<Void>) () ->
             {
-                @Override
-                public Void run()
-                {
-                    currentObject.getUserPreferences().delete(null, null, null);
-                    return null;
-                }
+                currentObject.getUserPreferences().delete(null, null, null);
+                return null;
             });
         }
     }
@@ -1174,45 +1119,42 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
         compactMemoryInternal();
     }
 
-    private ListenableFuture<Void> compactMemoryInternal()
+    private CompletableFuture<Void> compactMemoryInternal()
     {
         LOGGER.debug("Compacting direct memory buffers: numberOfActivePooledBuffers: {}",
                      QpidByteBuffer.getNumberOfBuffersInUse());
 
         final Collection<VirtualHostNode<?>> vhns = getVirtualHostNodes();
-        List<ListenableFuture<Void>> futures = new ArrayList<>(vhns.size());
+        List<CompletableFuture<Void>> futures = new ArrayList<>(vhns.size());
         for (VirtualHostNode<?> vhn : vhns)
         {
             VirtualHost<?> vh = vhn.getVirtualHost();
             if (vh instanceof QueueManagingVirtualHost)
             {
-                ListenableFuture<Void> future = ((QueueManagingVirtualHost) vh).reallocateMessages();
+                CompletableFuture<Void> future = ((QueueManagingVirtualHost) vh).reallocateMessages();
                 futures.add(future);
             }
         }
 
-        SettableFuture<Void> resultFuture = SettableFuture.create();
-        final ListenableFuture<List<Void>> combinedFuture = Futures.allAsList(futures);
-        addFutureCallback(combinedFuture, new FutureCallback<List<Void>>()
+        CompletableFuture<Void> resultFuture = new CompletableFuture<>();
+        final CompletableFuture<Void> combinedFuture = CompletableFuture.allOf(futures.toArray(CompletableFuture[]::new));
+        combinedFuture.whenCompleteAsync((result, error) ->
         {
-            @Override
-            public void onSuccess(final List<Void> result)
+            if (error != null)
+            {
+                LOGGER.warn("Unexpected error during direct memory compaction.", error);
+                resultFuture.completeExceptionally(error);
+            }
+            else
             {
                 if (LOGGER.isDebugEnabled())
                 {
-                   LOGGER.debug("After compact direct memory buffers: numberOfActivePooledBuffers: {}",
-                                QpidByteBuffer.getNumberOfBuffersInUse());
+                    LOGGER.debug("After compact direct memory buffers: numberOfActivePooledBuffers: {}", QpidByteBuffer.getNumberOfBuffersInUse());
                 }
-                resultFuture.set(null);
-            }
-
-            @Override
-            public void onFailure(final Throwable t)
-            {
-                LOGGER.warn("Unexpected error during direct memory compaction.", t);
-                resultFuture.setException(t);
+                resultFuture.complete(null);
             }
         }, _houseKeepingTaskExecutor);
+
         return resultFuture;
     }
 
@@ -1323,7 +1265,7 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
 
         private void waitForBrokerShutdown()
         {
-            final ListenableFuture<Void> closeResult = _parent.closeAsync();
+            final CompletableFuture<Void> closeResult = _parent.closeAsync();
             try
             {
                 if (_shutdownTimeout < 1)
@@ -1342,7 +1284,7 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
         }
     }
 
-    private final SocketConnectionMetaData getConnectionMetaDataInternal()
+    private SocketConnectionMetaData getConnectionMetaDataInternal()
     {
         final Subject subject = Subject.getSubject(AccessController.getContext());
         final SocketConnectionPrincipal principal;
@@ -1365,14 +1307,14 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
         return principal == null ? null : principal.getConnectionMetaData();
     }
 
-    private final Set<Principal> getGroupsInternal()
+    private Set<Principal> getGroupsInternal()
     {
         final Subject currentSubject = Subject.getSubject(AccessController.getContext());
         if (currentSubject == null)
         {
-            return Collections.emptySet();
+            return Set.of();
         }
-        return Collections.<Principal>unmodifiableSet(currentSubject.getPrincipals(GroupPrincipal.class));
+        return Collections.unmodifiableSet(currentSubject.getPrincipals(GroupPrincipal.class));
     }
 
     private void reportDirectMemoryBelowThresholdIfReached()
