@@ -31,6 +31,7 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicLong;
 
@@ -38,12 +39,12 @@ import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLSessionContext;
 import javax.security.auth.Subject;
 
-import com.fasterxml.jackson.databind.ObjectMapper;
-import com.google.common.util.concurrent.Futures;
-import com.google.common.util.concurrent.ListenableFuture;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import tools.jackson.databind.ObjectMapper;
+import tools.jackson.databind.json.JsonMapper;
+
 import org.apache.qpid.server.configuration.IllegalConfigurationException;
 import org.apache.qpid.server.logging.messages.BrokerMessages;
 import org.apache.qpid.server.logging.messages.PortMessages;
@@ -75,10 +76,8 @@ import org.apache.qpid.server.util.ServerScopedRuntimeException;
 
 public class AmqpPortImpl extends AbstractPort<AmqpPortImpl> implements AmqpPort<AmqpPortImpl>
 {
-
     private static final Logger LOGGER = LoggerFactory.getLogger(AmqpPortImpl.class);
 
-
     @ManagedAttributeField
     private boolean _tcpNoDelay;
 
@@ -109,7 +108,6 @@ public class AmqpPortImpl extends AbstractPort<AmqpPortImpl> implements AmqpPort
     private volatile int _tlsSessionTimeout;
     private volatile int _tlsSessionCacheSize;
     private volatile List<ConnectionPropertyEnricher> _connectionPropertyEnrichers;
-    private volatile boolean _ignoreInvalidSni;
 
 
     @ManagedObjectFactoryConstructor
@@ -150,12 +148,6 @@ public class AmqpPortImpl extends AbstractPort<AmqpPortImpl> implements AmqpPort
         return _maxOpenConnections;
     }
 
-    @Override
-    public boolean isIgnoreInvalidSni()
-    {
-        return _ignoreInvalidSni;
-    }
-
     @Override
     protected void onCreate()
     {
@@ -176,18 +168,13 @@ public class AmqpPortImpl extends AbstractPort<AmqpPortImpl> implements AmqpPort
         hostnameAliasAttributes.put(VirtualHostAlias.TYPE, HostNameAlias.TYPE_NAME);
         hostnameAliasAttributes.put(VirtualHostAlias.DURABLE, true);
 
-        Subject.doAs(getSubjectWithAddedSystemRights(),
-                     new PrivilegedAction<Object>()
-                     {
-                         @Override
-                         public Object run()
-                         {
-                             createChild(VirtualHostAlias.class, nameAliasAttributes);
-                             createChild(VirtualHostAlias.class, defaultAliasAttributes);
-                             createChild(VirtualHostAlias.class, hostnameAliasAttributes);
-                             return null;
-                         }
-                     });
+        Subject.doAs(getSubjectWithAddedSystemRights(), (PrivilegedAction<Object>) () ->
+        {
+            createChild(VirtualHostAlias.class, nameAliasAttributes);
+            createChild(VirtualHostAlias.class, defaultAliasAttributes);
+            createChild(VirtualHostAlias.class, hostnameAliasAttributes);
+            return null;
+        });
     }
 
     @Override
@@ -201,7 +188,6 @@ public class AmqpPortImpl extends AbstractPort<AmqpPortImpl> implements AmqpPort
         _heartBeatDelay = getContextValue(Integer.class, AmqpPort.HEART_BEAT_DELAY);
         _tlsSessionTimeout = getContextValue(Integer.class, AmqpPort.TLS_SESSION_TIMEOUT);
         _tlsSessionCacheSize = getContextValue(Integer.class, AmqpPort.TLS_SESSION_CACHE_SIZE);
-        _ignoreInvalidSni = getContextValue(Boolean.class, AmqpPort.PORT_IGNORE_INVALID_SNI);
 
         @SuppressWarnings("unchecked")
         List<String> configurationPropertyEnrichers = getContextValue(List.class, AmqpPort.CONNECTION_PROPERTY_ENRICHERS);
@@ -296,28 +282,28 @@ public class AmqpPortImpl extends AbstractPort<AmqpPortImpl> implements AmqpPort
     }
 
     @Override
-    protected ListenableFuture<Void> beforeClose()
+    protected CompletableFuture<Void> beforeClose()
     {
         _closingOrDeleting.set(true);
-        return Futures.immediateFuture(null);
+        return CompletableFuture.completedFuture(null);
     }
 
     @Override
-    protected ListenableFuture<Void> onClose()
+    protected CompletableFuture<Void> onClose()
     {
         closeTransport();
-        return Futures.immediateFuture(null);
+        return CompletableFuture.completedFuture(null);
     }
 
     @Override
-    protected ListenableFuture<Void> beforeDelete()
+    protected CompletableFuture<Void> beforeDelete()
     {
         _closingOrDeleting.set(true);
         return super.beforeDelete();
     }
 
     @Override
-    protected ListenableFuture<Void> onDelete()
+    protected CompletableFuture<Void> onDelete()
     {
         closeTransport();
         return super.onDelete();
@@ -490,7 +476,7 @@ public class AmqpPortImpl extends AbstractPort<AmqpPortImpl> implements AmqpPort
             last = current;
         }
         Set<String> combinationsAsString = new HashSet<>(protocolCombinations.size());
-        ObjectMapper mapper = new ObjectMapper();
+        ObjectMapper mapper = JsonMapper.builder().build();
         for(Set<String> combination : protocolCombinations)
         {
             try(StringWriter writer = new StringWriter())
@@ -517,7 +503,7 @@ public class AmqpPortImpl extends AbstractPort<AmqpPortImpl> implements AmqpPort
         }
 
         Set<String> combinationsAsString = new HashSet<>(combinations.size());
-        ObjectMapper mapper = new ObjectMapper();
+        ObjectMapper mapper = JsonMapper.builder().build();
         for(Set<Transport> combination : combinations)
         {
             try(StringWriter writer = new StringWriter())
@@ -537,7 +523,7 @@ public class AmqpPortImpl extends AbstractPort<AmqpPortImpl> implements AmqpPort
     public static String getInstalledProtocolsAsString()
     {
         Set<Protocol> installedProtocols = getInstalledProtocols();
-        ObjectMapper mapper = new ObjectMapper();
+        ObjectMapper mapper = JsonMapper.builder().build();
 
         try(StringWriter output = new StringWriter())
         {
