@@ -22,10 +22,8 @@
 package org.apache.qpid.server.protocol;
 
 import java.util.HashMap;
-import java.util.List;
 import java.util.Map;
 
-import org.apache.qpid.server.bytebuffer.QpidByteBuffer;
 import org.apache.qpid.server.message.ServerMessage;
 import org.apache.qpid.server.plugin.MessageFormat;
 import org.apache.qpid.server.plugin.QpidServiceLoader;
