@@ -33,7 +33,8 @@ import java.security.cert.X509Certificate;
 import java.util.Arrays;
 import java.util.Base64;
 import java.util.Map;
-import java.util.concurrent.Callable;
+import java.util.concurrent.CompletableFuture;
+import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.ThreadFactory;
 
@@ -43,12 +44,6 @@ import javax.net.ssl.SSLSocket;
 import javax.net.ssl.TrustManager;
 import javax.net.ssl.X509TrustManager;
 
-import com.google.common.util.concurrent.FutureCallback;
-import com.google.common.util.concurrent.Futures;
-import com.google.common.util.concurrent.ListenableFuture;
-import com.google.common.util.concurrent.ListeningExecutorService;
-import com.google.common.util.concurrent.MoreExecutors;
-import com.google.common.util.concurrent.SettableFuture;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -168,35 +163,32 @@ public class SiteSpecificTrustStoreImpl
     }
 
     @StateTransition(currentState = {State.UNINITIALIZED, State.ERRORED}, desiredState = State.ACTIVE)
-    protected ListenableFuture<Void> doActivate()
+    protected CompletableFuture<Void> doActivate()
     {
         initializeExpiryChecking();
 
-        final SettableFuture<Void> result = SettableFuture.create();
+        final CompletableFuture<Void> result = new CompletableFuture<>();
         if(_x509Certificate == null)
         {
             final String currentCertificate = getCertificate();
 
-            final ListenableFuture<X509Certificate> certFuture = downloadCertificate(getSiteUrl());
-            addFutureCallback(certFuture, new FutureCallback<X509Certificate>()
+            final CompletableFuture<X509Certificate> certFuture = downloadCertificate(getSiteUrl());
+            certFuture.whenCompleteAsync((certificate, error) ->
             {
-                @Override
-                public void onSuccess(final X509Certificate cert)
-                {
-                    _x509Certificate = cert;
-                    attributeSet(CERTIFICATE, currentCertificate, _x509Certificate);
-                    generateTrustAndSetState(result);
-                }
-
-                @Override
-                public void onFailure(final Throwable t)
+                if (error != null)
                 {
                     _trustManagers = new TrustManager[0];
                     setState(State.ERRORED);
-                    result.setException(t);
-
+                    result.completeExceptionally(error);
+                }
+                else
+                {
+                    _x509Certificate = certificate;
+                    attributeSet(CERTIFICATE, currentCertificate, _x509Certificate);
+                    generateTrustAndSetState(result);
                 }
             }, getTaskExecutor());
+
             return result;
         }
         else
@@ -206,76 +198,71 @@ public class SiteSpecificTrustStoreImpl
         return result;
     }
 
-    private void generateTrustAndSetState(final SettableFuture<Void> result)
+    private void generateTrustAndSetState(final CompletableFuture<Void> result)
     {
         State state = State.ERRORED;
         try
         {
             generateTrustManagers();
             state = State.ACTIVE;
-            result.set(null);
+            result.complete(null);
         }
         catch(IllegalConfigurationException e)
         {
-            result.setException(e);
+            result.completeExceptionally(e);
         }
         finally
         {
             setState(state);
-            result.set(null);
+            result.complete(null);
         }
     }
 
-    private ListenableFuture<X509Certificate> downloadCertificate(final String url)
+    private CompletableFuture<X509Certificate> downloadCertificate(final String url)
     {
-        final ListeningExecutorService workerService = MoreExecutors.listeningDecorator(Executors.newSingleThreadExecutor(
-                getThreadFactory("download-certificate-worker-" + getName())));
+        final ExecutorService workerService = Executors.newSingleThreadExecutor(
+                getThreadFactory("download-certificate-worker-" + getName()));
         try
         {
-            return workerService.submit(new Callable<X509Certificate>()
+            return CompletableFuture.supplyAsync(() ->
             {
-
-                @Override
-                public X509Certificate call()
+                try
                 {
-                    try
+                    final URL siteUrl = new URL(url);
+                    final int port = siteUrl.getPort() == -1 ? siteUrl.getDefaultPort() : siteUrl.getPort();
+                    SSLContext sslContext = SSLUtil.tryGetSSLContext();
+                    sslContext.init(new KeyManager[0], new TrustManager[]{new AlwaysTrustManager()}, null);
+                    try (SSLSocket socket = (SSLSocket) sslContext.getSocketFactory().createSocket())
                     {
-                        final URL siteUrl = new URL(url);
-                        final int port = siteUrl.getPort() == -1 ? siteUrl.getDefaultPort() : siteUrl.getPort();
-                        SSLContext sslContext = SSLUtil.tryGetSSLContext();
-                        sslContext.init(new KeyManager[0], new TrustManager[]{new AlwaysTrustManager()}, null);
-                        try (SSLSocket socket = (SSLSocket) sslContext.getSocketFactory().createSocket())
+                        socket.setSoTimeout(_readTimeout);
+                        socket.connect(new InetSocketAddress(siteUrl.getHost(), port), _connectTimeout);
+                        socket.startHandshake();
+                        final Certificate[] certificateChain = socket.getSession().getPeerCertificates();
+                        if (certificateChain != null
+                            && certificateChain.length != 0
+                            && certificateChain[0] instanceof X509Certificate)
                         {
-                            socket.setSoTimeout(_readTimeout);
-                            socket.connect(new InetSocketAddress(siteUrl.getHost(), port), _connectTimeout);
-                            socket.startHandshake();
-                            final Certificate[] certificateChain = socket.getSession().getPeerCertificates();
-                            if (certificateChain != null
-                                && certificateChain.length != 0
-                                && certificateChain[0] instanceof X509Certificate)
-                            {
-                                final X509Certificate x509Certificate = (X509Certificate) certificateChain[0];
-                                LOGGER.debug("Successfully downloaded X509Certificate with DN {} certificate from {}",
-                                             x509Certificate.getSubjectDN(), url);
-                                return x509Certificate;
-                            }
-                            else
-                            {
-                                throw new IllegalConfigurationException(String.format("TLS handshake for '%s' from '%s' "
-                                                                                      + "did not provide a X509Certificate",
-                                                                                     getName(),
-                                                                                     url));
-                            }
+                            final X509Certificate x509Certificate = (X509Certificate) certificateChain[0];
+                            LOGGER.debug("Successfully downloaded X509Certificate with DN {} certificate from {}",
+                                         x509Certificate.getSubjectX500Principal().getName(), url);
+                            return x509Certificate;
+                        }
+                        else
+                        {
+                            throw new IllegalConfigurationException(String.format("TLS handshake for '%s' from '%s' "
+                                                                                  + "did not provide a X509Certificate",
+                                                                                 getName(),
+                                                                                 url));
                         }
                     }
-                    catch (IOException | GeneralSecurityException e)
-                    {
-                        throw new IllegalConfigurationException(String.format("Unable to get certificate for '%s' from '%s'",
-                                                                              getName(),
-                                                                              url), e);
-                    }
                 }
-            });
+                catch (IOException | GeneralSecurityException e)
+                {
+                    throw new IllegalConfigurationException(String.format("Unable to get certificate for '%s' from '%s'",
+                                                                          getName(),
+                                                                          url), e);
+                }
+            }, workerService);
         }
         finally
         {
@@ -322,16 +309,12 @@ public class SiteSpecificTrustStoreImpl
     {
         logOperation("refreshCertificate");
         final String currentCertificate = getCertificate();
-        final ListenableFuture<X509Certificate> certFuture = downloadCertificate(getSiteUrl());
-        final ListenableFuture<Void> modelFuture = doAfter(certFuture, new CallableWithArgument<ListenableFuture<Void>, X509Certificate>()
+        final CompletableFuture<X509Certificate> certFuture = downloadCertificate(getSiteUrl());
+        final CompletableFuture<Void> modelFuture = certFuture.thenApply(cert ->
         {
-            @Override
-            public ListenableFuture<Void> call(final X509Certificate cert) throws Exception
-            {
-                _x509Certificate = cert;
-                attributeSet(CERTIFICATE, currentCertificate, _x509Certificate);
-                return Futures.immediateFuture(null);
-            }
+            _x509Certificate = cert;
+            attributeSet(CERTIFICATE, currentCertificate, _x509Certificate);
+            return null;
         });
         doSync(modelFuture);
     }
@@ -340,13 +323,11 @@ public class SiteSpecificTrustStoreImpl
     {
         @Override
         public void checkClientTrusted(final X509Certificate[] chain, final String authType)
-                throws CertificateException
         {
 
         }
         @Override
         public void checkServerTrusted(final X509Certificate[] chain, final String authType)
-                throws CertificateException
         {
 
         }
@@ -362,7 +343,6 @@ public class SiteSpecificTrustStoreImpl
     {
         return runnable ->
         {
-
             final Thread thread = Executors.defaultThreadFactory().newThread(runnable);
             if (!thread.isDaemon())
             {
