@@ -33,11 +33,13 @@ import java.security.Principal;
 import java.util.Map;
 import java.util.stream.Stream;
 
-import com.fasterxml.jackson.core.JsonProcessingException;
-import com.fasterxml.jackson.databind.ObjectMapper;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import tools.jackson.core.JacksonException;
+import tools.jackson.databind.ObjectMapper;
+import tools.jackson.databind.json.JsonMapper;
+
 import org.apache.qpid.server.configuration.IllegalConfigurationException;
 import org.apache.qpid.server.model.NamedAddressSpace;
 import org.apache.qpid.server.model.TrustStore;
@@ -64,7 +66,7 @@ public class GitHubOAuth2IdentityResolverService implements OAuth2IdentityResolv
 
     public static final String TYPE = "GitHubUser";
 
-    private final ObjectMapper _objectMapper = new ObjectMapper();
+    private final ObjectMapper _objectMapper = JsonMapper.builder().build();
 
     @Override
     public String getType()
@@ -129,7 +131,7 @@ public class GitHubOAuth2IdentityResolverService implements OAuth2IdentityResolv
             {
                 responseMap = _objectMapper.readValue(input, Map.class);
             }
-            catch (JsonProcessingException e)
+            catch (JacksonException e)
             {
                 throw new IOException(String.format("Identity resolver '%s' did not return json",
                                                     userInfoEndpoint), e);
