@@ -48,7 +48,9 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
 {
     private static final Logger LOGGER = LoggerFactory.getLogger(BrokerStoreUpgraderAndRecoverer.class);
 
-    public static final String VIRTUALHOSTS = "virtualhosts";
+    private static final String BROKER = "Broker";
+    private static final String VIRTUALHOSTS = "virtualhosts";
+
     private final SystemConfig<?> _systemConfig;
 
     // Note: don't use externally defined constants in upgraders in case they change, the values here MUST stay the same
@@ -70,6 +72,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         register(new Upgrader_7_0_to_7_1());
         register(new Upgrader_7_1_to_8_0());
         register(new Upgrader_8_0_to_9_0());
+        register(new Upgrader_9_0_to_9_1());
     }
 
     private static final class Upgrader_1_0_to_1_1 extends StoreUpgraderPhase
@@ -82,12 +85,12 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         @Override
         public void configuredObject(ConfiguredObjectRecord record)
         {
-            if (record.getType().equals("Broker"))
+            if (record.getType().equals(BROKER))
             {
                 record = upgradeRootRecord(record);
                 createVirtualHostsRecordsFromBrokerRecordForModel_1_x(record, this);
             }
-            else if (record.getType().equals("VirtualHost") && record.getAttributes().containsKey("storeType"))
+            else if (record.getType().equals(VIRTUALHOST) && record.getAttributes().containsKey("storeType"))
             {
                 Map<String, Object> updatedAttributes = new HashMap<>(record.getAttributes());
                 updatedAttributes.put("type", "STANDARD");
@@ -114,7 +117,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         @Override
         public void configuredObject(ConfiguredObjectRecord record)
         {
-            if (record.getType().equals("Broker"))
+            if (record.getType().equals(BROKER))
             {
                 record = upgradeRootRecord(record);
                 createVirtualHostsRecordsFromBrokerRecordForModel_1_x(record, this);
@@ -154,7 +157,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
                 getUpdateMap().put(record.getId(), record);
 
             }
-            else if (record.getType().equals("Broker"))
+            else if (record.getType().equals(BROKER))
             {
                 record = upgradeRootRecord(record);
                 createVirtualHostsRecordsFromBrokerRecordForModel_1_x(record, this);
@@ -181,7 +184,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         @Override
         public void configuredObject(ConfiguredObjectRecord record)
         {
-            if (record.getType().equals("VirtualHost"))
+            if (record.getType().equals(VIRTUALHOST))
             {
                 Map<String, Object> attributes = record.getAttributes();
                 if (attributes.containsKey("configPath"))
@@ -200,7 +203,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
                 getUpdateMap().put(record.getId(), record);
 
             }
-            else if (record.getType().equals("Broker"))
+            else if (record.getType().equals(BROKER))
             {
                 record = upgradeRootRecord(record);
                 createVirtualHostsRecordsFromBrokerRecordForModel_1_x(record, this);
@@ -238,7 +241,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
                 record = new ConfiguredObjectRecordImpl(record.getId(), record.getType(), updatedAttributes, record.getParents());
                 getUpdateMap().put(record.getId(), record);
             }
-            else if (record.getType().equals("Broker"))
+            else if (record.getType().equals(BROKER))
             {
                 upgradeRootRecord(record);
             }
@@ -316,7 +319,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         @Override
         public void configuredObject(ConfiguredObjectRecord record)
         {
-            if (record.getType().equals("Broker"))
+            if (record.getType().equals(BROKER))
             {
                 record = upgradeRootRecord(record);
 
@@ -370,7 +373,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
             final ConfiguredObjectRecord logger = new ConfiguredObjectRecordImpl(UUID.randomUUID(),
                     "BrokerLogger",
                     attributes,
-                    Collections.singletonMap("Broker",
+                    Collections.singletonMap(BROKER,
                             record.getId()));
             addNameValueFilter("Root", logger, LogLevel.WARN, "ROOT");
             addNameValueFilter("Qpid", logger, LogLevel.INFO, "org.apache.qpid.*");
@@ -454,7 +457,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         @Override
         public void configuredObject(ConfiguredObjectRecord record)
         {
-            if (record.getType().equals("Broker"))
+            if (record.getType().equals(BROKER))
             {
                 record = upgradeRootRecord(record);
                 _rootRecordId = record.getId();
@@ -543,7 +546,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
                 attrs.put(ConfiguredObject.TYPE, "AllowAll");
                 attrs.put("priority", 9999);
                 ConfiguredObjectRecord allowAllAclRecord =
-                        new ConfiguredObjectRecordImpl(allowAllACLId, "AccessControlProvider", attrs, Collections.singletonMap("Broker", _rootRecordId));
+                        new ConfiguredObjectRecordImpl(allowAllACLId, "AccessControlProvider", attrs, Collections.singletonMap(BROKER, _rootRecordId));
                 getUpdateMap().put(allowAllAclRecord.getId(), allowAllAclRecord);
 
             }
@@ -569,7 +572,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         @Override
         public void configuredObject(ConfiguredObjectRecord record)
         {
-            if (record.getType().equals("Broker"))
+            if (record.getType().equals(BROKER))
             {
                 boolean rebuildRecord = false;
                 Map<String, Object> attributes = new HashMap<>(record.getAttributes());
@@ -601,12 +604,12 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
                 if (!additionalContext.isEmpty())
                 {
                     Map<String, String> newContext = new HashMap<>();
-                    if (attributes.containsKey("context"))
+                    if (attributes.containsKey(CONTEXT))
                     {
-                        newContext.putAll((Map<String, String>) attributes.get("context"));
+                        newContext.putAll((Map<String, String>) attributes.get(CONTEXT));
                     }
                     newContext.putAll(additionalContext);
-                    attributes.put("context", newContext);
+                    attributes.put(CONTEXT, newContext);
 
                     rebuildRecord = true;
                 }
@@ -653,9 +656,9 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         private void upgradeHttpPortIfRequired(final ConfiguredObjectRecord record)
         {
             Map<String, Object> attributes = record.getAttributes();
-            if (attributes.containsKey("context"))
+            if (attributes.containsKey(CONTEXT))
             {
-                Map<String, String> context = (Map<String, String>) attributes.get("context");
+                Map<String, String> context = (Map<String, String>) attributes.get(CONTEXT);
                 if (context != null
                     && (context.containsKey("port.http.additionalInternalThreads")
                         || context.containsKey("port.http.maximumQueuedRequests")))
@@ -668,7 +671,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
                         updatedContext.put("qpid.port.http.acceptBacklog", acceptorsBacklog);
                     }
                     Map<String, Object> updatedAttributes = new LinkedHashMap<>(attributes);
-                    updatedAttributes.put("context", updatedContext);
+                    updatedAttributes.put(CONTEXT, updatedContext);
 
                     ConfiguredObjectRecord upgradedRecord = new ConfiguredObjectRecordImpl(record.getId(),
                                                                                            record.getType(),
@@ -697,7 +700,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         @Override
         public void configuredObject(final ConfiguredObjectRecord record)
         {
-            if("Broker".equals(record.getType()))
+            if(BROKER.equals(record.getType()))
             {
                 upgradeRootRecord(record);
             }
@@ -721,7 +724,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         @Override
         public void configuredObject(final ConfiguredObjectRecord record)
         {
-            if("Broker".equals(record.getType()))
+            if(BROKER.equals(record.getType()))
             {
                 upgradeRootRecord(record);
             }
@@ -745,12 +748,12 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         @Override
         public void configuredObject(ConfiguredObjectRecord record)
         {
-            if ("Broker".equals(record.getType()))
+            if (BROKER.equals(record.getType()))
             {
                 record = upgradeRootRecord(record);
             }
             renameContextVariables(record,
-                                   "context",
+                                   CONTEXT,
                                    UpgraderHelper.MODEL9_MAPPING_FOR_RENAME_TO_ALLOW_DENY_CONTEXT_VARIABLES);
         }
 
@@ -761,6 +764,46 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         }
     }
 
+    private static class Upgrader_9_0_to_9_1 extends StoreUpgraderPhase
+    {
+        public Upgrader_9_0_to_9_1()
+        {
+            super("modelVersion", "9.0", "9.1");
+        }
+
+        @Override
+        public void configuredObject(ConfiguredObjectRecord record)
+        {
+            if (BROKER.equals(record.getType()))
+            {
+                record = upgradeRootRecord(UpgraderHelper.upgradeConnectionPool(record));
+                getUpdateMap().put(record.getId(), record);
+                return;
+            }
+
+            final Map<String, Object> attributes = record.getAttributes();
+
+            if (attributes == null)
+            {
+                return;
+            }
+
+            if (!JDBC.equals(attributes.get("type")))
+            {
+                return;
+            }
+
+            final ConfiguredObjectRecord updatedRecord = UpgraderHelper.upgradeConnectionPool(record);
+            getUpdateMap().put(updatedRecord.getId(), updatedRecord);
+        }
+
+        @Override
+        public void complete()
+        {
+
+        }
+    }
+
     private static class VirtualHostEntryUpgrader
     {
         Map<String, AttributesTransformer> _messageStoreToNodeTransformers = Map.of("DERBY", new AttributesTransformer().
@@ -784,8 +827,8 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
                     addAttributeTransformer("storePath", copyAttribute()).
                     addAttributeTransformer("storeUnderfullSize", copyAttribute()).
                     addAttributeTransformer("storeOverfullSize", copyAttribute()).
-                    addAttributeTransformer("bdbEnvironmentConfig", mutateAttributeName("context")),
-                "JDBC", new AttributesTransformer().
+                    addAttributeTransformer("bdbEnvironmentConfig", mutateAttributeName(CONTEXT)),
+                JDBC, new AttributesTransformer().
                     addAttributeTransformer("id", copyAttribute()).
                     addAttributeTransformer("name", copyAttribute()).
                     addAttributeTransformer("createdTime", copyAttribute()).
@@ -822,8 +865,8 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
                     addAttributeTransformer("haHelperAddress", mutateAttributeName("helperAddress")).
                     addAttributeTransformer("haNodeAddress", mutateAttributeName("address")).
                     addAttributeTransformer("haDesignatedPrimary", mutateAttributeName("designatedPrimary")).
-                    addAttributeTransformer("haReplicationConfig", mutateAttributeName("context")).
-                    addAttributeTransformer("bdbEnvironmentConfig", mutateAttributeName("context")));
+                    addAttributeTransformer("haReplicationConfig", mutateAttributeName(CONTEXT)).
+                    addAttributeTransformer("bdbEnvironmentConfig", mutateAttributeName(CONTEXT)));
 
         public ConfiguredObjectRecord upgrade(ConfiguredObjectRecord vhost)
         {
@@ -973,7 +1016,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         @Override
         public MutableEntry transform(MutableEntry entry)
         {
-            return new MutableEntry("context", Collections.singletonMap(_newName, entry.getValue()));
+            return new MutableEntry(CONTEXT, Collections.singletonMap(_newName, entry.getValue()));
         }
     }
 
@@ -1062,7 +1105,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
                         }
                     }
 
-                    ConfiguredObjectRecord nodeRecord = new ConfiguredObjectRecordImpl(id, "VirtualHost", virtualHostAttributes, Collections.singletonMap("Broker", brokerRecord.getId()));
+                    ConfiguredObjectRecord nodeRecord = new ConfiguredObjectRecordImpl(id, VIRTUALHOST, virtualHostAttributes, Collections.singletonMap(BROKER, brokerRecord.getId()));
 
                     upgrader.getUpdateMap().put(nodeRecord.getId(), nodeRecord);
                     upgrader.configuredObject(nodeRecord);
