@@ -74,6 +74,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         register(new Upgrader_7_0_to_7_1());
         register(new Upgrader_7_1_to_8_0());
         register(new Upgrader_8_0_to_9_0());
+        register(new Upgrader_9_0_to_9_1());
 
         Map<String, UUID> defaultExchangeIds = new HashMap<>();
         for (String exchangeName : DEFAULT_EXCHANGES.keySet())
@@ -192,7 +193,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
             ConfiguredObjectRecord newRecord = new ConfiguredObjectRecordImpl(record.getId(), type, record.getAttributes(), record.getParents());
             getUpdateMap().put(record.getId(), newRecord);
 
-            if ("VirtualHost".equals(type))
+            if (VIRTUALHOST.equals(type))
             {
                 upgradeRootRecord(newRecord);
             }
@@ -256,7 +257,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         @Override
         public void configuredObject(ConfiguredObjectRecord record)
         {
-            if ("VirtualHost".equals(record.getType()))
+            if (VIRTUALHOST.equals(record.getType()))
             {
                 upgradeRootRecord(record);
             }
@@ -362,7 +363,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         @Override
         public void configuredObject(ConfiguredObjectRecord record)
         {
-            if("VirtualHost".equals(record.getType()))
+            if(VIRTUALHOST.equals(record.getType()))
             {
                 upgradeRootRecord(record);
             }
@@ -419,13 +420,13 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         @Override
         public void configuredObject(ConfiguredObjectRecord record)
         {
-            if("VirtualHost".equals(record.getType()))
+            if(VIRTUALHOST.equals(record.getType()))
             {
                 record = upgradeRootRecord(record);
                 Map<String, Object> virtualHostAttributes = new HashMap<>(record.getAttributes());
                 virtualHostAttributes.put("name", _virtualHostNode.getName());
                 virtualHostAttributes.put("modelVersion", getToVersion());
-                record = new ConfiguredObjectRecordImpl(record.getId(), "VirtualHost", virtualHostAttributes, Map.of());
+                record = new ConfiguredObjectRecordImpl(record.getId(), VIRTUALHOST, virtualHostAttributes, Map.of());
                 _virtualHostRecord = record;
             }
             else if("Exchange".equals(record.getType()))
@@ -543,7 +544,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         public void configuredObject(ConfiguredObjectRecord record)
         {
 
-            if("VirtualHost".equals(record.getType()))
+            if(VIRTUALHOST.equals(record.getType()))
             {
                 upgradeRootRecord(record);
             }
@@ -566,7 +567,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         public void configuredObject(ConfiguredObjectRecord record)
         {
 
-            if("VirtualHost".equals(record.getType()))
+            if(VIRTUALHOST.equals(record.getType()))
             {
                 upgradeRootRecord(record);
             }
@@ -590,7 +591,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         public void configuredObject(ConfiguredObjectRecord record)
         {
 
-            if("VirtualHost".equals(record.getType()))
+            if(VIRTUALHOST.equals(record.getType()))
             {
                 upgradeRootRecord(record);
             }
@@ -623,12 +624,12 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         @Override
         public void configuredObject(ConfiguredObjectRecord record)
         {
-            if("VirtualHost".equals(record.getType()))
+            if(VIRTUALHOST.equals(record.getType()))
             {
                 record = upgradeRootRecord(record);
                 Map<String, Object> attributes = new HashMap<>(record.getAttributes());
                 boolean modified = attributes.remove("queue_deadLetterQueueEnabled") != null;
-                Object context = attributes.get("context");
+                Object context = attributes.get(CONTEXT);
                 Map<String,Object> contextMap = null;
                 if(context instanceof Map)
                 {
@@ -636,7 +637,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
                     modified |= contextMap.remove("queue.deadLetterQueueEnabled") != null;
                     if (modified)
                     {
-                        attributes.put("context", contextMap);
+                        attributes.put(CONTEXT, contextMap);
                     }
                 }
 
@@ -650,7 +651,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
                     }
 
                     contextMap.put("qpid.virtualhost.statisticsReportPattern", "${ancestor:virtualhost:name}: messagesIn=${messagesIn}, bytesIn=${bytesIn:byteunit}, messagesOut=${messagesOut}, bytesOut=${bytesOut:byteunit}");
-                    attributes.put("context", contextMap);
+                    attributes.put(CONTEXT, contextMap);
                     modified = true;
                 }
 
@@ -725,7 +726,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
                                            / ((double) queueFlowControlSizeBytesValue);
                             String flowResumeLimit = String.format("%.2f", ratio * 100.0);
 
-                            Object context = attributes.get("context");
+                            Object context = attributes.get(CONTEXT);
                             Map<String, String> contextMap;
                             if (context instanceof Map)
                             {
@@ -734,7 +735,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
                             else
                             {
                                 contextMap = new HashMap<>();
-                                attributes.put("context", contextMap);
+                                attributes.put(CONTEXT, contextMap);
                             }
                             contextMap.put("queue.queueFlowResumeLimit", flowResumeLimit);
                         }
@@ -1046,7 +1047,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         @Override
         public void configuredObject(final ConfiguredObjectRecord record)
         {
-            if("VirtualHost".equals(record.getType()))
+            if(VIRTUALHOST.equals(record.getType()))
             {
                 upgradeRootRecord(record);
             }
@@ -1070,7 +1071,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         @Override
         public void configuredObject(final ConfiguredObjectRecord record)
         {
-            if("VirtualHost".equals(record.getType()))
+            if(VIRTUALHOST.equals(record.getType()))
             {
                 upgradeRootRecord(record);
             }
@@ -1093,12 +1094,12 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         @Override
         public void configuredObject(ConfiguredObjectRecord record)
         {
-            if ("VirtualHost".equals(record.getType()))
+            if (VIRTUALHOST.equals(record.getType()))
             {
                 record = upgradeRootRecord(record);
             }
             renameContextVariables(record,
-                                   "context",
+                                   CONTEXT,
                                    UpgraderHelper.MODEL9_MAPPING_FOR_RENAME_TO_ALLOW_DENY_CONTEXT_VARIABLES);
         }
 
@@ -1109,6 +1110,39 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         }
     }
 
+    private static class Upgrader_9_0_to_9_1 extends StoreUpgraderPhase
+    {
+        public Upgrader_9_0_to_9_1()
+        {
+            super("modelVersion", "9.0", "9.1");
+        }
+
+        @Override
+        public void configuredObject(final ConfiguredObjectRecord record)
+        {
+            final Map<String, Object> attributes = record.getAttributes();
+
+            if (attributes == null)
+            {
+                return;
+            }
+
+            if (!JDBC.equals(attributes.get("type")))
+            {
+                return;
+            }
+
+            final ConfiguredObjectRecord updatedRecord = UpgraderHelper.upgradeConnectionPool(record);
+            getUpdateMap().put(updatedRecord.getId(), updatedRecord);
+        }
+
+        @Override
+        public void complete()
+        {
+
+        }
+    }
+
     public boolean upgradeAndRecover(final DurableConfigurationStore durableConfigurationStore,
                                      final ConfiguredObjectRecord... initialRecords)
     {
