@@ -40,6 +40,9 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import org.apache.qpid.server.bytebuffer.QpidByteBuffer;
+import org.apache.qpid.server.logging.EventLogger;
+import org.apache.qpid.server.logging.messages.NetworkMessages;
+import org.apache.qpid.server.model.Broker;
 import org.apache.qpid.server.model.port.AmqpPort;
 import org.apache.qpid.server.transport.network.TransportEncryption;
 import org.apache.qpid.server.util.ConnectionScopedRuntimeException;
@@ -58,12 +61,15 @@ public class NonBlockingConnection implements ServerNetworkConnection, ByteBuffe
     private final AtomicBoolean _closed = new AtomicBoolean(false);
     private final ProtocolEngine _protocolEngine;
     private final Runnable _onTransportEncryptionAction;
+    private final int _finalWriteThreshold;
+    private final long _finalWriteTimeout;
 
     private volatile boolean _fullyWritten = true;
 
     private volatile boolean _partialRead = false;
 
     private final AmqpPort _port;
+    private final EventLogger _eventLogger;
     private final AtomicBoolean _scheduled = new AtomicBoolean();
     private volatile long _scheduledTime;
     private volatile boolean _unexpectedByteBufferSizeReported;
@@ -110,7 +116,11 @@ public class NonBlockingConnection implements ServerNetworkConnection, ByteBuffe
         {
             _delegate = new NonBlockingConnectionUndecidedDelegate(this);
         }
+        _finalWriteThreshold = port.getContextValue(Integer.class, AmqpPort.FINAL_WRITE_THRESHOLD);
+        _finalWriteTimeout = port.getContextValue(Long.class, AmqpPort.FINAL_WRITE_TIMEOUT);
 
+        final Broker broker = (Broker<?>) port.getParent();
+        _eventLogger = broker.getEventLogger();
     }
 
     String getThreadName()
@@ -136,6 +146,8 @@ public class NonBlockingConnection implements ServerNetworkConnection, ByteBuffe
     @Override
     public void start()
     {
+        final String localAddressStr = formattedLocalAddress();
+        _eventLogger.message(NetworkMessages.OPEN(_port.getName(), localAddressStr, _remoteSocketAddress));
     }
 
     @Override
@@ -395,6 +407,8 @@ public class NonBlockingConnection implements ServerNetworkConnection, ByteBuffe
                 finally
                 {
                     _socketChannel.close();
+                    final String localAddressStr = formattedLocalAddress();
+                    _eventLogger.message(NetworkMessages.CLOSED(_port.getName(), localAddressStr, _remoteSocketAddress));
                 }
             }
             catch (IOException e)
@@ -414,8 +428,16 @@ public class NonBlockingConnection implements ServerNetworkConnection, ByteBuffe
     {
         try
         {
-            while(!doWrite())
+            final long startTime = System.currentTimeMillis();
+            int cnt = 0;
+            while (!doWrite())
             {
+                if (cnt % _finalWriteThreshold == 0 && System.currentTimeMillis() - startTime > _finalWriteTimeout)
+                {
+                    final long executionTime = System.currentTimeMillis() - startTime;
+                    throw new IOException("Failed to perform final write to connection after " + executionTime + " ms timeout");
+                }
+                cnt++;
             }
         }
         catch (IOException e)
