@@ -27,10 +27,12 @@ import java.nio.charset.StandardCharsets;
 import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
 import java.util.BitSet;
+import java.util.Collection;
 import java.util.Comparator;
 import java.util.Map;
 import java.util.Random;
 import java.security.SecureRandom;
+import java.util.stream.Collectors;
 
 public class StringUtil
 {
@@ -192,4 +194,26 @@ public class StringUtil
         }
         return 0;
     }
+
+    public static String join(final Collection<?> collection, final String delimiter, final String useForNull)
+    {
+        if (collection == null)
+        {
+            return "";
+        }
+        return collection.stream()
+                         .map(el -> el == null ? useForNull : String.valueOf(el))
+                         .collect(Collectors.joining(delimiter));
+    }
+
+    public static String join(final Map<?, ?> map, final String delimiter, final String keyValueSeparator)
+    {
+        if (map == null)
+        {
+            return "";
+        }
+        return map.entrySet().stream()
+                  .map(entry -> entry.getKey() + keyValueSeparator + entry.getValue())
+                  .collect(Collectors.joining(delimiter));
+    }
 }
