@@ -24,9 +24,8 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.TreeMap;
 import java.util.UUID;
+import java.util.concurrent.CompletableFuture;
 
-import com.google.common.util.concurrent.Futures;
-import com.google.common.util.concurrent.ListenableFuture;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -53,7 +52,6 @@ import org.apache.qpid.server.txn.DtxBranch;
 import org.apache.qpid.server.txn.DtxRegistry;
 import org.apache.qpid.server.txn.ServerTransaction;
 import org.apache.qpid.server.txn.Xid;
-import org.apache.qpid.server.util.Action;
 import org.apache.qpid.server.util.ServerScopedRuntimeException;
 
 public class SynchronousMessageStoreRecoverer implements MessageStoreRecoverer
@@ -61,7 +59,7 @@ public class SynchronousMessageStoreRecoverer implements MessageStoreRecoverer
     private static final Logger LOGGER = LoggerFactory.getLogger(SynchronousMessageStoreRecoverer.class);
 
     @Override
-    public ListenableFuture<Void> recover(QueueManagingVirtualHost<?> virtualHost)
+    public CompletableFuture<Void> recover(QueueManagingVirtualHost<?> virtualHost)
     {
         EventLogger eventLogger = virtualHost.getEventLogger();
         MessageStore store = virtualHost.getMessageStore();
@@ -147,7 +145,7 @@ public class SynchronousMessageStoreRecoverer implements MessageStoreRecoverer
                              MessageStoreMessages.RECOVERED(recoveredMessages.size() - unusedMessages.size()));
         eventLogger.message(logSubject, MessageStoreMessages.RECOVERY_COMPLETE());
 
-        return Futures.immediateFuture(null);
+        return CompletableFuture.completedFuture(null);
     }
 
     @Override
@@ -316,14 +314,7 @@ public class SynchronousMessageStoreRecoverer implements MessageStoreRecoverer
                         final MessageReference<?> ref = message.newReference();
                         final MessageEnqueueRecord[] records = new MessageEnqueueRecord[1];
 
-                        branch.enqueue(queue, message, new Action<MessageEnqueueRecord>()
-                        {
-                            @Override
-                            public void performAction(final MessageEnqueueRecord record)
-                            {
-                                records[0] = record;
-                            }
-                        });
+                        branch.enqueue(queue, message, record1 -> records[0] = record1);
                         branch.addPostTransactionAction(new ServerTransaction.Action()
                         {
                             @Override
