@@ -24,7 +24,7 @@ import java.text.NumberFormat;
 import java.util.List;
 import java.util.Locale;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 /**
  * Test BRK log Messages
@@ -34,13 +34,11 @@ public class BrokerMessagesTest extends AbstractTestMessages
     @Test
     public void testBrokerStartup()
     {
-        String version = "Qpid 0.6";
-        String build = "796936M";
-
+        final String version = "Qpid 0.6";
+        final String build = "796936M";
         _logMessage = BrokerMessages.STARTUP(version, build);
-        List<Object> log = performLog();
-
-        String[] expected = {"Startup :", "Version:", version, "Build:", build};
+        final List<Object> log = performLog();
+        final String[] expected = {"Startup :", "Version:", version, "Build:", build};
 
         validateLogMessage(log, "BRK-1001", expected);
     }
@@ -48,15 +46,14 @@ public class BrokerMessagesTest extends AbstractTestMessages
     @Test
     public void testBrokerListening()
     {
-        String transport = "TCP";
-        Integer port = 2765;
+        final String transport = "TCP";
+        final Integer port = 2765;
 
         _logMessage = BrokerMessages.LISTENING(transport, port);
 
-        List<Object> log = performLog();
+        final List<Object> log = performLog();
 
-        String[] expected = {"Starting", "Listening on ",
-                             transport, "port ", String.valueOf(port)};
+        final String[] expected = {"Starting", "Listening on ", transport, "port ", String.valueOf(port)};
 
         validateLogMessage(log, "BRK-1002", expected);
     }
@@ -64,14 +61,14 @@ public class BrokerMessagesTest extends AbstractTestMessages
     @Test
     public void testBrokerShuttingDown()
     {
-        String transport = "TCP";
-        Integer port = 2765;
+        final String transport = "TCP";
+        final Integer port = 2765;
 
         _logMessage = BrokerMessages.SHUTTING_DOWN(transport, port);
 
-        List<Object> log = performLog();
+        final List<Object> log = performLog();
 
-        String[] expected = {"Shutting down", transport, "port ", String.valueOf(port)};
+        final String[] expected = { "Shutting down", transport, "port ", String.valueOf(port) };
 
         validateLogMessage(log, "BRK-1003", expected);
     }
@@ -80,9 +77,9 @@ public class BrokerMessagesTest extends AbstractTestMessages
     public void testBrokerReady()
     {
         _logMessage = BrokerMessages.READY();
-        List<Object> log = performLog();
+        final List<Object> log = performLog();
 
-        String[] expected = {"Ready"};
+        final String[] expected = {"Ready"};
 
         validateLogMessage(log, "BRK-1004", expected);
     }
@@ -91,9 +88,9 @@ public class BrokerMessagesTest extends AbstractTestMessages
     public void testBrokerStopped()
     {
         _logMessage = BrokerMessages.STOPPED();
-        List<Object> log = performLog();
+        final List<Object> log = performLog();
 
-        String[] expected = {"Stopped"};
+        final String[] expected = {"Stopped"};
 
         validateLogMessage(log, "BRK-1005", expected);
     }
@@ -101,12 +98,12 @@ public class BrokerMessagesTest extends AbstractTestMessages
     @Test
     public void testBrokerConfig()
     {
-        String path = "/file/path/to/configuration.xml";
+        final String path = "/file/path/to/configuration.xml";
 
         _logMessage = BrokerMessages.CONFIG(path);
-        List<Object> log = performLog();
+        final List<Object> log = performLog();
 
-        String[] expected = {"Using configuration :", path};
+        final String[] expected = {"Using configuration :", path};
 
         validateLogMessage(log, "BRK-1006", expected);
     }
@@ -114,19 +111,17 @@ public class BrokerMessagesTest extends AbstractTestMessages
     @Test
     public void testBrokerPlatform()
     {
-        String javaVendor = "jvendor";
-        String javaVersion = "j1.0";
-
-        String osName = "os";
-        String osVersion = "o1.0";
-        String osArch = "oarch";
-
-        String cores = "2";
+        final String javaVendor = "jvendor";
+        final String javaVersion = "j1.0";
+        final String osName = "os";
+        final String osVersion = "o1.0";
+        final String osArch = "oarch";
+        final String cores = "2";
 
         _logMessage = BrokerMessages.PLATFORM(javaVendor, javaVersion, osName, osVersion, osArch, cores);
-        List<Object> log = performLog();
+        final List<Object> log = performLog();
 
-        String[] expected = {"Platform :", "JVM :", javaVendor, " version: ", " OS : ", osName, " version: ", osVersion, " arch: ", osArch, " cores: ", cores};
+        final String[] expected = {"Platform :", "JVM :", javaVendor, " version: ", " OS : ", osName, " version: ", osVersion, " arch: ", osArch, " cores: ", cores};
 
         validateLogMessage(log, "BRK-1010", expected);
     }
@@ -134,21 +129,17 @@ public class BrokerMessagesTest extends AbstractTestMessages
     @Test
     public void testBrokerMemory()
     {
-        long oneGiga = 1024*1024*1024;
-        long twoGiga = oneGiga * 2;
+        final long oneGiga = 1024*1024*1024;
+        final long twoGiga = oneGiga * 2;
 
         _logMessage = BrokerMessages.MAX_MEMORY(oneGiga, twoGiga);
-        List<Object> log = performLog();
+        final List<Object> log = performLog();
 
         // Log messages always use US Locale format for numbers
-        NumberFormat numberFormat = NumberFormat.getNumberInstance(Locale.US);
-
-        String[] expected = {"Maximum Memory :",
-                             "Heap", numberFormat.format(oneGiga), "bytes",
-                             "Direct", numberFormat.format(twoGiga), "bytes"
-        };
+        final NumberFormat numberFormat = NumberFormat.getNumberInstance(Locale.US);
 
+        final String[] expected = {"Maximum Memory :", "Heap", numberFormat.format(oneGiga), "bytes",
+                "Direct", numberFormat.format(twoGiga), "bytes" };
         validateLogMessage(log, "BRK-1011", expected);
     }
-
 }
