@@ -22,7 +22,7 @@ package org.apache.qpid.server.logging.messages;
 
 import java.util.List;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.logging.Outcome;
 
@@ -55,5 +55,4 @@ public class VirtualHostMessagesTest extends AbstractTestMessages
 
         validateLogMessage(log, "VHT-1002", expected);
     }
-
 }
