@@ -31,10 +31,9 @@ import java.security.Principal;
 import java.security.PrivilegedAction;
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Collections;
-import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 import java.util.UUID;
 
 import javax.security.auth.Subject;
@@ -60,55 +59,44 @@ import org.apache.qpid.server.virtualhost.QueueManagingVirtualHost;
 import org.apache.qpid.server.virtualhost.TestMemoryVirtualHost;
 import org.apache.qpid.test.utils.UnitTestBase;
 
-
+@SuppressWarnings({"rawtypes", "unchecked"})
 public class BrokerTestHelper
 {
-
-    private static final Principal SYSTEM_PRINCIPAL =
-            new Principal()
-            {
-
-                @Override
-                public String getName()
-                {
-                    return "TEST";
-                }
-            };
-    private static final Subject SYSTEM_SUBJECT = new Subject(true,
-                                                              Collections.singleton(SYSTEM_PRINCIPAL),
-                                                              Collections.emptySet(),
-                                                              Collections.emptySet());
-
-
+    private static final Principal PRINCIPAL = () -> "TEST";
+    private static final Subject SYSTEM_SUBJECT = new Subject(true, Set.of(PRINCIPAL), Set.of(), Set.of());
     private static final List<VirtualHost> CREATED_VIRTUAL_HOSTS = new ArrayList<>();
-
     private static final TaskExecutor TASK_EXECUTOR = new CurrentThreadTaskExecutor();
-    private static final Runnable CLOSE_VIRTUAL_HOSTS = new Runnable()
-    {
-        @Override
-        public void run()
-        {
-            for (VirtualHost virtualHost : CREATED_VIRTUAL_HOSTS)
-            {
-                virtualHost.close();
-            }
-            CREATED_VIRTUAL_HOSTS.clear();
-        }
-    };
 
     static
     {
         TASK_EXECUTOR.start();
     }
 
+    private static final Runnable CLOSE_VIRTUAL_HOSTS = () ->
+    {
+        CREATED_VIRTUAL_HOSTS.forEach(VirtualHost::close);
+        CREATED_VIRTUAL_HOSTS.clear();
+    };
+
+    private static Broker _broker;
+
     public static Broker<?> createBrokerMock()
     {
-        return createBrokerMock(createAccessControlMock());
+        if (_broker != null)
+        {
+            return _broker;
+        }
+        return createBrokerMock(createAccessControlMock(), true);
+    }
+
+    public static Broker<?> createNewBrokerMock()
+    {
+        return createBrokerMock(createAccessControlMock(), false);
     }
 
     public static AccessControl createAccessControlMock()
     {
-        AccessControl mock = mock(AccessControl.class);
+        final AccessControl mock = mock(AccessControl.class);
         when(mock.authorise(any(SecurityToken.class), any(Operation.class), any(PermissionedObject.class))).thenReturn(
                 Result.DEFER);
         when(mock.authorise(isNull(), any(Operation.class), any(PermissionedObject.class))).thenReturn(
@@ -119,19 +107,19 @@ public class BrokerTestHelper
         return mock;
     }
 
-    private static Broker<?> createBrokerMock(AccessControl accessControl)
+    private static Broker<?> createBrokerMock(final AccessControl accessControl, final boolean cacheBroker)
     {
-        ConfiguredObjectFactory objectFactory = new ConfiguredObjectFactoryImpl(BrokerModel.getInstance());
-        EventLogger eventLogger = new EventLogger();
+        final ConfiguredObjectFactory objectFactory = new ConfiguredObjectFactoryImpl(BrokerModel.getInstance());
+        final EventLogger eventLogger = new EventLogger();
 
-        SystemConfig systemConfig = mock(SystemConfig.class);
+        final SystemConfig systemConfig = mock(SystemConfig.class);
         when(systemConfig.getEventLogger()).thenReturn(eventLogger);
         when(systemConfig.getObjectFactory()).thenReturn(objectFactory);
         when(systemConfig.getModel()).thenReturn(objectFactory.getModel());
         when(systemConfig.getCategoryClass()).thenReturn(SystemConfig.class);
         when(systemConfig.getTypeClass()).thenReturn(SystemConfig.class);
 
-        Broker broker = mockWithSystemPrincipalAndAccessControl(Broker.class, SYSTEM_PRINCIPAL, accessControl);
+        final Broker broker = mockWithSystemPrincipalAndAccessControl(Broker.class, PRINCIPAL, accessControl);
         when(broker.getId()).thenReturn(UUID.randomUUID());
         when(broker.getObjectFactory()).thenReturn(objectFactory);
         when(broker.getModel()).thenReturn(objectFactory.getModel());
@@ -142,50 +130,46 @@ public class BrokerTestHelper
         when(broker.getParent()).thenReturn(systemConfig);
         when(broker.getContextValue(eq(Long.class), eq(Broker.CHANNEL_FLOW_CONTROL_ENFORCEMENT_TIMEOUT))).thenReturn(0L);
         when(broker.getFlowToDiskThreshold()).thenReturn(Long.MAX_VALUE);
-
         when(broker.getTaskExecutor()).thenReturn(TASK_EXECUTOR);
-        when(systemConfig.getTaskExecutor()).thenReturn(TASK_EXECUTOR);
         when(broker.getChildExecutor()).thenReturn(TASK_EXECUTOR);
+        when(systemConfig.getTaskExecutor()).thenReturn(TASK_EXECUTOR);
         when(systemConfig.getChildExecutor()).thenReturn(TASK_EXECUTOR);
         when(systemConfig.createPreferenceStore()).thenReturn(mock(PreferenceStore.class));
-        when(systemConfig.getChildren(Broker.class)).thenReturn(Collections.singleton(broker));
+        when(systemConfig.getChildren(Broker.class)).thenReturn(Set.of(broker));
+
+        if (cacheBroker)
+        {
+            _broker = broker;
+        }
 
         return broker;
     }
 
-    public static void setUp()
-    {
-    }
-
-    public static void tearDown()
-    {
-    }
-
-    public static QueueManagingVirtualHost<?> createVirtualHost(Map<String, Object> attributes,
+    public static QueueManagingVirtualHost<?> createVirtualHost(final Map<String, Object> attributes,
                                                                 final UnitTestBase testBase)
     {
-        Broker<?> broker = createBrokerMock(createAccessControlMock());
+        final Broker<?> broker = createBrokerMock(createAccessControlMock(), true);
         return createVirtualHost(attributes, broker, false, createAccessControlMock(), testBase);
     }
 
     private static QueueManagingVirtualHost<?> createVirtualHost(final Map<String, Object> attributes,
                                                                  final Broker<?> broker,
-                                                                 boolean defaultVHN,
-                                                                 AccessControl accessControl,
+                                                                 final boolean defaultVHN,
+                                                                 final AccessControl accessControl,
                                                                  final UnitTestBase testBase)
     {
-        ConfiguredObjectFactory objectFactory = broker.getObjectFactory();
-        String virtualHostNodeName = String.format("%s_%s", attributes.get(VirtualHostNode.NAME), "_node");
-        VirtualHostNode virtualHostNode =
+        final ConfiguredObjectFactory objectFactory = broker.getObjectFactory();
+        final String virtualHostNodeName = String.format("%s_%s", attributes.get(VirtualHostNode.NAME), "_node");
+        final VirtualHostNode virtualHostNode =
                 createVirtualHostNodeMock(virtualHostNodeName, defaultVHN, accessControl, broker);
 
-        AbstractVirtualHost
-                host = (AbstractVirtualHost) objectFactory.create(VirtualHost.class, attributes, virtualHostNode );
+        final AbstractVirtualHost host = (AbstractVirtualHost) objectFactory
+                .create(VirtualHost.class, attributes, virtualHostNode );
         host.start();
         when(virtualHostNode.getVirtualHost()).thenReturn(host);
         CREATED_VIRTUAL_HOSTS.add(host);
 
-        testBase.registerTearDown(CLOSE_VIRTUAL_HOSTS);
+        testBase.registerAfterAllTearDown(CLOSE_VIRTUAL_HOSTS);
         return host;
     }
 
@@ -194,9 +178,10 @@ public class BrokerTestHelper
                                                             final AccessControl accessControl,
                                                             final Broker<?> broker)
     {
-        ConfiguredObjectFactory objectFactory = broker.getObjectFactory();
+        final ConfiguredObjectFactory objectFactory = broker.getObjectFactory();
 
-        VirtualHostNode virtualHostNode = mockWithSystemPrincipalAndAccessControl(VirtualHostNode.class, SYSTEM_PRINCIPAL, accessControl);
+        final VirtualHostNode virtualHostNode = mockWithSystemPrincipalAndAccessControl(VirtualHostNode.class,
+                                                                                        PRINCIPAL, accessControl);
         when(virtualHostNode.getName()).thenReturn( virtualHostNodeName);
         when(virtualHostNode.getTaskExecutor()).thenReturn(TASK_EXECUTOR);
         when(virtualHostNode.getChildExecutor()).thenReturn(TASK_EXECUTOR);
@@ -205,11 +190,11 @@ public class BrokerTestHelper
         when(virtualHostNode.getParent()).thenReturn(broker);
 
         Collection<VirtualHostNode<?>> nodes = broker.getVirtualHostNodes();
-        nodes = new ArrayList<>(nodes != null ?  nodes : Collections.<VirtualHostNode<?>>emptyList());
+        nodes = new ArrayList<>(nodes != null ?  nodes : List.of());
         nodes.add(virtualHostNode);
         when(broker.getVirtualHostNodes()).thenReturn(nodes);
 
-        DurableConfigurationStore dcs = mock(DurableConfigurationStore.class);
+        final DurableConfigurationStore dcs = mock(DurableConfigurationStore.class);
         when(virtualHostNode.getConfigurationStore()).thenReturn(dcs);
         when(virtualHostNode.getModel()).thenReturn(objectFactory.getModel());
         when(virtualHostNode.getObjectFactory()).thenReturn(objectFactory);
@@ -220,46 +205,45 @@ public class BrokerTestHelper
         return virtualHostNode;
     }
 
-    public static QueueManagingVirtualHost<?> createVirtualHost(String name,
+    public static QueueManagingVirtualHost<?> createVirtualHost(final String name,
                                                                 final UnitTestBase testBase) throws Exception
     {
-        return createVirtualHost(name, createBrokerMock(createAccessControlMock()), false, createAccessControlMock(),
+        return createVirtualHost(name, createBrokerMock(createAccessControlMock(), true), false, createAccessControlMock(),
                                  testBase);
     }
 
-    public static QueueManagingVirtualHost<?> createVirtualHost(String name,
-                                                                Broker<?> broker,
-                                                                boolean defaultVHN,
+    public static QueueManagingVirtualHost<?> createVirtualHost(final String name,
+                                                                final Broker<?> broker,
+                                                                final boolean defaultVHN,
                                                                 final UnitTestBase testBase) throws Exception
     {
         return createVirtualHost(name, broker, defaultVHN, createAccessControlMock(), testBase);
     }
 
-    private static QueueManagingVirtualHost<?> createVirtualHost(String name,
-                                                                 Broker<?> broker,
-                                                                 boolean defaultVHN,
-                                                                 AccessControl accessControl,
-                                                                 final UnitTestBase testBase) throws Exception
+    private static QueueManagingVirtualHost<?> createVirtualHost(final String name,
+                                                                 final Broker<?> broker,
+                                                                 final boolean defaultVHN,
+                                                                 final AccessControl accessControl,
+                                                                 final UnitTestBase testBase)
     {
-        Map<String,Object> attributes = new HashMap<>();
-        attributes.put(org.apache.qpid.server.model.VirtualHost.TYPE, TestMemoryVirtualHost.VIRTUAL_HOST_TYPE);
-        attributes.put(org.apache.qpid.server.model.VirtualHost.NAME, name);
+        final Map<String,Object> attributes = Map.of(
+                org.apache.qpid.server.model.VirtualHost.TYPE, TestMemoryVirtualHost.VIRTUAL_HOST_TYPE,
+                org.apache.qpid.server.model.VirtualHost.NAME, name);
 
         return createVirtualHost(attributes, broker, defaultVHN, accessControl, testBase);
     }
 
-    public static AMQPSession<?,?> createSession(int channelId, AMQPConnection<?> connection)
+    public static AMQPSession<?,?> createSession(final int channelId, final AMQPConnection<?> connection)
     {
-        @SuppressWarnings("rawtypes")
-        AMQPSession session = mock(AMQPSession.class);
+        final AMQPSession session = mock(AMQPSession.class);
         when(session.getAMQPConnection()).thenReturn(connection);
         when(session.getChannelId()).thenReturn(channelId);
         return session;
     }
 
-    public static AMQPSession<?,?> createSession(int channelId) throws Exception
+    public static AMQPSession<?,?> createSession(final int channelId) throws Exception
     {
-        AMQPConnection<?> session = createConnection();
+        final AMQPConnection<?> session = createConnection();
         return createSession(channelId, session);
     }
 
@@ -268,19 +252,19 @@ public class BrokerTestHelper
         return createSession(1);
     }
 
-    public static AMQPConnection<?> createConnection() throws Exception
+    public static AMQPConnection<?> createConnection()
     {
         return createConnection("test");
     }
 
-    public static AMQPConnection<?> createConnection(String hostName) throws Exception
+    public static AMQPConnection<?> createConnection(final String hostName)
     {
         return mock(AMQPConnection.class);
     }
 
-    public static Exchange<?> createExchange(String hostName, final boolean durable, final EventLogger eventLogger) throws Exception
+    public static Exchange<?> createExchange(final String hostName, final boolean durable, final EventLogger eventLogger)
     {
-        final QueueManagingVirtualHost virtualHost =  mockWithSystemPrincipal(QueueManagingVirtualHost.class, SYSTEM_PRINCIPAL);
+        final QueueManagingVirtualHost virtualHost =  mockWithSystemPrincipal(QueueManagingVirtualHost.class, PRINCIPAL);
         when(virtualHost.getName()).thenReturn(hostName);
         when(virtualHost.getEventLogger()).thenReturn(eventLogger);
         when(virtualHost.getDurableConfigurationStore()).thenReturn(mock(DurableConfigurationStore.class));
@@ -290,31 +274,22 @@ public class BrokerTestHelper
         when(virtualHost.getTaskExecutor()).thenReturn(TASK_EXECUTOR);
         when(virtualHost.getChildExecutor()).thenReturn(TASK_EXECUTOR);
         when(virtualHost.getCategoryClass()).thenReturn(VirtualHost.class);
-        final Map<String,Object> attributes = new HashMap<String, Object>();
-        attributes.put(org.apache.qpid.server.model.Exchange.ID, UUIDGenerator.generateExchangeUUID("amp.direct", virtualHost.getName()));
-        attributes.put(org.apache.qpid.server.model.Exchange.NAME, "amq.direct");
-        attributes.put(org.apache.qpid.server.model.Exchange.TYPE, "direct");
-        attributes.put(org.apache.qpid.server.model.Exchange.DURABLE, durable);
+        final Map<String,Object> attributes = Map.of(
+                Exchange.ID, UUIDGenerator.generateExchangeUUID("amp.direct", virtualHost.getName()),
+                Exchange.NAME, "amq.direct",
+                Exchange.TYPE, "direct",
+                Exchange.DURABLE, durable);
 
-        return Subject.doAs(SYSTEM_SUBJECT, new PrivilegedAction<Exchange<?>>()
-        {
-            @Override
-            public Exchange<?> run()
-            {
-
-                return (Exchange<?>) objectFactory.create(Exchange.class, attributes, virtualHost);
-            }
-        });
+        return Subject.doAs(SYSTEM_SUBJECT, (PrivilegedAction<Exchange<?>>) () ->
+                (Exchange<?>) objectFactory.create(Exchange.class, attributes, virtualHost));
 
     }
 
-    public static Queue<?> createQueue(String queueName, VirtualHost<?> virtualHost)
+    public static Queue<?> createQueue(final String queueName, final VirtualHost<?> virtualHost)
     {
-        Map<String,Object> attributes = new HashMap<String, Object>();
-        attributes.put(Queue.ID, UUIDGenerator.generateRandomUUID());
-        attributes.put(Queue.NAME, queueName);
-        Queue<?> queue = virtualHost.createChild(Queue.class, attributes);
-        return queue;
+        final Map<String,Object> attributes = Map.of(Queue.ID, UUIDGenerator.generateRandomUUID(),
+                Queue.NAME, queueName);
+        return virtualHost.createChild(Queue.class, attributes);
     }
 
     // The generated classes can't directly inherit from SystemPricipalSource / AccessControlSource as
@@ -323,29 +298,28 @@ public class BrokerTestHelper
     public interface TestableSystemPrincipalSource extends SystemPrincipalSource {}
     public interface TestableAccessControlSource extends AccessControlSource {}
 
-    public static <X extends ConfiguredObject> X mockWithSystemPrincipal(Class<X> clazz, Principal principal)
+    public static <X extends ConfiguredObject> X mockWithSystemPrincipal(final Class<X> clazz, final Principal principal)
     {
-        X mock = mock(clazz, withSettings().extraInterfaces(TestableSystemPrincipalSource.class));
+        final X mock = mock(clazz, withSettings().extraInterfaces(TestableSystemPrincipalSource.class));
         when(((SystemPrincipalSource)mock).getSystemPrincipal()).thenReturn(principal);
         return mock;
     }
 
-    public static <X extends ConfiguredObject> X mockWithSystemPrincipalAndAccessControl(Class<X> clazz,
-                                                                                         Principal principal,
-                                                                                         AccessControl accessControl)
+    public static <X extends ConfiguredObject> X mockWithSystemPrincipalAndAccessControl(final Class<X> clazz,
+                                                                                         final Principal principal,
+                                                                                         final AccessControl accessControl)
     {
-        X mock = mock(clazz,
-                      withSettings().extraInterfaces(TestableSystemPrincipalSource.class,
-                                                     TestableAccessControlSource.class));
+        final X mock = mock(clazz, withSettings().extraInterfaces(TestableSystemPrincipalSource.class,
+                TestableAccessControlSource.class));
         when(((SystemPrincipalSource) mock).getSystemPrincipal()).thenReturn(principal);
         when(((AccessControlSource) mock).getAccessControl()).thenReturn(accessControl);
 
         return mock;
     }
 
-    public static <X extends ConfiguredObject> X mockAsSystemPrincipalSource(Class<X> clazz)
+    public static <X extends ConfiguredObject> X mockAsSystemPrincipalSource(final Class<X> clazz)
     {
-        return mockWithSystemPrincipal(clazz, SYSTEM_PRINCIPAL);
+        return mockWithSystemPrincipal(clazz, PRINCIPAL);
     }
 
     @SuppressWarnings({"rawtypes", "unchecked"})
