@@ -21,9 +21,7 @@
 package org.apache.qpid.server.model.testmodels.hierarchy;
 
 import java.util.Map;
-
-import com.google.common.util.concurrent.Futures;
-import com.google.common.util.concurrent.ListenableFuture;
+import java.util.concurrent.CompletableFuture;
 
 import org.apache.qpid.server.model.AbstractConfiguredObject;
 import org.apache.qpid.server.model.State;
@@ -47,9 +45,9 @@ public class TestAbstractInstrumentPanelImpl<X extends TestAbstractInstrumentPan
 
     @StateTransition(currentState = {State.UNINITIALIZED, State.ERRORED}, desiredState = State.ACTIVE)
     @SuppressWarnings({"unused"})
-    private ListenableFuture<Void> onActivate()
+    private CompletableFuture<Void> onActivate()
     {
         setState(State.ACTIVE);
-        return Futures.immediateFuture(null);
+        return CompletableFuture.completedFuture(null);
     }
 }
