@@ -20,22 +20,20 @@
  */
 package org.apache.qpid.server.queue;
 
-import java.util.HashMap;
 import java.util.Map;
 
-import org.junit.Before;
+import org.junit.jupiter.api.BeforeEach;
 
 import org.apache.qpid.server.model.Queue;
+
 public class SortedQueueTest extends AbstractQueueTestBase
 {
-    @Before
+    @BeforeEach
     public void setUp() throws Exception
     {
-        Map<String,Object> arguments = new HashMap<>();
-        arguments.put(SortedQueue.SORT_KEY, "sortKey");
-        arguments.put(Queue.TYPE, SortedQueue.SORTED_QUEUE_TYPE);
+        final Map<String,Object> arguments = Map.of(SortedQueue.SORT_KEY, "sortKey",
+                Queue.TYPE, SortedQueue.SORTED_QUEUE_TYPE);
         setArguments(arguments);
-
         super.setUp();
     }
 }
