@@ -34,9 +34,6 @@ import jakarta.servlet.http.HttpServlet;
 import jakarta.servlet.http.HttpServletRequest;
 import jakarta.servlet.http.HttpServletResponse;
 
-import com.fasterxml.jackson.core.type.TypeReference;
-import com.fasterxml.jackson.databind.ObjectMapper;
-
 import org.eclipse.jetty.ee11.servlet.ServletContextHandler;
 import org.eclipse.jetty.server.HttpConfiguration;
 import org.eclipse.jetty.server.HttpConnectionFactory;
@@ -46,6 +43,10 @@ import org.eclipse.jetty.server.ServerConnector;
 import org.eclipse.jetty.util.resource.ResourceFactory;
 import org.eclipse.jetty.util.ssl.SslContextFactory;
 
+import tools.jackson.core.JacksonException;
+import tools.jackson.core.type.TypeReference;
+import tools.jackson.databind.ObjectMapper;
+
 import org.apache.qpid.server.configuration.CommonProperties;
 import org.apache.qpid.server.transport.network.security.ssl.SSLUtil;
 
@@ -178,7 +179,7 @@ class OAuth2MockEndpointHolder
             {
                 listOfStrings = new ObjectMapper().readValue(listAsString.getBytes(UTF_8), new TypeReference<>() { });
             }
-            catch (IOException e)
+            catch (JacksonException e)
             {
                 listOfStrings = Arrays.asList(listAsString.split("\\s*,\\s*"));
             }
