@@ -18,16 +18,17 @@
  */
 package org.apache.qpid.server.security.access.firewall;
 
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
 import java.net.InetAddress;
 import java.net.InetSocketAddress;
-import java.util.Collections;
+import java.util.Set;
 
-import com.google.common.collect.ImmutableSet;
 import org.apache.qpid.server.model.AuthenticationProvider;
 import org.apache.qpid.server.security.access.config.FirewallRule;
 import org.apache.qpid.server.security.access.config.LegacyOperation;
@@ -35,33 +36,32 @@ import org.apache.qpid.server.security.access.config.ObjectProperties;
 import org.apache.qpid.server.security.access.config.RulePredicate;
 import org.apache.qpid.server.security.auth.ManagementConnectionPrincipal;
 import org.apache.qpid.server.security.auth.UsernamePrincipal;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.test.utils.UnitTestBase;
 
 import javax.security.auth.Subject;
 
-public class NetworkFirewallRuleTest extends UnitTestBase
+class NetworkFirewallRuleTest extends UnitTestBase
 {
     private static final String LOCALHOST_IP = "127.0.0.1";
     private static final String OTHER_IP_1 = "192.168.23.1";
     private static final String OTHER_IP_2 = "192.168.23.2";
 
     private InetAddress _addressNotInRule;
-
     private NetworkFirewallRule _networkFirewallRule;
 
-    @Before
-    public void setUp() throws Exception
+    @BeforeEach
+    void setUp() throws Exception
     {
         _addressNotInRule = InetAddress.getByName(LOCALHOST_IP);
     }
 
     @Test
-    public void testIpRule() throws Exception
+    void ipRule() throws Exception
     {
-        String ipAddressInRule = OTHER_IP_1;
+        final String ipAddressInRule = OTHER_IP_1;
 
         _networkFirewallRule = new NetworkFirewallRule(ipAddressInRule);
 
@@ -70,9 +70,9 @@ public class NetworkFirewallRuleTest extends UnitTestBase
     }
 
     @Test
-    public void testNetMask() throws Exception
+    void netMask() throws Exception
     {
-        String ipAddressInRule = "192.168.23.0/24";
+        final String ipAddressInRule = "192.168.23.0/24";
         _networkFirewallRule = new NetworkFirewallRule(ipAddressInRule);
 
         assertFalse(_networkFirewallRule.matches(InetAddress.getByName("192.168.24.1")));
@@ -81,7 +81,7 @@ public class NetworkFirewallRuleTest extends UnitTestBase
     }
 
     @Test
-    public void testWildcard() throws Exception
+    void wildcard() throws Exception
     {
         // Test xxx.xxx.*
 
@@ -107,38 +107,38 @@ public class NetworkFirewallRuleTest extends UnitTestBase
     }
 
     @Test
-    public void testMultipleNetworks() throws Exception
+    void multipleNetworks() throws Exception
     {
-        String[] ipAddressesInRule = new String[] {OTHER_IP_1, OTHER_IP_2};
+        final String[] ipAddressesInRule = new String[] {OTHER_IP_1, OTHER_IP_2};
 
         _networkFirewallRule = new NetworkFirewallRule(ipAddressesInRule);
 
         assertFalse(_networkFirewallRule.matches(_addressNotInRule));
-        for (String ipAddressInRule : ipAddressesInRule)
+        for (final String ipAddressInRule : ipAddressesInRule)
         {
             assertTrue(_networkFirewallRule.matches(InetAddress.getByName(ipAddressInRule)));
         }
     }
 
     @Test
-    public void testEqualsAndHashCode()
+    void equalsAndHashCode()
     {
-        NetworkFirewallRule rule = new NetworkFirewallRule(LOCALHOST_IP, OTHER_IP_1);
-        NetworkFirewallRule equalRule = new NetworkFirewallRule(LOCALHOST_IP, OTHER_IP_1);
+        final NetworkFirewallRule rule = new NetworkFirewallRule(LOCALHOST_IP, OTHER_IP_1);
+        final NetworkFirewallRule equalRule = new NetworkFirewallRule(LOCALHOST_IP, OTHER_IP_1);
 
-        assertTrue(rule.equals(rule));
-        assertTrue(rule.equals(equalRule));
-        assertTrue(equalRule.equals(rule));
+        assertEquals(rule, rule);
+        assertEquals(rule, equalRule);
+        assertEquals(equalRule, rule);
 
-        assertTrue(rule.hashCode() == equalRule.hashCode());
+        assertEquals(rule.hashCode(), equalRule.hashCode());
 
-        assertFalse("Different networks should cause rules to be unequal",
-                           rule.equals(new NetworkFirewallRule(LOCALHOST_IP, OTHER_IP_2)));
+        assertNotEquals(rule, new NetworkFirewallRule(LOCALHOST_IP, OTHER_IP_2),
+                "Different networks should cause rules to be unequal");
 
     }
 
     @Test
-    public void testManagementConnectionPrincipals()
+    void managementConnectionPrincipals()
     {
         final ManagementConnectionPrincipal managementConnectionPrincipal = mock(ManagementConnectionPrincipal.class);
         when(managementConnectionPrincipal.getRemoteAddress())
@@ -159,11 +159,9 @@ public class NetworkFirewallRuleTest extends UnitTestBase
         assertTrue(RulePredicate.any().and(rule2).matches(LegacyOperation.ACCESS, new ObjectProperties(), subject));
 
         final Subject anotherSubject = new Subject(false,
-                ImmutableSet.of(
-                        new UsernamePrincipal("name", mock(AuthenticationProvider.class)), managementConnectionPrincipal
-                ),
-                Collections.emptySet(),
-                Collections.emptySet());
+                Set.of(new UsernamePrincipal("name", mock(AuthenticationProvider.class)), managementConnectionPrincipal),
+                Set.of(),
+                Set.of());
 
         assertTrue(rule1.and(RulePredicate.any()).matches(LegacyOperation.ACCESS, new ObjectProperties(), anotherSubject));
         assertTrue(RulePredicate.any().and(rule1).matches(LegacyOperation.ACCESS, new ObjectProperties(), anotherSubject));
@@ -175,11 +173,9 @@ public class NetworkFirewallRuleTest extends UnitTestBase
         assertFalse(RulePredicate.any().and(rule2).matches(LegacyOperation.ACCESS, new ObjectProperties(), anotherSubject));
 
         final Subject invalidSubject = new Subject(false,
-            ImmutableSet.of(
-                new UsernamePrincipal("name", mock(AuthenticationProvider.class)), invalidManagementConnectionPrincipal
-            ),
-            Collections.emptySet(),
-            Collections.emptySet());
+                Set.of(new UsernamePrincipal("name", mock(AuthenticationProvider.class)), invalidManagementConnectionPrincipal),
+                Set.of(),
+                Set.of());
 
         assertFalse(rule1.and(RulePredicate.any()).matches(LegacyOperation.ACCESS, new ObjectProperties(), invalidSubject));
         assertFalse(RulePredicate.any().and(rule1).matches(LegacyOperation.ACCESS, new ObjectProperties(), invalidSubject));
