@@ -18,7 +18,7 @@
  * under the License.
  *
  */
-package org.apache.qpid.server.protocol.v0_10;
+package org.apache.qpid.server.protocol.v0_8;
 
 import org.apache.qpid.server.transport.ProtocolEngine;
 import org.apache.qpid.server.model.Broker;
@@ -31,36 +31,36 @@ import org.apache.qpid.server.transport.ServerNetworkConnection;
 import org.apache.qpid.server.transport.AggregateTicker;
 
 @PluggableService
-public class ProtocolEngineCreator_0_10 implements ProtocolEngineCreator
+public class ProtocolEngineCreator_0_9_1 implements ProtocolEngineCreator
 {
-    private static final ProtocolEngineCreator INSTANCE = new ProtocolEngineCreator_0_10();
+    private static final ProtocolEngineCreator INSTANCE = new ProtocolEngineCreator_0_9_1();
 
-    private static final byte[] AMQP_0_10_HEADER =
+    private static final byte[] AMQP_0_9_1_HEADER =
             new byte[] { (byte) 'A',
                          (byte) 'M',
                          (byte) 'Q',
                          (byte) 'P',
-                         (byte) 1,
-                         (byte) 1,
                          (byte) 0,
-                         (byte) 10
+                         (byte) 0,
+                         (byte) 9,
+                         (byte) 1
             };
 
-    public ProtocolEngineCreator_0_10()
+    public ProtocolEngineCreator_0_9_1()
     {
     }
 
     @Override
     public Protocol getVersion()
     {
-        return Protocol.AMQP_0_10;
+        return Protocol.AMQP_0_9_1;
     }
 
 
     @Override
     public byte[] getHeaderIdentifier()
     {
-        return AMQP_0_10_HEADER;
+        return AMQP_0_9_1_HEADER;
     }
 
     @Override
@@ -70,11 +70,10 @@ public class ProtocolEngineCreator_0_10 implements ProtocolEngineCreator
                                             Transport transport,
                                             long id, final AggregateTicker aggregateTicker)
     {
-
-        final AMQPConnection_0_10Impl protocolEngine_0_10 =
-                new AMQPConnection_0_10Impl(broker, network, port, transport, id, aggregateTicker);
-        protocolEngine_0_10.create();
-        return protocolEngine_0_10;
+        final AMQPConnection_0_8Impl protocolEngine =
+                new AMQPConnection_0_8Impl(broker, network, port, transport, getVersion(), id, aggregateTicker);
+        protocolEngine.create();
+        return protocolEngine;
     }
 
     @Override
