@@ -20,157 +20,156 @@
  */
 package org.apache.qpid.server.protocol.v0_8;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
-import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.LinkedHashMap;
+import java.util.List;
 import java.util.Map;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.bytebuffer.QpidByteBuffer;
 import org.apache.qpid.test.utils.UnitTestBase;
 
-public class FieldTableTest extends UnitTestBase
+class FieldTableTest extends UnitTestBase
 {
-
     /**
      * Set a boolean and check that we can only get it back as a boolean and a string
-     * Check that attempting to lookup a non existent value returns null
+     * Check that attempting to look up a non-existent value returns null
      */
     @Test
-    public void testBoolean()
+    void testBoolean()
     {
-        FieldTable table1 = FieldTableFactory.createFieldTable(Collections.singletonMap("value", true));
+        final FieldTable table1 = FieldTableFactory.createFieldTable(Map.of("value", true));
         assertTrue(table1.containsKey("value"));
         assertEquals(true, table1.get("value"));
     }
 
     /**
      * Set a byte and check that we can only get it back as a byte and a string
-     * Check that attempting to lookup a non existent value returns null
+     * Check that attempting to look up a non-existent value returns null
      */
     @Test
-    public void testByte()
+    void testByte()
     {
-        FieldTable table1 = FieldTableFactory.createFieldTable(Collections.singletonMap("value", Byte.MAX_VALUE));
+        final FieldTable table1 = FieldTableFactory.createFieldTable(Map.of("value", Byte.MAX_VALUE));
         assertTrue(table1.containsKey("value"));
         assertEquals(Byte.MAX_VALUE, table1.get("value"));
     }
 
     /**
      * Set a short and check that we can only get it back as a short and a string
-     * Check that attempting to lookup a non existent value returns null
+     * Check that attempting to look up a non-existent value returns null
      */
     @Test
-    public void testShort()
+    void testShort()
     {
-        FieldTable table1 = FieldTableFactory.createFieldTable(Collections.singletonMap("value", Short.MAX_VALUE));
+        final FieldTable table1 = FieldTableFactory.createFieldTable(Map.of("value", Short.MAX_VALUE));
         assertTrue(table1.containsKey("value"));
         assertEquals(Short.MAX_VALUE, table1.get("value"));
     }
 
     /**
      * Set a char and check that we can only get it back as a char
-     * Check that attempting to lookup a non existent value returns null
+     * Check that attempting to look up a non-existent value returns null
      */
     @Test
-    public void testChar()
+    void testChar()
     {
-        FieldTable table1 = FieldTableFactory.createFieldTable(Collections.singletonMap("value", 'c'));
+        final FieldTable table1 = FieldTableFactory.createFieldTable(Map.of("value", 'c'));
         assertTrue(table1.containsKey("value"));
         assertEquals('c', table1.get("value"));
     }
 
     /**
      * Set a double and check that we can only get it back as a double
-     * Check that attempting to lookup a non existent value returns null
+     * Check that attempting to look up a non-existent value returns null
      */
     @Test
-    public void testDouble()
+    void testDouble()
     {
-        FieldTable table1 = FieldTableFactory.createFieldTable(Collections.singletonMap("value", Double.MAX_VALUE));
+        final FieldTable table1 = FieldTableFactory.createFieldTable(Map.of("value", Double.MAX_VALUE));
         assertTrue(table1.containsKey("value"));
         assertEquals(Double.MAX_VALUE, table1.get("value"));
     }
 
     /**
      * Set a float and check that we can only get it back as a float
-     * Check that attempting to lookup a non existent value returns null
+     * Check that attempting to look up a non-existent value returns null
      */
     @Test
-    public void testFloat()
+    void testFloat()
     {
-        FieldTable table1 = FieldTableFactory.createFieldTable(Collections.singletonMap("value", Float.MAX_VALUE));
+        final FieldTable table1 = FieldTableFactory.createFieldTable(Map.of("value", Float.MAX_VALUE));
         assertTrue(table1.containsKey("value"));
         assertEquals(Float.MAX_VALUE, table1.get("value"));
     }
 
     /**
      * Set an int and check that we can only get it back as an int
-     * Check that attempting to lookup a non existent value returns null
+     * Check that attempting to look up a non-existent value returns null
      */
     @Test
-    public void testInt()
+    void testInt()
     {
-        FieldTable table1 = FieldTableFactory.createFieldTable(Collections.singletonMap("value", Integer.MAX_VALUE));
+        final FieldTable table1 = FieldTableFactory.createFieldTable(Map.of("value", Integer.MAX_VALUE));
         assertTrue(table1.containsKey("value"));
         assertEquals(Integer.MAX_VALUE, table1.get("value"));
     }
 
     /**
      * Set a long and check that we can only get it back as a long
-     * Check that attempting to lookup a non existent value returns null
+     * Check that attempting to look up a non-existent value returns null
      */
     @Test
-    public void testLong()
+    void testLong()
     {
-        FieldTable table1 = FieldTableFactory.createFieldTable(Collections.singletonMap("value", Long.MAX_VALUE));
+        final FieldTable table1 = FieldTableFactory.createFieldTable(Map.of("value", Long.MAX_VALUE));
         assertTrue(table1.containsKey("value"));
         assertEquals(Long.MAX_VALUE, table1.get("value"));
     }
 
     /**
      * Set a double and check that we can only get it back as a double
-     * Check that attempting to lookup a non existent value returns null
+     * Check that attempting to look up a non-existent value returns null
      */
     @Test
-    public void testBytes()
+    void bytes()
     {
-        byte[] bytes = { 99, 98, 97, 96, 95 };
+        final byte[] bytes = { 99, 98, 97, 96, 95 };
 
-        FieldTable table1 = FieldTableFactory.createFieldTable(Collections.singletonMap("value", bytes));
+        final FieldTable table1 = FieldTableFactory.createFieldTable(Map.of("value", bytes));
         assertTrue(table1.containsKey("value"));
         assertBytesEqual(bytes, (byte[])table1.get("value"));
     }
 
     /**
      * Set a String and check that we can only get it back as a String
-     * Check that attempting to lookup a non existent value returns null
+     * Check that attempting to look up a non-existent value returns null
      */
     @Test
-    public void testString()
+    void string()
     {
-        FieldTable table1 = FieldTableFactory.createFieldTable(Collections.singletonMap("value", "Hello"));
+        final FieldTable table1 = FieldTableFactory.createFieldTable(Map.of("value", "Hello"));
         assertTrue(table1.containsKey("value"));
-
         assertEquals("Hello", table1.get("value"));
     }
 
     /** Check that a nested field table parameter correctly encodes and decodes to a byte buffer. */
     @Test
-    public void testNestedFieldTable() throws AMQFrameDecodingException
+    void nestedFieldTable()
     {
-        byte[] testBytes = new byte[] { 0, 1, 2, 3, 4, 5 };
+        final byte[] testBytes = new byte[] { 0, 1, 2, 3, 4, 5 };
 
-        Map<String, Object> innerTable = new LinkedHashMap<>();
+        final Map<String, Object> innerTable = new LinkedHashMap<>();
 
         // Put some stuff in the inner table.
         innerTable.put("bool", true);
@@ -184,24 +183,24 @@ public class FieldTableTest extends UnitTestBase
         innerTable.put("short", Short.MAX_VALUE);
         innerTable.put("string", "hello");
         innerTable.put("null-string", null);
-        innerTable.put("field-array",Arrays.asList("hello", 42, Collections.emptyList()));
+        innerTable.put("field-array", List.of("hello", 42, List.of()));
 
         // Put the inner table in the outer one.
-        FieldTable outerTable = FieldTableFactory.createFieldTable(Collections.singletonMap("innerTable",
-                                                                                         FieldTableFactory.createFieldTable(innerTable)));
+        final FieldTable outerTable = FieldTableFactory
+                .createFieldTable(Map.of("innerTable", FieldTableFactory.createFieldTable(innerTable)));
 
         // Write the outer table into the buffer.
-        QpidByteBuffer buf = QpidByteBuffer.allocate(EncodingUtils.encodedFieldTableLength(outerTable));
+        final QpidByteBuffer buf = QpidByteBuffer.allocate(EncodingUtils.encodedFieldTableLength(outerTable));
 
         outerTable.writeToBuffer(buf);
 
         buf.flip();
 
         // Extract the table back from the buffer again.
-        FieldTable extractedOuterTable = EncodingUtils.readFieldTable(buf);
-        assertNotNull("Unexpected outer table", extractedOuterTable);
+        final FieldTable extractedOuterTable = EncodingUtils.readFieldTable(buf);
+        assertNotNull(extractedOuterTable, "Unexpected outer table");
 
-        FieldTable extractedTable = (FieldTable)extractedOuterTable.get("innerTable");
+        final FieldTable extractedTable = (FieldTable)extractedOuterTable.get("innerTable");
 
         assertEquals(Boolean.TRUE, extractedTable.get("bool"));
         assertEquals(Byte.MAX_VALUE, extractedTable.get("byte"));
@@ -214,36 +213,32 @@ public class FieldTableTest extends UnitTestBase
         assertEquals(Short.MAX_VALUE, extractedTable.get("short"));
         assertEquals("hello", extractedTable.get("string"));
         assertNull(extractedTable.get("null-string"));
-        Collection fieldArray = (Collection) extractedTable.get("field-array");
+        Collection<?> fieldArray = (Collection<?>) extractedTable.get("field-array");
         assertEquals(3, fieldArray.size());
-        Iterator iter = fieldArray.iterator();
+        Iterator<?> iter = fieldArray.iterator();
         assertEquals("hello", iter.next());
         assertEquals(42, iter.next());
-        assertTrue(((Collection)iter.next()).isEmpty());
-    }
-
-    public void testUnsupportedObject()
-    {
-        try
-        {
-            FieldTableFactory.createFieldTable(Collections.singletonMap("value", new Exception()));
-            fail("Non primitive values are not allowed");
-        }
-        catch (AMQPInvalidClassException aice)
-        {
-            assertEquals("Non primitive values are not allowed to be set",
-                         AMQPInvalidClassException.INVALID_OBJECT_MSG + Exception.class,
-                         aice.getMessage());
-        }
+        assertTrue(((Collection<?>)iter.next()).isEmpty());
     }
 
     @Test
-    public void testValues() throws Exception
+    void unsupportedObject()
     {
-        Map<String, Object> map = new LinkedHashMap<>();
+        final Map<String, Object> map = Map.of("value", new Exception());
+        final AMQPInvalidClassException thrown = assertThrows(AMQPInvalidClassException.class,
+                () -> FieldTableFactory.createFieldTable(map),
+                "Non primitive values are not allowed");
+        assertEquals(AMQPInvalidClassException.INVALID_OBJECT_MSG + Exception.class, thrown.getMessage(),
+                "Non primitive values are not allowed to be set");
+    }
+
+    @Test
+    void values()
+    {
+        final Map<String, Object> map = new LinkedHashMap<>();
         map.put("bool", true);
         map.put("byte", Byte.MAX_VALUE);
-        byte[] bytes = { 99, 98, 97, 96, 95 };
+        final byte[] bytes = { 99, 98, 97, 96, 95 };
         map.put("bytes", bytes);
         map.put("char", 'c');
         map.put("double", Double.MAX_VALUE);
@@ -264,12 +259,12 @@ public class FieldTableTest extends UnitTestBase
         map.put("object-short", Short.MAX_VALUE);
         map.put("object-string", "Hello");
 
-        FieldTable mapTable = FieldTableFactory.createFieldTable(map);
-        QpidByteBuffer buf = QpidByteBuffer.allocate(EncodingUtils.encodedFieldTableLength(mapTable));
+        final FieldTable mapTable = FieldTableFactory.createFieldTable(map);
+        final QpidByteBuffer buf = QpidByteBuffer.allocate(EncodingUtils.encodedFieldTableLength(mapTable));
         mapTable.writeToBuffer(buf);
         buf.flip();
 
-        FieldTable table = EncodingUtils.readFieldTable(buf);
+        final FieldTable table = EncodingUtils.readFieldTable(buf);
         assertNotNull(table);
 
         assertEquals(Boolean.TRUE, table.get("bool"));
@@ -296,11 +291,11 @@ public class FieldTableTest extends UnitTestBase
     }
 
     @Test
-    public void testWriteBuffer()
+    void writeBuffer()
     {
-        byte[] bytes = { 99, 98, 97, 96, 95 };
+        final byte[] bytes = { 99, 98, 97, 96, 95 };
 
-        Map<String, Object> map = new LinkedHashMap<>();
+        final Map<String, Object> map = new LinkedHashMap<>();
         map.put("bool", true);
         map.put("byte", Byte.MAX_VALUE);
         map.put("bytes", bytes);
@@ -313,19 +308,18 @@ public class FieldTableTest extends UnitTestBase
         map.put("string", "hello");
         map.put("null-string", null);
 
-        FieldTable table = FieldTableFactory.createFieldTable(map);
+        final FieldTable table = FieldTableFactory.createFieldTable(map);
 
-        QpidByteBuffer buf = QpidByteBuffer.allocate((int) table.getEncodedSize() + 4);
+        final QpidByteBuffer buf = QpidByteBuffer.allocate((int) table.getEncodedSize() + 4);
         table.writeToBuffer(buf);
 
         buf.flip();
 
-        long length = buf.getInt() & 0xFFFFFFFFL;
-        QpidByteBuffer bufSlice = buf.slice();
+        final long length = buf.getInt() & 0xFFFFFFFFL;
+        final QpidByteBuffer bufSlice = buf.slice();
         bufSlice.limit((int)length);
 
-
-        FieldTable table2 = FieldTableFactory.createFieldTable(buf);
+        final FieldTable table2 = FieldTableFactory.createFieldTable(buf);
         assertNotNull(table2);
 
         assertEquals(true, table2.get("bool"));
@@ -346,9 +340,9 @@ public class FieldTableTest extends UnitTestBase
     }
 
     @Test
-    public void testEncodingSize()
+    void encodingSize()
     {
-        Map<String, Object> result = new LinkedHashMap<>();
+        final Map<String, Object> result = new LinkedHashMap<>();
         int size = 0;
 
         result.put("boolean", true);
@@ -417,136 +411,84 @@ public class FieldTableTest extends UnitTestBase
      * Additional test checkPropertyName doesn't accept Null
      */
     @Test
-    public void testCheckPropertyNameIsNull()
+    void checkPropertyNameIsNull()
     {
-        try
-        {
-            FieldTableFactory.createFieldTable(Collections.singletonMap(null, "String"));
-            fail("Null property name is not allowed");
-        }
-        catch (IllegalArgumentException iae)
-        {
-            // normal path
-        }
+        final Map<String, Object> map = Collections.singletonMap(null, "String");
+        assertThrows(IllegalArgumentException.class,
+                () -> FieldTableFactory.createFieldTable(map),
+                "Null property name is not allowed");
     }
 
     /**
      * Additional test checkPropertyName doesn't accept an empty String
      */
     @Test
-    public void testCheckPropertyNameIsEmptyString()
+    void checkPropertyNameIsEmptyString()
     {
-        try
-        {
-            FieldTableFactory.createFieldTable(Collections.singletonMap("", "String"));
-            fail("empty property name is not allowed");
-        }
-        catch (IllegalArgumentException iae)
-        {
-            // normal path
-        }
+        final Map<String, Object> map =Map.of("", "String");
+        assertThrows(IllegalArgumentException.class,
+                () -> FieldTableFactory.createFieldTable(map),
+                "Empty property name is not allowed");
+
     }
 
     /**
      * Additional test checkPropertyName doesn't accept an empty String
      */
     @Test
-    public void testCheckPropertyNameHasMaxLength()
+    void checkPropertyNameHasMaxLength()
     {
-        StringBuilder longPropertyName = new StringBuilder(129);
-
-        for (int i = 0; i < 129; i++)
-        {
-            longPropertyName.append("x");
-        }
-
-        boolean strictAMQP = FieldTable._strictAMQP;
-        try
-        {
-            FieldTable._strictAMQP = true;
-            new FieldTable(Collections.singletonMap(longPropertyName.toString(), "String"));
-            fail("property name must be < 128 characters");
-        }
-        catch (IllegalArgumentException iae)
-        {
-            // normal path
-        }
-        finally
-        {
-            FieldTable._strictAMQP = strictAMQP;
-        }
+        final boolean strictAMQP = FieldTable._strictAMQP;
+        final Map<String, Object> map = Map.of("x".repeat(129), "String");
+        FieldTable._strictAMQP = true;
+        assertThrows(IllegalArgumentException.class,
+                     () -> new FieldTable(map),
+                     "property name must be < 128 characters");
+        FieldTable._strictAMQP = strictAMQP;
     }
 
     /**
      * Additional test checkPropertyName starts with a letter
      */
     @Test
-    public void testCheckPropertyNameStartCharacterIsLetter()
+    void checkPropertyNameStartCharacterIsLetter()
     {
-        boolean strictAMQP = FieldTable._strictAMQP;
+        final boolean strictAMQP = FieldTable._strictAMQP;
 
         // Try a name that starts with a number
-        try
-        {
-            FieldTable._strictAMQP = true;
-            new FieldTable(Collections.singletonMap("1", "String"));
-            fail("property name must start with a letter");
-        }
-        catch (IllegalArgumentException iae)
-        {
-            // normal path
-        }
-        finally
-        {
-            FieldTable._strictAMQP = strictAMQP;
-        }
+        FieldTable._strictAMQP = true;
+        final Map<String, Object> map = Map.of("1", "String");
+        assertThrows(IllegalArgumentException.class,
+                     () -> new FieldTable(map),
+                     "property name must start with a letter");
+        FieldTable._strictAMQP = strictAMQP;
     }
 
     /**
      * Additional test checkPropertyName starts with a hash or a dollar
      */
     @Test
-    public void testCheckPropertyNameStartCharacterIsHashOrDollar()
+    void checkPropertyNameStartCharacterIsHashOrDollar()
     {
-        try
-        {
-            FieldTableFactory.createFieldTable(Collections.singletonMap("#", "String"));
-        }
-        catch (IllegalArgumentException iae)
-        {
-            fail("property name are allowed to start with # and $s");
-        }
-
-        try
-        {
-            FieldTableFactory.createFieldTable(Collections.singletonMap("$", "String"));
-        }
-        catch (IllegalArgumentException iae)
-        {
-            fail("property name are allowed to start with # and $s");
-        }
+        assertDoesNotThrow(() -> FieldTableFactory.createFieldTable(Map.of("#", "String")),
+                "Property names are allowed to start with # and $s");
+        
+        assertDoesNotThrow(() -> FieldTableFactory.createFieldTable(Map.of("$", "String")),
+                "Property names are allowed to start with # and $s");
     }
 
     @Test
-    public void testValidateMalformedFieldTable()
+    void validateMalformedFieldTable()
     {
         final FieldTable fieldTable = buildMalformedFieldTable();
 
-        try
-        {
-            fieldTable.validate();
-            fail("Exception is expected");
-        }
-        catch (RuntimeException e)
-        {
-            // pass
-        }
+        assertThrows(RuntimeException.class, fieldTable::validate, "Exception is expected");
     }
 
     @Test
-    public void testValidateCorrectFieldTable()
+    void validateCorrectFieldTable()
     {
-        final FieldTable ft = new FieldTable(Collections.singletonMap("testKey", "testValue"));
+        final FieldTable ft = new FieldTable(Map.of("testKey", "testValue"));
         final int encodedSize = (int)ft.getEncodedSize() + Integer.BYTES;
         final QpidByteBuffer buf = QpidByteBuffer.allocate(encodedSize);
         ft.writeToBuffer(buf);
@@ -556,7 +498,7 @@ public class FieldTableTest extends UnitTestBase
         final FieldTable fieldTable = new FieldTable(buf);
         assertEquals(1, fieldTable.size());
         fieldTable.validate();
-        assertTrue("Expected key is not found", fieldTable.containsKey("testKey"));
+        assertTrue(fieldTable.containsKey("testKey"), "Expected key is not found");
     }
 
     private FieldTable buildMalformedFieldTable()
@@ -578,10 +520,4 @@ public class FieldTableTest extends UnitTestBase
             assertEquals(expected[index], actual[index]);
         }
     }
-
-    public static junit.framework.Test suite()
-    {
-        return new junit.framework.TestSuite(FieldTableTest.class);
-    }
-
 }
