@@ -1,3 +1,4 @@
+
 /*
  *
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -18,12 +19,8 @@
  * under the License.
  *
  */
+package org.apache.qpid.server.protocol.v0_8;
 
-package org.apache.qpid.server.protocol.v0_10;
-
-import static java.nio.charset.StandardCharsets.UTF_8;
-
-import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNull;
@@ -39,18 +36,13 @@ import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
-import java.io.ByteArrayOutputStream;
-import java.io.IOException;
-import java.io.ObjectOutputStream;
-import java.math.BigDecimal;
 import java.util.HashMap;
 import java.util.Map;
-import java.util.UUID;
 
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
-import org.apache.qpid.server.bytebuffer.QpidByteBuffer;
+import org.apache.qpid.server.exchange.ExchangeDefaults;
 import org.apache.qpid.server.message.AMQMessageHeader;
 import org.apache.qpid.server.message.internal.InternalMessage;
 import org.apache.qpid.server.message.internal.InternalMessageHeader;
@@ -60,36 +52,34 @@ import org.apache.qpid.server.model.Exchange;
 import org.apache.qpid.server.model.NamedAddressSpace;
 import org.apache.qpid.server.model.Queue;
 import org.apache.qpid.server.protocol.converter.MessageConversionException;
-import org.apache.qpid.server.protocol.v0_10.transport.DeliveryProperties;
-import org.apache.qpid.server.protocol.v0_10.transport.MessageDeliveryMode;
-import org.apache.qpid.server.protocol.v0_10.transport.ReplyTo;
+import org.apache.qpid.server.protocol.v0_8.transport.BasicContentHeaderProperties;
+import org.apache.qpid.server.protocol.v0_8.transport.MessagePublishInfo;
 import org.apache.qpid.server.store.StoredMessage;
 import org.apache.qpid.test.utils.UnitTestBase;
 
-class PropertyConverter_Internal_to_v0_10Test extends UnitTestBase
+class PropertyConverter_Internal_to_v0_8Test extends UnitTestBase
 {
-    private static final int AMQP_0_8_SHORT_STRING_MAX_LENGTH = 255;
-
-    private MessageConverter_Internal_to_v0_10 _messageConverter;
+    private MessageConverter_Internal_to_v0_8 _messageConverter;
     private NamedAddressSpace _addressSpace;
 
     @BeforeEach
-    void setUp()
+    void setUp() throws Exception
     {
+        _messageConverter = new MessageConverter_Internal_to_v0_8();
         _addressSpace = mock(NamedAddressSpace.class);
         when(_addressSpace.getLocalAddress(anyString())).then(returnsFirstArg());
-        _messageConverter = new MessageConverter_Internal_to_v0_10();
     }
 
     @Test
-    void persistentTrueConversion() throws IOException
+    void durableTrueConversion()
     {
         final AMQMessageHeader header = mock(AMQMessageHeader.class);
-        final InternalMessage originalMessage = createTestMessage(header, null, true, System.currentTimeMillis());
+        final InternalMessage originalMessage = createTestMessage(header, null, true);
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
 
-        assertEquals(MessageDeliveryMode.PERSISTENT, convertedMessage.getHeader().getDeliveryProperties().getDeliveryMode(),
+        assertEquals(BasicContentHeaderProperties.PERSISTENT,
+                (long) convertedMessage.getContentHeaderBody().getProperties().getDeliveryMode(),
                 "Unexpected delivery mode");
 
         assertTrue(convertedMessage.isPersistent(), "Unexpected persistence of message");
@@ -98,69 +88,67 @@ class PropertyConverter_Internal_to_v0_10Test extends UnitTestBase
     }
 
     @Test
-    void persistentFalseConversion() throws IOException
+    void durableFalseConversion()
     {
         final AMQMessageHeader header = mock(AMQMessageHeader.class);
-        final InternalMessage originalMessage = createTestMessage(header, null, false, System.currentTimeMillis());
+        final InternalMessage originalMessage = createTestMessage(header, null, false);
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
 
-        assertEquals(MessageDeliveryMode.NON_PERSISTENT, convertedMessage.getHeader().getDeliveryProperties().getDeliveryMode(),
+        assertEquals(BasicContentHeaderProperties.NON_PERSISTENT,
+                (long) convertedMessage.getContentHeaderBody().getProperties().getDeliveryMode(),
                 "Unexpected delivery mode");
         assertFalse(convertedMessage.isPersistent(), "Unexpected persistence of message");
         assertFalse(convertedMessage.getStoredMessage().getMetaData().isPersistent(),
-                "Unexpected persistence of meta data");
+                               "Unexpected persistence of meta data");
     }
 
     @Test
-    void priorityConversion() throws IOException
+    void priorityConversion()
     {
         final AMQMessageHeader header = mock(AMQMessageHeader.class);
         final byte priority = (byte) 7;
         when(header.getPriority()).thenReturn(priority);
         final InternalMessage originalMessage = createTestMessage(header);
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
 
-        assertEquals(priority, (long) convertedMessage.getHeader().getDeliveryProperties().getPriority().getValue(),
+        assertEquals(priority, (long) convertedMessage.getContentHeaderBody().getProperties().getPriority(),
                 "Unexpected priority");
-
     }
 
     @Test
-    void expirationConversion() throws IOException
+    void expirationConversion()
     {
         final long ttl = 10000;
-        final long arrivalTime = System.currentTimeMillis();
-        final long expiryTime = arrivalTime + ttl;
+        final long expiryTime = System.currentTimeMillis() + ttl;
         final AMQMessageHeader header = mock(AMQMessageHeader.class);
         when(header.getExpiration()).thenReturn(expiryTime);
-        final InternalMessage originalMessage = createTestMessage(header, arrivalTime);
+        final InternalMessage originalMessage = createTestMessage(header);
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
 
-        assertEquals(expiryTime, convertedMessage.getHeader().getDeliveryProperties().getExpiration(),
+        assertEquals(expiryTime, convertedMessage.getContentHeaderBody().getProperties().getExpiration(),
                 "Unexpected expiration time");
-
-        assertEquals(ttl, convertedMessage.getHeader().getDeliveryProperties().getTtl(), "Unexpected TTL");
     }
 
     @Test
-    void contentEncodingConversion() throws IOException
+    void contentEncodingConversion()
     {
         final String contentEncoding = "my-test-encoding";
         final AMQMessageHeader header = mock(AMQMessageHeader.class);
         when(header.getEncoding()).thenReturn(contentEncoding);
         final InternalMessage originalMessage = createTestMessage(header);
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
 
-        assertEquals(contentEncoding, convertedMessage.getHeader().getMessageProperties().getContentEncoding(),
+        assertEquals(contentEncoding, convertedMessage.getContentHeaderBody().getProperties().getEncodingAsString(),
                 "Unexpected content encoding");
+
     }
 
     @Test
-    void longContentEncodingConversion() throws IOException
+    void longContentEncodingConversion()
     {
         final String contentEncoding = generateLongString();
         final AMQMessageHeader header = mock(AMQMessageHeader.class);
@@ -173,51 +161,36 @@ class PropertyConverter_Internal_to_v0_10Test extends UnitTestBase
     }
 
     @Test
-    void messageIdUUIDConversion() throws IOException
-    {
-        final UUID messageId = UUID.randomUUID();
-        final String messageIdAsString = messageId.toString();
-        final AMQMessageHeader header = mock(AMQMessageHeader.class);
-        when(header.getMessageId()).thenReturn("ID:" + messageIdAsString);
-        final InternalMessage originalMessage = createTestMessage(header);
-
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
-
-        assertEquals(messageId, convertedMessage.getHeader().getMessageProperties().getMessageId(),
-                "Unexpected messageId");
-    }
-
-    @Test
-    void messageIdStringConversion() throws IOException
+    void messageIdConversion()
     {
         final String messageId = "testMessageId";
         final AMQMessageHeader header = mock(AMQMessageHeader.class);
         when(header.getMessageId()).thenReturn(messageId);
         final InternalMessage originalMessage = createTestMessage(header);
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
 
-        assertNull(convertedMessage.getHeader().getMessageProperties().getMessageId(), "Unexpected messageId");
+        assertEquals(messageId, convertedMessage.getContentHeaderBody().getProperties().getMessageIdAsString(),
+                "Unexpected messageId");
     }
 
     @Test
-    void correlationIdConversion() throws IOException
+    void messageIdConversionWhenLengthExceeds255()
     {
-        final String correlationId = "testCorrelationId";
+        final String messageId = generateLongString();
         final AMQMessageHeader header = mock(AMQMessageHeader.class);
-        when(header.getCorrelationId()).thenReturn(correlationId);
+        when(header.getMessageId()).thenReturn(messageId);
         final InternalMessage originalMessage = createTestMessage(header);
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
 
-        assertArrayEquals(correlationId.getBytes(UTF_8),
-                convertedMessage.getHeader().getMessageProperties().getCorrelationId(), "Unexpected correlationId");
+        assertNull(convertedMessage.getContentHeaderBody().getProperties().getMessageId(), "Unexpected messageId");
     }
 
     @Test
-    void correlationIdConversionWhenLengthExceeds16Bits() throws IOException
+    void correlationIdConversionWhenLengthExceeds255()
     {
-        final String correlationId = generateLongLongString();
+        final String correlationId = generateLongString();
         final AMQMessageHeader header = mock(AMQMessageHeader.class);
         when(header.getCorrelationId()).thenReturn(correlationId);
         final InternalMessage originalMessage = createTestMessage(header);
@@ -228,61 +201,48 @@ class PropertyConverter_Internal_to_v0_10Test extends UnitTestBase
     }
 
     @Test
-    void userIdConversion() throws IOException
+    void userIdConversion()
     {
         final String userId = "testUserId";
         final AMQMessageHeader header = mock(AMQMessageHeader.class);
         when(header.getUserId()).thenReturn(userId);
         final InternalMessage originalMessage = createTestMessage(header);
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
 
-        assertArrayEquals(userId.getBytes(UTF_8), convertedMessage.getHeader().getMessageProperties().getUserId(),
+        assertEquals(userId, convertedMessage.getContentHeaderBody().getProperties().getUserIdAsString(),
                 "Unexpected userId");
     }
 
     @Test
-    void userIdConversionWhenLengthExceeds16Bits() throws IOException
+    void userIdConversionWhenLengthExceeds255()
     {
-        final String userId = generateLongLongString();
+        final String userId = generateLongString();
         final AMQMessageHeader header = mock(AMQMessageHeader.class);
         when(header.getUserId()).thenReturn(userId);
         final InternalMessage originalMessage = createTestMessage(header);
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
 
-        assertNull(convertedMessage.getHeader().getMessageProperties().getUserId(), "Unexpected userId");
+        assertNull(convertedMessage.getContentHeaderBody().getProperties().getUserId(), "Unexpected userId");
     }
 
     @Test
-    void timestampConversion() throws IOException
+    void timestampConversion()
     {
         final long timestamp = System.currentTimeMillis();
         final AMQMessageHeader header = mock(AMQMessageHeader.class);
         when(header.getTimestamp()).thenReturn(timestamp);
         final InternalMessage originalMessage = createTestMessage(header);
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
 
-        assertEquals(timestamp, convertedMessage.getHeader().getDeliveryProperties().getTimestamp(),
+        assertEquals(timestamp, convertedMessage.getContentHeaderBody().getProperties().getTimestamp(),
                 "Unexpected timestamp");
     }
 
     @Test
-    void arrivalTimeConversion() throws IOException
-    {
-        final long timestamp = System.currentTimeMillis();
-
-        final InternalMessage originalMessage = createTestMessage(mock(AMQMessageHeader.class), timestamp);
-
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
-
-        assertEquals(timestamp, convertedMessage.getHeader().getDeliveryProperties().getTimestamp(),
-                "Unexpected timestamp");
-    }
-
-    @Test
-    void headersConversion() throws IOException
+    void headersConversion()
     {
         final Map<String, Object> properties = Map.of("testProperty1", "testProperty1Value",
                 "intProperty", 1);
@@ -295,33 +255,14 @@ class PropertyConverter_Internal_to_v0_10Test extends UnitTestBase
         }).when(header).getHeader(any(String.class));
         final InternalMessage originalMessage = createTestMessage(header);
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
 
-        final Map<String, Object> convertedHeaders =
-                convertedMessage.getHeader().getMessageProperties().getApplicationHeaders();
+        final Map<String, Object> convertedHeaders = convertedMessage.getContentHeaderBody().getProperties().getHeadersAsMap();
         assertEquals(properties, new HashMap<>(convertedHeaders), "Unexpected application properties");
     }
 
     @Test
-    void headersConversionWithUnsupportedTypes() throws IOException
-    {
-        final Map<String, Object> properties = Map.of("bigDecimalProperty", new BigDecimal(1));
-        final AMQMessageHeader header = mock(AMQMessageHeader.class);
-        when(header.getHeaderNames()).thenReturn(properties.keySet());
-        doAnswer(invocation ->
-        {
-            final String originalArgument = (String) (invocation.getArguments())[0];
-            return properties.get(originalArgument);
-        }).when(header).getHeader(any(String.class));
-        final InternalMessage originalMessage = createTestMessage(header);
-
-        assertThrows(MessageConversionException.class,
-                () -> _messageConverter.convert(originalMessage, _addressSpace),
-                "Expected exception not thrown");
-    }
-
-    @Test
-    void headersConversionWhenKeyLengthExceeds255() throws IOException
+    void headersConversionWhenKeyLengthExceeds255()
     {
         final Map<String, Object> properties = Map.of(generateLongString(), "test");
         final AMQMessageHeader header = mock(AMQMessageHeader.class);
@@ -339,95 +280,88 @@ class PropertyConverter_Internal_to_v0_10Test extends UnitTestBase
     }
 
     @Test
-    void contentLengthConversion() throws IOException
-    {
-        final byte[] content = {(byte) 1, (byte) 2};
-
-        final InternalMessage originalMessage = createTestMessage(mock(AMQMessageHeader.class), content, false, 0);
-
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
-
-        assertEquals(content.length, convertedMessage.getHeader().getMessageProperties().getContentLength(),
-                "Unexpected timestamp");
-    }
-
-    @Test
-    void replyToConversionWhenQueueIsSpecified() throws IOException
+    void replyToConversionWhenQueueIsSpecified()
     {
+        final String replyTo = "testQueue";
         final AMQMessageHeader header = mock(AMQMessageHeader.class);
-        final String replyTo = "myTestQueue";
+        when(header.getReplyTo()).thenReturn(replyTo);
         final Queue<?> queue = mock(Queue.class);
         when(queue.getName()).thenReturn(replyTo);
-        doReturn(queue).when(_addressSpace).getAttainedMessageDestination(eq(replyTo),anyBoolean());
-        when(header.getReplyTo()).thenReturn(replyTo);
+        doReturn(queue).when(_addressSpace).getAttainedMessageDestination(eq(replyTo), anyBoolean());
+
         final InternalMessage originalMessage = createTestMessage(header);
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
 
-        final ReplyTo convertedReplyTo =
-                convertedMessage.getHeader().getMessageProperties().getReplyTo();
-        assertEquals("", convertedReplyTo.getExchange(), "Unexpected exchange");
-        assertEquals(replyTo, convertedReplyTo.getRoutingKey(), "Unexpected routing key");
+        assertEquals("direct:////" + replyTo,
+                convertedMessage.getContentHeaderBody().getProperties().getReplyToAsString(),
+                "Unexpected reply-to");
     }
 
     @Test
-    void replyToConversionWhenExchangeIsSpecified() throws IOException
+    void replyToConversionWhenExchangeIsSpecified()
     {
+        final String replyTo = "testExchange";
         final AMQMessageHeader header = mock(AMQMessageHeader.class);
-        final String replyTo = "myTestExchange";
+        when(header.getReplyTo()).thenReturn(replyTo);
         final Exchange<?> exchange = mock(Exchange.class);
         when(exchange.getName()).thenReturn(replyTo);
-        doReturn(exchange).when(_addressSpace).getAttainedMessageDestination(eq(replyTo),anyBoolean());
-        when(header.getReplyTo()).thenReturn(replyTo);
+        when(exchange.getType()).thenReturn(ExchangeDefaults.FANOUT_EXCHANGE_CLASS);
+
+        doReturn(exchange).when(_addressSpace).getAttainedMessageDestination(eq(replyTo), anyBoolean());
+
         final InternalMessage originalMessage = createTestMessage(header);
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
 
-        final ReplyTo convertedReplyTo =
-                convertedMessage.getHeader().getMessageProperties().getReplyTo();
-        assertEquals(replyTo, convertedReplyTo.getExchange(), "Unexpected exchange");
-        assertEquals("", convertedReplyTo.getRoutingKey(), "Unexpected routing key");
+        assertEquals("fanout://" + replyTo + "//",
+                convertedMessage.getContentHeaderBody().getProperties().getReplyToAsString(),
+                "Unexpected reply-to");
     }
 
     @Test
-    void replyToConversionWhenExchangeAndRoutingKeyAreSpecified() throws IOException
+    void replyToConversionWhenExchangeAndRoutingKeyAreSpecified()
     {
-        final AMQMessageHeader header = mock(AMQMessageHeader.class);
-        final String exchangeName = "testExchangeName";
-        final String routingKey = "testRoutingKey";
+        final String exchangeName = "testExchange";
+        final String routingKey = "testKey";
         final String replyTo = String.format("%s/%s", exchangeName, routingKey);
+        final AMQMessageHeader header = mock(AMQMessageHeader.class);
+        when(header.getReplyTo()).thenReturn(replyTo);
         final Exchange<?> exchange = mock(Exchange.class);
         when(exchange.getName()).thenReturn(exchangeName);
-        doReturn(exchange).when(_addressSpace).getAttainedMessageDestination(eq(exchangeName),anyBoolean());
-        when(header.getReplyTo()).thenReturn(replyTo);
+        when(exchange.getType()).thenReturn(ExchangeDefaults.TOPIC_EXCHANGE_CLASS);
+
+        doReturn(exchange).when(_addressSpace).getAttainedMessageDestination(eq(exchangeName), anyBoolean());
+
         final InternalMessage originalMessage = createTestMessage(header);
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
 
-        final ReplyTo convertedReplyTo =
-                convertedMessage.getHeader().getMessageProperties().getReplyTo();
-        assertEquals(exchangeName, convertedReplyTo.getExchange(), "Unexpected exchange");
-        assertEquals(routingKey, convertedReplyTo.getRoutingKey(), "Unexpected routing key");
+        assertEquals("topic://" + exchangeName + "//?routingkey='" + routingKey + "'",
+                convertedMessage.getContentHeaderBody().getProperties().getReplyToAsString(),
+                "Unexpected reply-to");
     }
 
     @Test
-    void replyToConversionWhenReplyToCannotBeResolved() throws IOException
+    void replyToConversionWhenNonExistingExchangeAndRoutingKeyAreSpecified()
     {
+        final String exchangeName = "testExchange";
+        final String routingKey = "testKey";
+        final String replyTo = String.format("%s/%s", exchangeName, routingKey);
         final AMQMessageHeader header = mock(AMQMessageHeader.class);
-        final String replyTo = "direct://amq.direct//test?routingkey='test'";
         when(header.getReplyTo()).thenReturn(replyTo);
+
         final InternalMessage originalMessage = createTestMessage(header);
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(originalMessage, _addressSpace);
 
-        final ReplyTo convertedReplyTo =
-                convertedMessage.getHeader().getMessageProperties().getReplyTo();
-        assertEquals("", convertedReplyTo.getExchange(), "Unexpected exchange");
-        assertEquals(replyTo, convertedReplyTo.getRoutingKey(), "Unexpected routing key");
+        assertEquals("direct:////?routingkey='" + replyTo + "'",
+                convertedMessage.getContentHeaderBody().getProperties().getReplyToAsString(),
+                "Unexpected reply-to");
     }
 
     @Test
-    void toConversionWhenExchangeAndRoutingKeyIsSpecified() throws IOException
+    void toConversionWhenExchangeAndRoutingKeyIsSpecified()
     {
         final String testExchange = "testExchange";
         final String testRoutingKey = "testRoutingKey";
@@ -440,58 +374,79 @@ class PropertyConverter_Internal_to_v0_10Test extends UnitTestBase
         when(exchange.getName()).thenReturn(testExchange);
         doReturn(exchange).when(_addressSpace).getAttainedMessageDestination(eq(testExchange), anyBoolean());
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(message, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(message, _addressSpace);
 
-        final DeliveryProperties deliveryProperties =
-                convertedMessage.getStoredMessage().getMetaData().getDeliveryProperties();
-        assertEquals(testExchange, deliveryProperties.getExchange(), "Unexpected exchange");
-        assertEquals(testRoutingKey, deliveryProperties.getRoutingKey(), "Unexpected routing key");
+        final MessagePublishInfo messagePublishInfo = convertedMessage.getMessagePublishInfo();
+
+        assertEquals(testExchange, messagePublishInfo.getExchange().toString(), "Unexpected exchange");
+        assertEquals(testRoutingKey, messagePublishInfo.getRoutingKey().toString(),
+                "Unexpected routing key");
     }
 
     @Test
-    void toConversionWhenExchangeIsSpecified() throws IOException
+    void toConversionWhenExchangeIsSpecified()
     {
         final String testExchange = "testExchange";
-
         final InternalMessage message = createTestMessage(testExchange);
 
         final Exchange<?> exchange = mock(Exchange.class);
         when(exchange.getName()).thenReturn(testExchange);
         doReturn(exchange).when(_addressSpace).getAttainedMessageDestination(eq(testExchange), anyBoolean());
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(message, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(message, _addressSpace);
 
-        final DeliveryProperties deliveryProperties =
-                convertedMessage.getStoredMessage().getMetaData().getDeliveryProperties();
-        assertEquals(testExchange, deliveryProperties.getExchange(), "Unexpected exchange");
-        assertEquals("", deliveryProperties.getRoutingKey(), "Unexpected routing key");
+        final MessagePublishInfo messagePublishInfo = convertedMessage.getMessagePublishInfo();
+
+        assertEquals(testExchange, messagePublishInfo.getExchange().toString(), "Unexpected exchange");
+        assertEquals("", messagePublishInfo.getRoutingKey().toString(), "Unexpected routing key");
     }
 
     @Test
-    void toConversionWhenQueueIsSpecified() throws IOException
+    void conversionWhenToIsUnsetButInitialRoutingKeyIsSet()
+    {
+        final String testExchange = "testExchange";
+        final String testRoutingKey = "testRoutingKey";
+
+        final InternalMessage message = createTestMessage("");
+        final String testInitialRoutingAddress = testExchange + "/" + testRoutingKey;
+        message.setInitialRoutingAddress(testInitialRoutingAddress);
+
+        final Exchange<?> exchange = mock(Exchange.class);
+        when(exchange.getName()).thenReturn(testExchange);
+        doReturn(exchange).when(_addressSpace).getAttainedMessageDestination(eq(testExchange), anyBoolean());
+
+        final AMQMessage convertedMessage = _messageConverter.convert(message, _addressSpace);
+
+        final MessagePublishInfo messagePublishInfo = convertedMessage.getMessagePublishInfo();
+
+        assertEquals(testExchange, messagePublishInfo.getExchange().toString(), "Unexpected exchange");
+        assertEquals(testRoutingKey, messagePublishInfo.getRoutingKey().toString(), "Unexpected routing key");
+    }
+
+    @Test
+    void toConversionWhenQueueIsSpecified()
     {
         final String testQueue = "testQueue";
-
         final InternalMessage message = createTestMessage(testQueue);
 
         final Queue<?> queue = mock(Queue.class);
         when(queue.getName()).thenReturn(testQueue);
         doReturn(queue).when(_addressSpace).getAttainedMessageDestination(eq(testQueue), anyBoolean());
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(message, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(message, _addressSpace);
 
-        final DeliveryProperties deliveryProperties =
-                convertedMessage.getStoredMessage().getMetaData().getDeliveryProperties();
-        assertEquals("", deliveryProperties.getExchange(), "Unexpected exchange");
-        assertEquals(testQueue, deliveryProperties.getRoutingKey(), "Unexpected routing key");
+        final MessagePublishInfo messagePublishInfo = convertedMessage.getMessagePublishInfo();
+
+        assertEquals("", messagePublishInfo.getExchange().toString(), "Unexpected exchange");
+        assertEquals(testQueue, messagePublishInfo.getRoutingKey().toString(), "Unexpected routing key");
     }
 
     @Test
-    void toConversionWhenGlobalAddressIsUnknown() throws IOException
+    void toConversionWhenGlobalAddressIsUnknown()
     {
+        final String globalPrefix = "/testPrefix";
         final String queueName = "testQueue";
-        final String prefix = "/testPrefix";
-        final String globalAddress = prefix + "/" + queueName;
+        final String globalAddress = globalPrefix + "/" + queueName;
 
         final InternalMessage message = createTestMessage(globalAddress);
 
@@ -499,37 +454,38 @@ class PropertyConverter_Internal_to_v0_10Test extends UnitTestBase
         when(queue.getName()).thenReturn(queueName);
         doReturn(queue).when(_addressSpace).getAttainedMessageDestination(eq(queueName), anyBoolean());
 
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(message, _addressSpace);
+        final AMQMessage convertedMessage = _messageConverter.convert(message, _addressSpace);
 
-        final DeliveryProperties deliveryProperties =
-                convertedMessage.getStoredMessage().getMetaData().getDeliveryProperties();
-        assertEquals("", deliveryProperties.getExchange(), "Unexpected exchange");
-        assertEquals(globalAddress, deliveryProperties.getRoutingKey(), "Unexpected routing key");
+        final MessagePublishInfo messagePublishInfo = convertedMessage.getMessagePublishInfo();
+
+        assertEquals("", messagePublishInfo.getExchange().toString(), "Unexpected exchange");
+        assertEquals(globalAddress, messagePublishInfo.getRoutingKey().toString(), "Unexpected routing key");
     }
 
     @Test
-    void toConversionWhenGlobalAddressIsKnown() throws IOException
+    void toConversionWhenGlobalAddressIsKnown()
     {
+        final String globalPrefix = "/testPrefix";
         final String queueName = "testQueue";
-        final String prefix = "/testPrefix";
-        final String globalAddress = prefix + "/" + queueName;
+        final String globalAddress = globalPrefix + "/" + queueName;
 
         final InternalMessage message = createTestMessage(globalAddress);
 
         final Queue<?> queue = mock(Queue.class);
         when(queue.getName()).thenReturn(queueName);
+        doReturn(queue).when(_addressSpace).getAttainedMessageDestination(eq(queueName), anyBoolean());
         when(_addressSpace.getLocalAddress(globalAddress)).thenReturn(queueName);
-        doReturn(queue).when(_addressSpace).getAttainedMessageDestination(eq(queueName), anyBoolean());
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(message, _addressSpace);
 
-        final DeliveryProperties deliveryProperties =
-                convertedMessage.getStoredMessage().getMetaData().getDeliveryProperties();
-        assertEquals("", deliveryProperties.getExchange(), "Unexpected exchange");
-        assertEquals(queueName, deliveryProperties.getRoutingKey(), "Unexpected routing key");
+        final AMQMessage convertedMessage = _messageConverter.convert(message, _addressSpace);
+
+        final MessagePublishInfo messagePublishInfo = convertedMessage.getMessagePublishInfo();
+
+        assertEquals("", messagePublishInfo.getExchange().toString(), "Unexpected exchange");
+        assertEquals(queueName, messagePublishInfo.getRoutingKey().toString(), "Unexpected routing key");
     }
 
     @Test
-    void toConversionWhenExchangeLengthExceeds255() throws IOException
+    void toConversionWhenExchangeLengthExceeds255()
     {
         final String testExchange = generateLongString();
         final String testRoutingKey = "testRoutingKey";
@@ -544,11 +500,13 @@ class PropertyConverter_Internal_to_v0_10Test extends UnitTestBase
     }
 
     @Test
-    void toConversionWhenRoutingKeyLengthExceeds255() throws Exception
+    void toConversionWhenRoutingKeyLengthExceeds255()
     {
         final String testExchange = "testExchange";
         final String testRoutingKey = generateLongString();
+
         final String to = testExchange + "/" + testRoutingKey;
+
         final InternalMessage message = createTestMessage(to);
 
         assertThrows(MessageConversionException.class,
@@ -557,87 +515,64 @@ class PropertyConverter_Internal_to_v0_10Test extends UnitTestBase
     }
 
     @Test
-    void toConversionWhenDestinationIsSpecifiedButDoesNotExists() throws IOException
+    void toConversionWhenDestinationIsSpecifiedButDoesNotExists()
     {
         final String testDestination = "testDestination";
+
         final InternalMessage message = createTestMessage(testDestination);
-        final MessageTransferMessage convertedMessage = _messageConverter.convert(message, _addressSpace);
-        final DeliveryProperties deliveryProperties =
-                convertedMessage.getStoredMessage().getMetaData().getDeliveryProperties();
-        assertEquals("", deliveryProperties.getExchange(), "Unexpected exchange");
-        assertEquals(testDestination, deliveryProperties.getRoutingKey(), "Unexpected routing key");
+
+        final AMQMessage convertedMessage = _messageConverter.convert(message, _addressSpace);
+
+        final MessagePublishInfo messagePublishInfo = convertedMessage.getMessagePublishInfo();
+
+        assertEquals("", messagePublishInfo.getExchange().toString(), "Unexpected exchange");
+        assertEquals(testDestination, messagePublishInfo.getRoutingKey().toString(), "Unexpected routing key");
     }
 
-    private InternalMessage createTestMessage(String to) throws IOException
+    private InternalMessage createTestMessage(final AMQMessageHeader header)
     {
-        final InternalMessageHeader internalMessageHeader = new InternalMessageHeader(mock(AMQMessageHeader.class));
-        final StoredMessage<InternalMessageMetaData> handle =
-                createInternalStoredMessage(null,false, internalMessageHeader);
-        return new InternalMessage(handle, internalMessageHeader, null, to);
-    }
-
-    private InternalMessage createTestMessage(final AMQMessageHeader header) throws IOException
-    {
-        return createTestMessage(header, null, false, System.currentTimeMillis());
-    }
-
-    private InternalMessage createTestMessage(final AMQMessageHeader header, final long arrivalTime) throws IOException
-    {
-        return createTestMessage(header, null, false, arrivalTime);
+        return createTestMessage(header, null, false);
     }
 
     private InternalMessage createTestMessage(final AMQMessageHeader header,
                                               final byte[] content,
-                                              final boolean persistent,
-                                              final long arrivalTime) throws IOException
+                                              final boolean persistent)
     {
-        final InternalMessageHeader internalMessageHeader = new InternalMessageHeader(header, arrivalTime);
+        final InternalMessageHeader internalMessageHeader = new InternalMessageHeader(header);
+        final int contentSize = content == null ? 0 : content.length;
         final StoredMessage<InternalMessageMetaData> storedMessage =
-                createInternalStoredMessage(content, persistent, internalMessageHeader);
+                createInternalStoredMessage(persistent, internalMessageHeader, contentSize);
         return ((InternalMessage) InternalMessageMetaDataType.INSTANCE.createMessage(storedMessage));
     }
 
-    private StoredMessage<InternalMessageMetaData> createInternalStoredMessage(final byte[] content,
-                                                                               final boolean persistent,
-                                                                               final InternalMessageHeader internalMessageHeader) throws IOException
+    private StoredMessage<InternalMessageMetaData> createInternalStoredMessage(final boolean persistent,
+                                                                               final InternalMessageHeader internalMessageHeader,
+                                                                               final int contentSize)
     {
-        final StoredMessage<InternalMessageMetaData> storedMessage = mock(StoredMessage.class);
-        final int contentSize = content == null ? 0 : content.length;
-        if (contentSize > 0)
-        {
-            try (final ByteArrayOutputStream baos = new ByteArrayOutputStream();
-                 final ObjectOutputStream oos = new ObjectOutputStream(baos))
-            {
-                oos.writeObject(content);
-
-                when(storedMessage.getContent(0, contentSize)).thenReturn(QpidByteBuffer.wrap(
-                        baos.toByteArray()));
-            }
-        }
-        when(storedMessage.getContentSize()).thenReturn(contentSize);
         final InternalMessageMetaData metaData =
                 new InternalMessageMetaData(persistent, internalMessageHeader, contentSize);
+        final StoredMessage<InternalMessageMetaData> storedMessage = mock(StoredMessage.class);
+
         when(storedMessage.getMetaData()).thenReturn(metaData);
+        when(storedMessage.getContentSize()).thenReturn(contentSize);
         return storedMessage;
     }
 
+    private InternalMessage createTestMessage(final String to)
+    {
+        final InternalMessageHeader internalMessageHeader = new InternalMessageHeader(mock(AMQMessageHeader.class));
+        final StoredMessage<InternalMessageMetaData> handle =
+                createInternalStoredMessage(false, internalMessageHeader, 0);
+        return new InternalMessage(handle, internalMessageHeader, null, to);
+    }
+    
     private String generateLongString()
     {
-        return generateLongString(AMQP_0_8_SHORT_STRING_MAX_LENGTH + 1);
+        return generateLongString(AMQShortString.MAX_LENGTH + 1);
     }
 
-    private String generateLongString(long stringLength)
+    private String generateLongString(int stringLength)
     {
-        final StringBuilder buffer = new StringBuilder();
-        for (long i = 0; i < stringLength; i++)
-        {
-            buffer.append('x');
-        }
-        return buffer.toString();
-    }
-
-    private String generateLongLongString()
-    {
-        return generateLongString(1 << 16);
+        return "x".repeat(Math.max(0, stringLength));
     }
 }
