@@ -20,14 +20,13 @@
  */
 package org.apache.qpid.server.protocol.v0_8.transport;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
-import java.util.LinkedHashMap;
 import java.util.Map;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.bytebuffer.QpidByteBuffer;
 import org.apache.qpid.server.protocol.v0_8.EncodingUtils;
@@ -35,8 +34,12 @@ import org.apache.qpid.server.protocol.v0_8.FieldTable;
 import org.apache.qpid.server.protocol.v0_8.FieldTableFactory;
 import org.apache.qpid.test.utils.UnitTestBase;
 
-public class BasicContentHeaderPropertiesTest extends UnitTestBase
+class BasicContentHeaderPropertiesTest extends UnitTestBase
 {
+    private static final int BUFFER_SIZE = 1024 * 10;
+    private static final int POOL_SIZE = 20;
+    private static final double SPARSITY_FRACTION = 0.5;
+
     private final String _testString = "This is a test string";
     private BasicContentHeaderProperties _testProperties;
     private FieldTable _testTable;
@@ -49,12 +52,11 @@ public class BasicContentHeaderPropertiesTest extends UnitTestBase
         _testProperties = new BasicContentHeaderProperties();
     }
 
-    @Before
-    public void setUp() throws Exception
+    @BeforeEach
+    void setUp()
     {
-        Map<String, Object> headers = new LinkedHashMap<>();
-        headers.put("TestString", _testString);
-        headers.put("Testint", Integer.MAX_VALUE);
+        final Map<String, Object> headers = Map.of("TestString", _testString,
+                "Testint", Integer.MAX_VALUE);
         _testTable = FieldTableFactory.createFieldTable(headers);
 
         _testProperties = new BasicContentHeaderProperties();
@@ -62,7 +64,7 @@ public class BasicContentHeaderPropertiesTest extends UnitTestBase
     }
 
     @Test
-    public void testGetPropertyListSize()
+    void getPropertyListSize()
     {
         //needs a better test but at least we're exercising the code !
          // FT length is encoded in an int
@@ -76,84 +78,83 @@ public class BasicContentHeaderPropertiesTest extends UnitTestBase
         // 1 is for the Encoding Letter. here an 'S'
         expectedSize += 1 + EncodingUtils.encodedLongStringLength(_testString);
 
+        final int size = _testProperties.getPropertyListSize();
 
-        int size = _testProperties.getPropertyListSize();
-
-        assertEquals((long) expectedSize, (long) size);
+        assertEquals(expectedSize, (long) size);
     }
 
     @Test
-    public void testGetSetPropertyFlags()
+    void getSetPropertyFlags()
     {
         _testProperties.setPropertyFlags(99);
-        assertEquals((long) 99, (long) _testProperties.getPropertyFlags());
+        assertEquals(99, (long) _testProperties.getPropertyFlags());
     }
 
     @Test
-    public void testPopulatePropertiesFromBuffer() throws Exception
+    void populatePropertiesFromBuffer() throws Exception
     {
-        QpidByteBuffer buf = QpidByteBuffer.wrap(new byte[300]);
+        final QpidByteBuffer buf = QpidByteBuffer.wrap(new byte[300]);
         _testProperties.dispose();
         _testProperties = new BasicContentHeaderProperties(buf, 99, 99);
     }
 
     @Test
-    public void testSetGetContentType()
+    void setGetContentType()
     {
-        String contentType = "contentType";
+        final String contentType = "contentType";
         _testProperties.setContentType(contentType);
         assertEquals(contentType, _testProperties.getContentTypeAsString());
     }
 
     @Test
-    public void testSetGetEncoding()
+    void setGetEncoding()
     {
-        String encoding = "encoding";
+        final String encoding = "encoding";
         _testProperties.setEncoding(encoding);
         assertEquals(encoding, _testProperties.getEncodingAsString());
     }
 
     @Test
-    public void testSetGetHeaders()
+    void setGetHeaders()
     {
         _testProperties.setHeaders(_testTable);
         assertEquals(FieldTable.convertToMap(_testTable), _testProperties.getHeadersAsMap());
     }
 
     @Test
-    public void testSetGetDeliveryMode()
+    void setGetDeliveryMode()
     {
-        byte deliveryMode = 1;
+        final byte deliveryMode = 1;
         _testProperties.setDeliveryMode(deliveryMode);
-        assertEquals((long) deliveryMode, (long) _testProperties.getDeliveryMode());
+        assertEquals(deliveryMode, (long) _testProperties.getDeliveryMode());
     }
 
     @Test
-    public void testSetGetPriority()
+    void setGetPriority()
     {
-        byte priority = 1;
+        final byte priority = 1;
         _testProperties.setPriority(priority);
-        assertEquals((long) priority, (long) _testProperties.getPriority());
+        assertEquals(priority, (long) _testProperties.getPriority());
     }
 
     @Test
-    public void testSetGetCorrelationId()
+    void setGetCorrelationId()
     {
-        String correlationId = "correlationId";
+        final String correlationId = "correlationId";
         _testProperties.setCorrelationId(correlationId);
         assertEquals(correlationId, _testProperties.getCorrelationIdAsString());
     }
 
     @Test
-    public void testSetGetReplyTo()
+    void setGetReplyTo()
     {
-        String replyTo = "replyTo";
+        final String replyTo = "replyTo";
         _testProperties.setReplyTo(replyTo);
         assertEquals(replyTo, _testProperties.getReplyToAsString());
     }
 
     @Test
-    public void testSetGetExpiration()
+    void setGetExpiration()
     {
         long expiration = 999999999;
         _testProperties.setExpiration(expiration);
@@ -164,65 +165,61 @@ public class BasicContentHeaderPropertiesTest extends UnitTestBase
     }
 
     @Test
-    public void testSetGetMessageId()
+    void setGetMessageId()
     {
-        String messageId = "messageId";
+        final String messageId = "messageId";
         _testProperties.setMessageId(messageId);
         assertEquals(messageId, _testProperties.getMessageIdAsString());
     }
 
     @Test
-    public void testSetGetTimestamp()
+    void setGetTimestamp()
     {
-        long timestamp = System.currentTimeMillis();
+        final long timestamp = System.currentTimeMillis();
         _testProperties.setTimestamp(timestamp);
         assertEquals(timestamp, _testProperties.getTimestamp());
     }
 
     @Test
-    public void testSetGetType()
+    void setGetType()
     {
-        String type = "type";
+        final String type = "type";
         _testProperties.setType(type);
         assertEquals(type, _testProperties.getTypeAsString());
     }
 
     @Test
-    public void testSetGetUserId()
+    void setGetUserId()
     {
-        String userId = "userId";
+        final String userId = "userId";
         _testProperties.setUserId(userId);
         assertEquals(userId, _testProperties.getUserIdAsString());
     }
 
     @Test
-    public void testSetGetAppId()
+    void setGetAppId()
     {
-        String appId = "appId";
+        final String appId = "appId";
         _testProperties.setAppId(appId);
         assertEquals(appId, _testProperties.getAppIdAsString());
     }
 
     @Test
-    public void testSetGetClusterId()
+    void setGetClusterId()
     {
-        String clusterId = "clusterId";
+        final String clusterId = "clusterId";
         _testProperties.setClusterId(clusterId);
         assertEquals(clusterId, _testProperties.getClusterIdAsString());
     }
 
-    private static final int BUFFER_SIZE = 1024 * 10;
-    private static final int POOL_SIZE = 20;
-    private static final double SPARSITY_FRACTION = 0.5;
-
     @Test
-    public void testReallocate() throws Exception
+    void reallocate() throws Exception
     {
         try
         {
             QpidByteBuffer.deinitialisePool();
             QpidByteBuffer.initialisePool(BUFFER_SIZE, POOL_SIZE, SPARSITY_FRACTION);
-            try (QpidByteBuffer buffer = QpidByteBuffer.allocateDirect(BUFFER_SIZE))
+            try (final QpidByteBuffer buffer = QpidByteBuffer.allocateDirect(BUFFER_SIZE))
             {
                 // set some test fields
                 _testProperties.setContentType("text/plain");
@@ -235,22 +232,22 @@ public class BasicContentHeaderPropertiesTest extends UnitTestBase
                 final int pos = BUFFER_SIZE - propertyListSize * 2;
                 buffer.position(pos);
 
-                try (QpidByteBuffer propertiesBuffer = buffer.view(0, propertyListSize))
+                try (final QpidByteBuffer propertiesBuffer = buffer.view(0, propertyListSize))
                 {
                     _testProperties.writePropertyListPayload(propertiesBuffer);
                     propertiesBuffer.flip();
 
-                    BasicContentHeaderProperties testProperties = new BasicContentHeaderProperties(propertiesBuffer, flags, propertyListSize);
+                    final BasicContentHeaderProperties testProperties = new BasicContentHeaderProperties(propertiesBuffer, flags, propertyListSize);
                     final Map<String, Object> headersBeforeReallocation = testProperties.getHeadersAsMap();
-                    assertEquals("Unexpected headers", headers, headersBeforeReallocation);
+                    assertEquals(headers, headersBeforeReallocation, "Unexpected headers");
 
                     buffer.dispose();
 
-                    assertTrue("Properties buffer should be sparse", propertiesBuffer.isSparse());
+                    assertTrue(propertiesBuffer.isSparse(), "Properties buffer should be sparse");
                     testProperties.reallocate();
 
                     final Map<String, Object> headersAfterReallocation = testProperties.getHeadersAsMap();
-                    assertEquals("Unexpected headers after re-allocation", headers, headersAfterReallocation);
+                    assertEquals(headers, headersAfterReallocation, "Unexpected headers after re-allocation");
                 }
             }
         }
