@@ -26,33 +26,33 @@ import static org.hamcrest.CoreMatchers.nullValue;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.mockito.Mockito.mock;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.protocol.v1_0.LinkEndpoint;
 import org.apache.qpid.server.protocol.v1_0.type.Binary;
 import org.apache.qpid.server.protocol.v1_0.type.UnsignedInteger;
 import org.apache.qpid.test.utils.UnitTestBase;
 
-public class DeliveryRegistryImplTest extends UnitTestBase
+class DeliveryRegistryImplTest extends UnitTestBase
 {
     private static final UnsignedInteger DELIVERY_ID = UnsignedInteger.ZERO;
     private static final UnsignedInteger DELIVERY_ID_2 = UnsignedInteger.ONE;
     private static final Binary DELIVERY_TAG = new Binary(new byte[]{(byte) 32, (byte) 33});
     private static final Binary DELIVERY_TAG_2 = new Binary(new byte[]{(byte) 32});
 
-    private DeliveryRegistryImpl _registry;
-    private UnsettledDelivery _unsettledDelivery;
+    private final UnsettledDelivery _unsettledDelivery = new UnsettledDelivery(DELIVERY_TAG, mock(LinkEndpoint.class));
 
-    @Before
-    public void setUp()
+    private DeliveryRegistryImpl _registry;
+
+    @BeforeEach
+    void setUp()
     {
         _registry = new DeliveryRegistryImpl();
-        _unsettledDelivery = new UnsettledDelivery(DELIVERY_TAG, mock(LinkEndpoint.class));
     }
 
     @Test
-    public void addDelivery()
+    void addDelivery()
     {
         assertThat(_registry.size(), is(equalTo(0)));
 
@@ -62,7 +62,7 @@ public class DeliveryRegistryImplTest extends UnitTestBase
     }
 
     @Test
-    public void removeDelivery()
+    void removeDelivery()
     {
         _registry.addDelivery(DELIVERY_ID, _unsettledDelivery);
         assertThat(_registry.size(), is(equalTo(1)));
@@ -72,7 +72,7 @@ public class DeliveryRegistryImplTest extends UnitTestBase
     }
 
     @Test
-    public void getDelivery()
+    void getDelivery()
     {
         _registry.addDelivery(DELIVERY_ID, _unsettledDelivery);
 
@@ -83,7 +83,7 @@ public class DeliveryRegistryImplTest extends UnitTestBase
     }
 
     @Test
-    public void removeDeliveriesForLinkEndpoint()
+    void removeDeliveriesForLinkEndpoint()
     {
         _registry.addDelivery(DELIVERY_ID, _unsettledDelivery);
         _registry.addDelivery(DELIVERY_ID_2, new UnsettledDelivery(DELIVERY_TAG_2, _unsettledDelivery.getLinkEndpoint()));
@@ -97,7 +97,7 @@ public class DeliveryRegistryImplTest extends UnitTestBase
     }
 
     @Test
-    public void getDeliveryId()
+    void getDeliveryId()
     {
         _registry.addDelivery(DELIVERY_ID, _unsettledDelivery);
         _registry.addDelivery(DELIVERY_ID_2, new UnsettledDelivery(DELIVERY_TAG, mock(LinkEndpoint.class)));
@@ -108,7 +108,7 @@ public class DeliveryRegistryImplTest extends UnitTestBase
     }
 
     @Test
-    public void size()
+    void size()
     {
         assertThat(_registry.size(), is(equalTo(0)));
 
