@@ -1,5 +1,4 @@
 /*
- *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,11 +17,10 @@
  * under the License.
  *
  */
-package org.apache.qpid.server.protocol.converter.v0_8_v1_0;
+package org.apache.qpid.server.protocol.converter.v0_10_v1_0;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.apache.qpid.server.protocol.v1_0.MessageConverter_from_1_0.getContentType;
-
 import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNull;
@@ -40,20 +38,17 @@ import java.util.UUID;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
 
-import org.junit.jupiter.params.ParameterizedTest;
-import org.junit.jupiter.params.provider.CsvSource;
 import org.mockito.ArgumentCaptor;
 
 import org.apache.qpid.server.bytebuffer.QpidByteBuffer;
 import org.apache.qpid.server.message.AMQMessageHeader;
 import org.apache.qpid.server.model.NamedAddressSpace;
+import org.apache.qpid.server.protocol.v0_10.MessageMetaData_0_10;
+import org.apache.qpid.server.protocol.v0_10.MessageTransferMessage;
+import org.apache.qpid.server.protocol.v0_10.transport.Header;
+import org.apache.qpid.server.protocol.v0_10.transport.MessageProperties;
 import org.apache.qpid.server.protocol.v0_10.transport.mimecontentconverter.ListToAmqpListConverter;
 import org.apache.qpid.server.protocol.v0_10.transport.mimecontentconverter.MapToAmqpMapConverter;
-import org.apache.qpid.server.protocol.v0_8.AMQMessage;
-import org.apache.qpid.server.protocol.v0_8.MessageMetaData;
-import org.apache.qpid.server.protocol.v0_8.transport.BasicContentHeaderProperties;
-import org.apache.qpid.server.protocol.v0_8.transport.ContentHeaderBody;
-import org.apache.qpid.server.protocol.v0_8.transport.MessagePublishInfo;
 import org.apache.qpid.server.protocol.v1_0.JmsMessageTypeAnnotation;
 import org.apache.qpid.server.protocol.v1_0.Message_1_0;
 import org.apache.qpid.server.protocol.v1_0.messaging.SectionDecoder;
@@ -71,44 +66,108 @@ import org.apache.qpid.server.typedmessage.TypedBytesContentWriter;
 import org.apache.qpid.test.utils.UnitTestBase;
 
 @SuppressWarnings({"unchecked"})
-class MessageConverter_0_8_to_1_0Test extends UnitTestBase
+class MessageConverter_0_10_to_1_0Test extends UnitTestBase
 {
-    private final MessageConverter_0_8_to_1_0 _converter = new MessageConverter_0_8_to_1_0();
+    private final MessageConverter_0_10_to_1_0 _converter = new MessageConverter_0_10_to_1_0();
     private final AMQPDescribedTypeRegistry _typeRegistry = AMQPDescribedTypeRegistry.newInstance()
             .registerTransportLayer()
             .registerMessagingLayer()
             .registerTransactionLayer()
             .registerSecurityLayer();
+    private final StoredMessage<MessageMetaData_0_10> _handle = mock(StoredMessage.class);
+    private final MessageMetaData_0_10 _metaData = mock(MessageMetaData_0_10.class);
+    private final AMQMessageHeader _amqpHeader = mock(AMQMessageHeader.class);
+    private final Header _header = mock(Header.class);
 
-    private final StoredMessage<MessageMetaData> _handle = mock(StoredMessage.class);
-
-    private final MessageMetaData _metaData = mock(MessageMetaData.class);
-    private final AMQMessageHeader _header = mock(AMQMessageHeader.class);
-    private final ContentHeaderBody _contentHeaderBody = mock(ContentHeaderBody.class);
-    private final BasicContentHeaderProperties _basicContentHeaderProperties = mock(BasicContentHeaderProperties.class);
+    private MessageProperties _messageProperties;
 
     @BeforeAll
     void setUp()
     {
+        _messageProperties = new MessageProperties();
         when(_handle.getMetaData()).thenReturn(_metaData);
-        when(_metaData.getMessageHeader()).thenReturn(_header);
-        when(_metaData.getMessagePublishInfo()).thenReturn(new MessagePublishInfo());
-        when(_metaData.getContentHeaderBody()).thenReturn(_contentHeaderBody);
-        when(_contentHeaderBody.getProperties()).thenReturn(_basicContentHeaderProperties);
+        when(_header.getMessageProperties()).thenReturn(_messageProperties);
+        when(_metaData.getHeader()).thenReturn(_header);
+        when(_metaData.getMessageHeader()).thenReturn(_amqpHeader);
+        when(_metaData.getMessageProperties()).thenReturn(_messageProperties);
     }
 
-    @CsvSource(
+    @Test
+    void convertStringMessageBody() throws Exception
     {
-            "helloworld,text/plain", "null,text/plain", "<helloworld></helloworld>,text/xml", "null,text/xml",
-            "null,application/xml", "foo,text/foobar", "<helloworld></helloworld>,application/xml",
-            "<!DOCTYPE name []>,application/xml-dtd", "<helloworld></helloworld>,application/foo+xml",
-            "[],application/json", "[],application/foo+json", "var foo,application/javascript",
-            "var foo,application/ecmascript"
-    })
-    @ParameterizedTest
-    void convertStringMessage(final String originalContent, final String mimeType) throws Exception
+        doTestTextMessage("helloworld", "text/plain");
+    }
+
+    @Test
+    void convertEmptyStringMessageBody() throws Exception
     {
-        doTestTextMessage(originalContent, mimeType);
+        doTestTextMessage(null, "text/plain");
+    }
+
+    @Test
+    void convertStringXmlMessageBody() throws Exception
+    {
+        doTestTextMessage("<helloworld></helloworld>", "text/xml");
+    }
+
+    @Test
+    void convertEmptyStringXmlMessageBody() throws Exception
+    {
+        doTestTextMessage(null, "text/xml");
+    }
+
+    @Test
+    void convertEmptyStringApplicationXmlMessageBody() throws Exception
+    {
+        doTestTextMessage(null, "application/xml");
+    }
+
+    @Test
+    void convertStringWithContentTypeText() throws Exception
+    {
+        doTestTextMessage("foo","text/foobar");
+    }
+
+    @Test
+    void convertStringWithContentTypeApplicationXml() throws Exception
+    {
+        doTestTextMessage("<helloworld></helloworld>","application/xml");
+    }
+
+    @Test
+    void convertStringWithContentTypeApplicationXmlDtd() throws Exception
+    {
+        doTestTextMessage("<!DOCTYPE name []>","application/xml-dtd");
+    }
+
+    @Test
+    void convertStringWithContentTypeApplicationFooXml() throws Exception
+    {
+        doTestTextMessage("<helloworld></helloworld>","application/foo+xml");
+    }
+
+    @Test
+    void convertStringWithContentTypeApplicationJson() throws Exception
+    {
+        doTestTextMessage("[]","application/json");
+    }
+
+    @Test
+    void convertStringWithContentTypeApplicationFooJson() throws Exception
+    {
+        doTestTextMessage("[]","application/foo+json");
+    }
+
+    @Test
+    void convertStringWithContentTypeApplicationJavascript() throws Exception
+    {
+        doTestTextMessage("var foo","application/javascript");
+    }
+
+    @Test
+    void convertStringWithContentTypeApplicationEcmascript() throws Exception
+    {
+        doTestTextMessage("var foo","application/ecmascript");
     }
 
     @Test
@@ -143,7 +202,6 @@ class MessageConverter_0_8_to_1_0Test extends UnitTestBase
         final List<Object> expected = List.of("apple", 43, 31.42D);
         final byte[] messageBytes = getJmsStreamMessageBytes(expected);
         final String mimeType = "jms/stream-message";
-
         doTestStreamMessage(messageBytes, mimeType, expected, JmsMessageTypeAnnotation.STREAM_MESSAGE.getType());
     }
 
@@ -151,7 +209,6 @@ class MessageConverter_0_8_to_1_0Test extends UnitTestBase
     void convertJmsStreamMessageEmptyBody() throws Exception
     {
         final List<Object> expected = List.of();
-
         doTestStreamMessage(null, "jms/stream-message", expected, JmsMessageTypeAnnotation.STREAM_MESSAGE.getType());
     }
 
@@ -160,8 +217,8 @@ class MessageConverter_0_8_to_1_0Test extends UnitTestBase
     {
         final List<Object> expected = List.of("apple", 43, 31.42D);
         final byte[] messageBytes = new ListToAmqpListConverter().toMimeContent(expected);
-        final String mimeType = "amqp/list";
 
+        final String mimeType = "amqp/list";
         doTestStreamMessage(messageBytes, mimeType, expected, JmsMessageTypeAnnotation.STREAM_MESSAGE.getType());
     }
 
@@ -171,7 +228,6 @@ class MessageConverter_0_8_to_1_0Test extends UnitTestBase
         final List<Object> expected = List.of("apple", 43, 31.42D, List.of("nonJMSList"));
         final byte[] messageBytes = new ListToAmqpListConverter().toMimeContent(expected);
         final String mimeType = "amqp/list";
-
         doTestStreamMessage(messageBytes, mimeType, expected, null);
     }
 
@@ -180,27 +236,24 @@ class MessageConverter_0_8_to_1_0Test extends UnitTestBase
     {
         final Map<String, Object> expected = Map.of("key", "value");
         final byte[] messageBytes = getJmsMapMessageBytes(expected);
-
         doTestMapMessage(messageBytes, "jms/map-message", expected, JmsMessageTypeAnnotation.MAP_MESSAGE.getType());
     }
 
-    @Test
-    void convertJmsMapMessageEmptyBody() throws Exception
-    {
-        final Map<String, Object> expected = Map.of();
-
-        doTestMapMessage(null, "jms/map-message", expected, JmsMessageTypeAnnotation.MAP_MESSAGE.getType());
-    }
-
     @Test
     void convertAmqpMapMessageBody() throws Exception
     {
         final Map<String, Object> expected = Map.of("key", "value");
         final byte[] messageBytes = new MapToAmqpMapConverter().toMimeContent(expected);
-
         doTestMapMessage(messageBytes, "amqp/map", expected, JmsMessageTypeAnnotation.MAP_MESSAGE.getType());
     }
 
+    @Test
+    void convertJmsMapMessageEmptyBody() throws Exception
+    {
+        final Map<String, Object> expected = Map.of();
+        doTestMapMessage(null, "jms/map-message", expected, JmsMessageTypeAnnotation.MAP_MESSAGE.getType());
+    }
+
     @Test
     void convertAmqpMapMessageBodyWithNonJmsContent() throws Exception
     {
@@ -214,7 +267,6 @@ class MessageConverter_0_8_to_1_0Test extends UnitTestBase
     void convertObjectStreamMessageBody() throws Exception
     {
         final byte[] messageBytes = getObjectStreamMessageBytes(UUID.randomUUID());
-
         doTestObjectMessage(messageBytes, "application/java-object-stream", messageBytes);
     }
 
@@ -222,7 +274,6 @@ class MessageConverter_0_8_to_1_0Test extends UnitTestBase
     void convertObjectStream2MessageBody() throws Exception
     {
         final byte[] messageBytes = getObjectStreamMessageBytes(UUID.randomUUID());
-
         doTestObjectMessage(messageBytes, "application/x-java-serialized-object", messageBytes);
     }
 
@@ -232,7 +283,6 @@ class MessageConverter_0_8_to_1_0Test extends UnitTestBase
         final byte[] messageBytes = null;
         final byte[] expectedBytes = getObjectStreamMessageBytes(messageBytes);
         final String mimeType = "application/java-object-stream";
-
         doTestObjectMessage(messageBytes, mimeType, expectedBytes);
     }
 
@@ -268,9 +318,9 @@ class MessageConverter_0_8_to_1_0Test extends UnitTestBase
     private byte[] getJmsStreamMessageBytes(final List<Object> objects) throws Exception
     {
         final TypedBytesContentWriter writer = new TypedBytesContentWriter();
-        for (final Object o : objects)
+        for (final Object object : objects)
         {
-            writer.writeObject(o);
+            writer.writeObject(object);
         }
         return getBytes(writer);
     }
@@ -305,18 +355,17 @@ class MessageConverter_0_8_to_1_0Test extends UnitTestBase
         return sections;
     }
 
-    protected AMQMessage getAmqMessage(final byte[] expected, final String mimeType)
+    private MessageTransferMessage getAmqMessage(final byte[] expected, final String mimeType)
     {
         configureMessageContent(expected);
         configureMessageHeader(mimeType);
-
-        return new AMQMessage(_handle);
+        return new MessageTransferMessage(_handle, new Object());
     }
 
     private void configureMessageHeader(final String mimeType)
     {
-        when(_header.getMimeType()).thenReturn(mimeType);
-        when(_basicContentHeaderProperties.getContentTypeAsString()).thenReturn(mimeType);
+        when(_amqpHeader.getMimeType()).thenReturn(mimeType);
+        _messageProperties.setContentType(mimeType);
     }
 
     private void configureMessageContent(byte[] section)
@@ -364,6 +413,7 @@ class MessageConverter_0_8_to_1_0Test extends UnitTestBase
                JmsMessageTypeAnnotation.TEXT_MESSAGE.getType());
     }
 
+
     private void doTestMapMessage(final byte[] messageBytes,
                                   final String mimeType,
                                   final Map<String, Object> expected,
@@ -390,9 +440,8 @@ class MessageConverter_0_8_to_1_0Test extends UnitTestBase
         doTest(messageBytes, mimeType, AmqpSequenceSection.class, expected, null, expectedJmsTypAnnotation);
     }
 
-    private void doTestObjectMessage(final byte[] messageBytes,
-                                     final String mimeType,
-                                     final byte[] expectedBytes) throws Exception
+    private void doTestObjectMessage(final byte[] messageBytes, final String mimeType, final byte[] expectedBytes)
+            throws Exception
     {
         doTest(messageBytes,
                mimeType,
@@ -409,7 +458,7 @@ class MessageConverter_0_8_to_1_0Test extends UnitTestBase
                         final Symbol expectedContentType,
                         final Byte expectedJmsTypeAnnotation) throws Exception
     {
-        final AMQMessage sourceMessage = getAmqMessage(messageBytes, mimeType);
+        final MessageTransferMessage sourceMessage = getAmqMessage(messageBytes, mimeType);
         final Message_1_0 convertedMessage = _converter.convert(sourceMessage, mock(NamedAddressSpace.class));
         final QpidByteBuffer content = convertedMessage.getContent(0, (int) convertedMessage.getSize());
 
@@ -444,7 +493,7 @@ class MessageConverter_0_8_to_1_0Test extends UnitTestBase
         }
         else
         {
-            assertEquals(expectedJmsTypeAnnotation, jmsMessageTypeAnnotation,"Unexpected annotation 'x-opt-jms-msg-type'");
+            assertEquals(expectedJmsTypeAnnotation, jmsMessageTypeAnnotation, "Unexpected annotation 'x-opt-jms-msg-type'");
         }
     }
 }
