@@ -22,15 +22,13 @@ package org.apache.qpid.server.logging.logback;
 
 import static org.apache.qpid.test.utils.JvmVendor.IBM;
 import static org.apache.qpid.test.utils.JvmVendor.OPENJDK;
-import static org.hamcrest.CoreMatchers.anyOf;
-import static org.hamcrest.CoreMatchers.equalTo;
-import static org.hamcrest.CoreMatchers.not;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assume.assumeThat;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assumptions.assumeFalse;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Objects;
 
 import ch.qos.logback.classic.Level;
 import ch.qos.logback.classic.Logger;
@@ -43,8 +41,9 @@ import ch.qos.logback.core.LogbackException;
 import ch.qos.logback.core.filter.Filter;
 import ch.qos.logback.core.spi.FilterReply;
 import ch.qos.logback.core.status.Status;
-import org.junit.Before;
-import org.junit.Test;
+
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.test.utils.UnitTestBase;
 
@@ -55,10 +54,10 @@ public class Logback1027WorkaroundTurboFilterTest extends UnitTestBase
     private Logger _logger;
     private SnoopingAppender _snoopingAppender;
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception
     {
-        LoggerContext context = new LoggerContext();
+        final LoggerContext context = new LoggerContext();
         _logger = context.getLogger(Logback1027WorkaroundTurboFilterTest.class);
         _snoopingAppender = new SnoopingAppender();
         _logger.addAppender(_snoopingAppender);
@@ -67,22 +66,22 @@ public class Logback1027WorkaroundTurboFilterTest extends UnitTestBase
     @Test
     public void testOneException()
     {
-        Exception e = new Exception();
+        final Exception e = new Exception();
         final FilterReply reply = doDecide(e);
         assertEquals(FilterReply.NEUTRAL, reply);
 
-        assertEquals((long) 0, (long) _snoopingAppender.getEvents().size());
+        assertEquals(0, (long) _snoopingAppender.getEvents().size());
     }
 
     @Test
     public void testSuppressedExceptionRecursion()
     {
         // https://www.ibm.com/developerworks/community/forums/html/topic?id=8482d948-665c-47a2-862e-457e49ac71a4&ps=25
-        assumeThat("(QPID-7955) Behaviourial difference between the IBM JDK and the Open JDK", getJvmVendor(),
-                   not(anyOf(equalTo(OPENJDK), equalTo(IBM))));
+        assumeFalse(Objects.equals(getJvmVendor(), OPENJDK) || Objects.equals(getJvmVendor(), IBM),
+                "(QPID-7955) Behavioural difference between the IBM JDK and the Open JDK");
 
-        Exception e1 = new Exception();
-        Exception e2 = new Exception();
+        final Exception e1 = new Exception();
+        final Exception e2 = new Exception();
         e2.addSuppressed(e1);
         e1.addSuppressed(e2);
 
@@ -90,7 +89,7 @@ public class Logback1027WorkaroundTurboFilterTest extends UnitTestBase
         assertEquals(FilterReply.DENY, reply);
 
         final List<ILoggingEvent> events = _snoopingAppender.getEvents();
-        assertEquals((long) 1, (long) events.size());
+        assertEquals(1, (long) events.size());
 
         assertLoggingEvent(events.get(0));
     }
@@ -100,33 +99,33 @@ public class Logback1027WorkaroundTurboFilterTest extends UnitTestBase
         assertEquals(Level.INFO, loggingEvent.getLevel());
         assertEquals(TEST_LOG_MESSAGE, loggingEvent.getMessage());
         assertNull(loggingEvent.getArgumentArray());
-        IThrowableProxy thing = loggingEvent.getThrowableProxy();
+        final IThrowableProxy thing = loggingEvent.getThrowableProxy();
         assertEquals(Logback1027WorkaroundTurboFilter.StringifiedException.class.getName(), thing.getClassName());
     }
 
     @Test
-    public void testInitCauseRecursion() throws Exception
+    public void testInitCauseRecursion()
     {
         // https://www.ibm.com/developerworks/community/forums/html/topic?id=8482d948-665c-47a2-862e-457e49ac71a4&ps=25
-        assumeThat("(QPID-7955) Behaviourial difference between the IBM JDK and the Open JDK", getJvmVendor(),
-                   not(anyOf(equalTo(OPENJDK), equalTo(IBM))));
+        assumeFalse(Objects.equals(getJvmVendor(), OPENJDK) || Objects.equals(getJvmVendor(), IBM),
+                "(QPID-7955) Behavioural difference between the IBM JDK and the Open JDK");
 
-        Exception e1 = new Exception();
-        Exception e2 = new Exception();
+        final Exception e1 = new Exception();
+        final Exception e2 = new Exception();
         e2.initCause(e1);
         e1.initCause(e2);
 
         final FilterReply reply = doDecide(e1);
         assertEquals(FilterReply.DENY, reply);
-        assertEquals((long) 1, (long) _snoopingAppender.getEvents().size());
+        assertEquals(1, (long) _snoopingAppender.getEvents().size());
     }
 
     @Test
     public void testNoRecursion()
     {
-        Exception e1 = new Exception();
-        Exception e2 = new Exception();
-        Exception e3 = new Exception();
+        final Exception e1 = new Exception();
+        final Exception e2 = new Exception();
+        final Exception e3 = new Exception();
 
         e2.addSuppressed(e3);
         e1.addSuppressed(e2);
@@ -134,15 +133,15 @@ public class Logback1027WorkaroundTurboFilterTest extends UnitTestBase
 
         final FilterReply reply = doDecide(e1);
         assertEquals(FilterReply.NEUTRAL, reply);
-        assertEquals((long) 0, (long) _snoopingAppender.getEvents().size());
+        assertEquals(0, (long) _snoopingAppender.getEvents().size());
     }
 
     @Test
     public void testNoRecursion2()
     {
-        Exception e1 = new Exception();
-        Exception e2 = new Exception();
-        Exception e3 = new Exception();
+        final Exception e1 = new Exception();
+        final Exception e2 = new Exception();
+        final Exception e3 = new Exception();
 
         e2.initCause(e3);
         e1.initCause(e2);
@@ -150,7 +149,7 @@ public class Logback1027WorkaroundTurboFilterTest extends UnitTestBase
 
         final FilterReply reply = doDecide(e1);
         assertEquals(FilterReply.NEUTRAL, reply);
-        assertEquals((long) 0, (long) _snoopingAppender.getEvents().size());
+        assertEquals(0, (long) _snoopingAppender.getEvents().size());
     }
 
     private FilterReply doDecide(final Exception e1)
