@@ -29,7 +29,8 @@ import java.util.TreeSet;
 import java.util.stream.Collectors;
 
 import javax.security.auth.Subject;
-import javax.servlet.http.HttpServletResponse;
+
+import jakarta.servlet.http.HttpServletResponse;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
