@@ -18,7 +18,7 @@
  * under the License.
  *
  */
-package org.apache.qpid.server.management.plugin.controller.v6_1.category;
+package org.apache.qpid.server.management.plugin.controller.v7_0.category;
 
 import java.util.Set;
 
@@ -30,13 +30,11 @@ import org.apache.qpid.server.management.plugin.controller.TypeController;
 
 public class LegacyCategoryController extends GenericCategoryController
 {
+    private final String _parentCategory;
 
-    private final String[] _parentCategories;
-
-
-    LegacyCategoryController(final LegacyManagementController managementController,
+    public LegacyCategoryController(final LegacyManagementController managementController,
                              final String name,
-                             final String[] parentCategories,
+                             final String parentCategory,
                              final String defaultType,
                              final Set<TypeController> typeControllers)
     {
@@ -45,18 +43,25 @@ public class LegacyCategoryController extends GenericCategoryController
               name,
               defaultType,
               typeControllers);
-        _parentCategories = parentCategories;
+        _parentCategory = parentCategory;
     }
 
     @Override
     public String[] getParentCategories()
     {
-        return _parentCategories;
+        return new String[]{_parentCategory};
     }
 
     @Override
     protected LegacyConfiguredObject convertNextVersionLegacyConfiguredObject(final LegacyConfiguredObject object)
     {
-        return new GenericLegacyConfiguredObject(getManagementController(), object, getCategory());
+        final GenericLegacyConfiguredObject legacyegacyConfiguredObject =
+                new GenericLegacyConfiguredObject(getManagementController(), object, getCategory());
+        if (LegacyCategoryControllerFactory.CATEGORY_VIRTUAL_HOST.equals(getCategory())
+            || LegacyCategoryControllerFactory.CATEGORY_BROKER.equals(getCategory()))
+        {
+            return new ContainerDecorator(legacyegacyConfiguredObject);
+        }
+        return legacyegacyConfiguredObject;
     }
 }
