@@ -27,17 +27,17 @@ import java.time.ZoneId;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.stream.Collectors;
 
 import jakarta.servlet.ServletContext;
 import jakarta.servlet.ServletException;
 import jakarta.servlet.http.HttpServletRequest;
 import jakarta.servlet.http.HttpServletResponse;
 
-import com.fasterxml.jackson.databind.ObjectMapper;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import tools.jackson.databind.ObjectMapper;
+
 import org.apache.qpid.server.filter.SelectorParsingException;
 import org.apache.qpid.server.management.plugin.HttpManagementConfiguration;
 import org.apache.qpid.server.management.plugin.HttpManagementUtil;
@@ -100,9 +100,10 @@ public abstract class QueryServlet<X extends ConfiguredObject<?>> extends Abstra
         final ConfiguredObject<?> managedObject
     ) throws IOException
     {
+        String content = "";
         try
         {
-            final String content = request.getReader().lines().collect(Collectors.joining());
+            content = String.join(" ", request.getReader().lines().toList());
             if (content.isEmpty())
             {
                 performQuery(request, response, managedObject);
@@ -119,7 +120,7 @@ public abstract class QueryServlet<X extends ConfiguredObject<?>> extends Abstra
         catch (Exception e)
         {
             sendJsonErrorResponse(request, response, HttpServletResponse.SC_INTERNAL_SERVER_ERROR, GENERIC_ERROR_MESSAGE);
-            LOGGER.error("Error when executing query", e);
+            LOGGER.error("Error when executing query '%s'".formatted(content), e);
         }
     }
 
