@@ -29,11 +29,13 @@ import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
 import java.util.Collection;
-import java.util.Collections;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
 import java.util.UUID;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.management.plugin.ManagementController;
 import org.apache.qpid.server.management.plugin.ManagementResponse;
@@ -48,14 +50,14 @@ public class SessionControllerTest extends UnitTestBase
     private LegacyManagementController _legacyManagementController;
     private SessionController _sessionController;
 
-    @Before
+    @BeforeEach
     public void setUp()
     {
         _legacyManagementController = mock(LegacyManagementController.class);
         final ManagementController nextVersionManagementController = mock(ManagementController.class);
         when(_legacyManagementController.getNextVersionManagementController()).thenReturn(
                 nextVersionManagementController);
-        _sessionController = new SessionController(_legacyManagementController, Collections.emptySet());
+        _sessionController = new SessionController(_legacyManagementController, Set.of());
     }
 
     @Test
@@ -70,9 +72,8 @@ public class SessionControllerTest extends UnitTestBase
         when(nextVersionSession.getAttribute(LegacyConfiguredObject.ID)).thenReturn(sessionID);
 
         final ManagementResponse operationResult = new ControllerManagementResponse(ResponseType.MODEL_OBJECT,
-                                                                                    Collections.singletonList(
-                                                                                            nextVersionConsumer));
-        when(nextVersionSession.invoke(eq("getConsumers"), eq(Collections.emptyMap()), eq(true))).thenReturn(
+                List.of(nextVersionConsumer));
+        when(nextVersionSession.invoke(eq("getConsumers"), eq(Map.of()), eq(true))).thenReturn(
                 operationResult);
 
         final LegacyConfiguredObject convertedConsumer = mock(LegacyConfiguredObject.class);
