@@ -28,13 +28,13 @@ import static org.hamcrest.MatcherAssert.assertThat;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.management.plugin.ManagementController;
 import org.apache.qpid.server.management.plugin.controller.LegacyConfiguredObject;
@@ -46,7 +46,7 @@ public class VirtualHostControllerTest extends UnitTestBase
 {
     private VirtualHostController _virtualHostController;
 
-    @Before
+    @BeforeEach
     public void setUp()
     {
         final LegacyManagementController legacyManagementController = mock(LegacyManagementController.class);
@@ -54,7 +54,7 @@ public class VirtualHostControllerTest extends UnitTestBase
         when(legacyManagementController.getNextVersionManagementController()).thenReturn(
                 nextVersionManagementController);
         when(legacyManagementController.getVersion()).thenReturn("6.1");
-        _virtualHostController = new VirtualHostController(legacyManagementController, Collections.emptySet());
+        _virtualHostController = new VirtualHostController(legacyManagementController, Set.of());
     }
 
     @Test
@@ -85,7 +85,7 @@ public class VirtualHostControllerTest extends UnitTestBase
         attributes.put(LegacyConfiguredObject.CONTEXT, context);
 
         final ConfiguredObject<?> root = mock(ConfiguredObject.class);
-        final List<String> path = Collections.singletonList("test-vhn");
+        final List<String> path = List.of("test-vhn");
         Map<String, Object> converted = _virtualHostController.convertAttributesToNextVersion(root, path, attributes);
 
         assertThat(converted, is(notNullValue()));
