@@ -20,15 +20,13 @@
 
 package org.apache.qpid.server.management.plugin.servlet.query;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.fail;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
 import java.time.Instant;
-import java.time.LocalDateTime;
 import java.time.ZoneId;
-import java.time.ZoneOffset;
 import java.time.ZonedDateTime;
 import java.time.format.DateTimeFormatter;
 import java.util.ArrayList;
@@ -38,12 +36,12 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.TreeMap;
 import java.util.UUID;
 import java.util.concurrent.TimeUnit;
 
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.filter.OrderByExpression;
 import org.apache.qpid.server.filter.SelectorParsingException;
@@ -64,36 +62,36 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
         VIPER
     };
 
-    private final List<ConfiguredObject<?>> _objects = new ArrayList<>();
+    private List<ConfiguredObject<?>> _objects;
     private ConfiguredObjectQuery _query;
 
+    @BeforeEach
+    public void setUp()
+    {
+        _objects = new ArrayList<>();
+    }
+
     @Test
     public void testNoClauses_SingleResult()
     {
         final UUID objectUuid = UUID.randomUUID();
         final String objectName = "obj1";
 
-        ConfiguredObject obj1 = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, objectUuid);
-            put(ConfiguredObject.NAME, objectName);
-        }});
+        ConfiguredObject obj1 = createCO(Map.of(ConfiguredObject.ID, objectUuid, ConfiguredObject.NAME, objectName));
 
         _objects.add(obj1);
 
         _query = new ConfiguredObjectQuery(_objects, null, null);
 
         final List<String> headers = _query.getHeaders();
-        assertEquals("Unexpected headers",
-                            Lists.newArrayList(ConfiguredObject.ID, ConfiguredObject.NAME),
-                            headers);
+        assertEquals(List.of(ConfiguredObject.ID, ConfiguredObject.NAME), headers, "Unexpected headers");
 
 
         List<List<Object>> results = _query.getResults();
-        assertEquals("Unexpected number of results", (long) 1, (long) results.size());
+        assertEquals(1, (long) results.size(), "Unexpected number of results");
 
         List<Object> row = results.iterator().next();
-        assertEquals("Unexpected row", Lists.newArrayList(objectUuid, objectName), row);
+        assertEquals(List.of(objectUuid, objectName), row, "Unexpected row");
     }
 
     @Test
@@ -106,7 +104,7 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
         try
         {
             orderByExpressions = parser.parseOrderBy(orderByClause);
-            assertEquals((long) 1, (long) orderByExpressions.size());
+            assertEquals(1, (long) orderByExpressions.size());
         }
         catch (ParseException | TokenMgrError e)
         {
@@ -141,18 +139,11 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
         final UUID object2Uuid = UUID.randomUUID();
         final String object2Name = "obj2";
 
-        ConfiguredObject obj1 = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, object1Uuid);
-            put(ConfiguredObject.NAME, object1Name);
-            put("foo", "bar");
-        }});
+        ConfiguredObject obj1 = createCO(Map.of(ConfiguredObject.ID, object1Uuid,
+                ConfiguredObject.NAME, object1Name,
+                "foo", "bar"));
 
-        ConfiguredObject obj2 = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, object2Uuid);
-            put(ConfiguredObject.NAME, object2Name);
-        }});
+        ConfiguredObject obj2 = createCO(Map.of(ConfiguredObject.ID, object2Uuid, ConfiguredObject.NAME, object2Name));
 
         _objects.add(obj1);
         _objects.add(obj2);
@@ -160,14 +151,14 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
         _query = new ConfiguredObjectQuery(_objects, null, null);
 
         List<List<Object>> results = _query.getResults();
-        assertEquals("Unexpected number of results", (long) 2, (long) results.size());
+        assertEquals(2, (long) results.size(), "Unexpected number of results");
 
         final Iterator<List<Object>> iterator = results.iterator();
         List<Object> row1 = iterator.next();
-        assertEquals("Unexpected row", Lists.newArrayList(object1Uuid, object1Name), row1);
+        assertEquals(List.of(object1Uuid, object1Name), row1, "Unexpected row");
 
         List<Object> row2 = iterator.next();
-        assertEquals("Unexpected row", Lists.newArrayList(object2Uuid, object2Name), row2);
+        assertEquals(List.of(object2Uuid, object2Name), row2, "Unexpected row");
     }
 
     @Test
@@ -175,11 +166,7 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
     {
         final UUID objectUuid = UUID.randomUUID();
 
-        ConfiguredObject obj = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, objectUuid);
-            put(NUMBER_ATTR, 1234);
-        }});
+        ConfiguredObject obj = createCO(Map.of(ConfiguredObject.ID, objectUuid, NUMBER_ATTR, 1234));
 
         _objects.add(obj);
 
@@ -188,30 +175,27 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
                                            null);
 
         List<List<Object>> results = _query.getResults();
-        assertEquals("Unexpected number of results", (long) 1, (long) results.size());
+        assertEquals(1, (long) results.size(), "Unexpected number of results");
 
         final List<String> headers = _query.getHeaders();
-        assertEquals("Unexpected headers", Lists.newArrayList(ConfiguredObject.ID, NUMBER_ATTR), headers);
+        assertEquals(List.of(ConfiguredObject.ID, NUMBER_ATTR), headers, "Unexpected headers");
 
         final Iterator<List<Object>> iterator = results.iterator();
         List<Object> row = iterator.next();
-        assertEquals("Unexpected row", Lists.newArrayList(objectUuid, 1234), row);
+        assertEquals(List.of(objectUuid, 1234), row, "Unexpected row");
     }
 
     @Test
     public void testSelectClause_NonExistingColumn()
     {
-       ConfiguredObject obj = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, UUID.randomUUID());
-        }});
+       ConfiguredObject obj = createCO(Map.of(ConfiguredObject.ID, UUID.randomUUID()));
         _objects.add(obj);
 
         _query = new ConfiguredObjectQuery(_objects, "foo", null);
         List<List<Object>> results = _query.getResults();
-        assertEquals("Unexpected number of results", (long) 1, (long) results.size());
-        assertEquals("Unexpected headers", Collections.singletonList("foo"), _query.getHeaders());
-        assertEquals("Unexpected row", Collections.singletonList(null), results.get(0));
+        assertEquals(1, (long) results.size(), "Unexpected number of results");
+        assertEquals(List.of("foo"), _query.getHeaders(), "Unexpected headers");
+        assertEquals(Collections.singletonList(null), results.get(0), "Unexpected row");
     }
 
     @Test
@@ -219,12 +203,9 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
     {
         final UUID objectUuid = UUID.randomUUID();
 
-        ConfiguredObject obj = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, objectUuid);
-            put(ConfiguredObject.NAME, "myObj");
-            put(NUMBER_ATTR, 1234);
-        }});
+        ConfiguredObject obj = createCO(Map.of(ConfiguredObject.ID, objectUuid,
+                ConfiguredObject.NAME, "myObj",
+                NUMBER_ATTR, 1234));
 
         _objects.add(obj);
 
@@ -233,14 +214,14 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
                                            null);
 
         List<List<Object>> results = _query.getResults();
-        assertEquals("Unexpected number of results", (long) 1, (long) results.size());
+        assertEquals(1, (long) results.size(), "Unexpected number of results");
 
         final List<String> headers = _query.getHeaders();
-        assertEquals("Unexpected headers", Lists.newArrayList(ConfiguredObject.ID, "alias"), headers);
+        assertEquals(List.of(ConfiguredObject.ID, "alias"), headers, "Unexpected headers");
 
         final Iterator<List<Object>> iterator = results.iterator();
         List<Object> row = iterator.next();
-        assertEquals("Unexpected row", Lists.newArrayList(objectUuid, "myObj1234"), row);
+        assertEquals(List.of(objectUuid, "myObj1234"), row, "Unexpected row");
     }
 
     @Test
@@ -249,17 +230,9 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
         final UUID objectUuid = UUID.randomUUID();
         final String objectName = "obj2";
 
-        ConfiguredObject nonMatch = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, UUID.randomUUID());
-            put(ConfiguredObject.NAME, "obj1");
-        }});
+        ConfiguredObject nonMatch = createCO(Map.of(ConfiguredObject.ID, UUID.randomUUID(), ConfiguredObject.NAME, "obj1"));
 
-        ConfiguredObject match = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, objectUuid);
-            put(ConfiguredObject.NAME, objectName);
-        }});
+        ConfiguredObject match = createCO(Map.of(ConfiguredObject.ID, objectUuid, ConfiguredObject.NAME, objectName));
 
         _objects.add(nonMatch);
         _objects.add(match);
@@ -267,16 +240,14 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
         _query = new ConfiguredObjectQuery(_objects, null, String.format("name = '%s'", objectName));
 
         final List<String> headers = _query.getHeaders();
-        assertEquals("Unexpected headers",
-                            Lists.newArrayList(ConfiguredObject.ID, ConfiguredObject.NAME),
-                            headers);
+        assertEquals(List.of(ConfiguredObject.ID, ConfiguredObject.NAME), headers, "Unexpected headers");
 
         List<List<Object>> results = _query.getResults();
-        assertEquals("Unexpected number of results", (long) 1, (long) results.size());
+        assertEquals(1, (long) results.size(), "Unexpected number of results");
 
         final Iterator<List<Object>> iterator = results.iterator();
         List<Object> row = iterator.next();
-        assertEquals("Unexpected row", objectUuid, row.get(0));
+        assertEquals(objectUuid, row.get(0), "Unexpected row");
     }
 
     @Test
@@ -288,17 +259,11 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
         final Date yesterday = new Date(now - oneDayInMillis);
         final Date tomorrow = new Date(now + oneDayInMillis);
 
-        ConfiguredObject nonMatch = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, UUID.randomUUID());
-            put(DATE_ATTR, yesterday);
-        }});
+        ConfiguredObject nonMatch = createCO(Map.of(ConfiguredObject.ID, UUID.randomUUID(),
+                DATE_ATTR, yesterday));
 
-        ConfiguredObject match = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, objectUuid);
-            put(DATE_ATTR, tomorrow);
-        }});
+        ConfiguredObject match = createCO(Map.of(ConfiguredObject.ID, objectUuid,
+                DATE_ATTR, tomorrow));
 
         _objects.add(nonMatch);
         _objects.add(match);
@@ -308,11 +273,11 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
                                            String.format("%s > NOW()", DATE_ATTR));
 
         List<List<Object>> results = _query.getResults();
-        assertEquals("Unexpected number of results", (long) 1, (long) results.size());
+        assertEquals(1, (long) results.size(), "Unexpected number of results");
 
         final Iterator<List<Object>> iterator = results.iterator();
         List<Object> row = iterator.next();
-        assertEquals("Unexpected row", objectUuid, row.get(0));
+        assertEquals(objectUuid, row.get(0), "Unexpected row");
     }
 
     @Test
@@ -325,17 +290,9 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
 
         final UUID objectUuid = UUID.randomUUID();
 
-        ConfiguredObject nonMatch = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, UUID.randomUUID());
-            put(DATE_ATTR, new Date(0));
-        }});
+        ConfiguredObject nonMatch = createCO(Map.of(ConfiguredObject.ID, UUID.randomUUID(), DATE_ATTR, new Date(0)));
 
-        ConfiguredObject match = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, objectUuid);
-            put(DATE_ATTR, new Date(now));
-        }});
+        ConfiguredObject match = createCO(Map.of(ConfiguredObject.ID, objectUuid, DATE_ATTR, new Date(now)));
 
         _objects.add(nonMatch);
         _objects.add(match);
@@ -346,11 +303,11 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
                                                          nowIso8601Str));
 
         List<List<Object>> results = _query.getResults();
-        assertEquals("Unexpected number of results", (long) 1, (long) results.size());
+        assertEquals(1, (long) results.size(), "Unexpected number of results");
 
         final Iterator<List<Object>> iterator = results.iterator();
         List<Object> row = iterator.next();
-        assertEquals("Unexpected row", objectUuid, row.get(0));
+        assertEquals(objectUuid, row.get(0), "Unexpected row");
     }
 
     @Test
@@ -358,11 +315,7 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
     {
         final UUID objectUuid = UUID.randomUUID();
 
-        ConfiguredObject match = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, objectUuid);
-            put(DATE_ATTR, new Date(0));
-        }});
+        ConfiguredObject match = createCO(Map.of(ConfiguredObject.ID, objectUuid, DATE_ATTR, new Date(0)));
 
         _objects.add(match);
 
@@ -374,11 +327,11 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
                                                          "-PT10H"));
 
         List<List<Object>> results = _query.getResults();
-        assertEquals("Unexpected number of results", (long) 1, (long) results.size());
+        assertEquals(1, (long) results.size(), "Unexpected number of results");
 
         final Iterator<List<Object>> iterator = results.iterator();
         List<Object> row = iterator.next();
-        assertEquals("Unexpected row", objectUuid, row.get(0));
+        assertEquals(objectUuid, row.get(0), "Unexpected row");
     }
 
     @Test
@@ -386,11 +339,7 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
     {
         final UUID objectUuid = UUID.randomUUID();
 
-        ConfiguredObject match = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, objectUuid);
-            put(DATE_ATTR, new Date(0));
-        }});
+        ConfiguredObject match = createCO(Map.of(ConfiguredObject.ID, objectUuid, DATE_ATTR, new Date(0)));
 
         _objects.add(match);
 
@@ -399,11 +348,11 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
                                            null);
 
         List<List<Object>> results = _query.getResults();
-        assertEquals("Unexpected number of results", (long) 1, (long) results.size());
+        assertEquals(1, (long) results.size(), "Unexpected number of results");
 
         final Iterator<List<Object>> iterator = results.iterator();
         List<Object> row = iterator.next();
-        assertEquals("Unexpected row", Lists.newArrayList(objectUuid, "1970-01-01T00:00:00Z"), row);
+        assertEquals(List.of(objectUuid, "1970-01-01T00:00:00Z"), row, "Unexpected row");
     }
 
     @Test
@@ -411,11 +360,7 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
     {
         final UUID objectUuid = UUID.randomUUID();
 
-        ConfiguredObject match = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, objectUuid);
-            put(DATE_ATTR, new Date(0));
-        }});
+        ConfiguredObject match = createCO(Map.of(ConfiguredObject.ID, objectUuid, DATE_ATTR, new Date(0)));
 
         _objects.add(match);
 
@@ -427,11 +372,11 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
                                            null);
 
         List<List<Object>> results = _query.getResults();
-        assertEquals("Unexpected number of results", (long) 1, (long) results.size());
+        assertEquals(1, (long) results.size(), "Unexpected number of results");
 
         final Iterator<List<Object>> iterator = results.iterator();
         List<Object> row = iterator.next();
-        assertEquals("Unexpected row", Lists.newArrayList(objectUuid, "1970-01-01 UTC"), row);
+        assertEquals(List.of(objectUuid, "1970-01-01 UTC"), row, "Unexpected row");
     }
 
     @Test
@@ -439,12 +384,9 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
     {
         final UUID objectUuid = UUID.randomUUID();
 
-        ConfiguredObject obj = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, objectUuid);
-            put(ENUM_ATTR, Snakes.PYTHON);
-            put(ENUM2_ATTR, Snakes.PYTHON);
-        }});
+        ConfiguredObject obj = createCO(Map.of(ConfiguredObject.ID, objectUuid,
+                ENUM_ATTR, Snakes.PYTHON,
+                ENUM2_ATTR, Snakes.PYTHON));
 
         _objects.add(obj);
 
@@ -453,42 +395,38 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
                                            String.format("%s = '%s'", ENUM_ATTR, Snakes.PYTHON));
 
         List<List<Object>> results = _query.getResults();
-        assertEquals("Unexpected number of results - enumAttr equality with enum constant",
-                            (long) 1,
-                            (long) results.size());
+        assertEquals(1, (long) results.size(),
+                "Unexpected number of results - enumAttr equality with enum constant");
 
         List<Object> row = _query.getResults().iterator().next();
-        assertEquals("Unexpected row", objectUuid, row.get(0));
+        assertEquals(objectUuid, row.get(0), "Unexpected row");
 
         _query = new ConfiguredObjectQuery(_objects,
                                            String.format("%s", ConfiguredObject.ID),
                                            String.format("'%s' = %s", Snakes.PYTHON, ENUM_ATTR));
 
         results = _query.getResults();
-        assertEquals("Unexpected number of results - enum constant equality with enumAttr",
-                            (long) 1,
-                            (long) results.size());
+        assertEquals(1, (long) results.size(),
+                     "Unexpected number of results - enum constant equality with enumAttr");
 
         row = _query.getResults().iterator().next();
-        assertEquals("Unexpected row", objectUuid, row.get(0));
+        assertEquals(objectUuid, row.get(0), "Unexpected row");
 
         _query = new ConfiguredObjectQuery(_objects,
                                            String.format("%s", ConfiguredObject.ID),
                                            String.format("%s <> '%s'", ENUM_ATTR, "toad"));
 
         results = _query.getResults();
-        assertEquals("Unexpected number of results - enumAttr not equal enum constant",
-                            (long) 1,
-                            (long) results.size());
+        assertEquals(1, (long) results.size(),
+                "Unexpected number of results - enumAttr not equal enum constant");
 
         _query = new ConfiguredObjectQuery(_objects,
                                            String.format("%s", ConfiguredObject.ID),
                                            String.format("%s = %s", ENUM_ATTR, ENUM2_ATTR));
 
         results = _query.getResults();
-        assertEquals("Unexpected number of results - two attributes of type enum",
-                            (long) 1,
-                            (long) results.size());
+        assertEquals(1, (long) results.size(),
+                "Unexpected number of results - two attributes of type enum");
     }
 
     @Test
@@ -496,12 +434,9 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
     {
         final UUID objectUuid = UUID.randomUUID();
 
-        ConfiguredObject obj = createCO(new HashMap<String, Object>()
-        {{
-            put(ConfiguredObject.ID, objectUuid);
-            put(ENUM_ATTR, Snakes.PYTHON);
-            put(ENUM2_ATTR, Snakes.PYTHON);
-        }});
+        ConfiguredObject obj = createCO(Map.of(ConfiguredObject.ID, objectUuid,
+                ENUM_ATTR, Snakes.PYTHON,
+                ENUM2_ATTR, Snakes.PYTHON));
 
         _objects.add(obj);
 
@@ -512,25 +447,24 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
                                                          "toad", Snakes.VIPER, Snakes.PYTHON));
 
         List<List<Object>> results = _query.getResults();
-        assertEquals("Unexpected number of results - emumAttr with set including the enum's constants",
-                            (long) 1,
-                            (long) results.size());
+        assertEquals(1, (long) results.size(),
+                "Unexpected number of results - emumAttr with set including the enum's constants");
 
         _query = new ConfiguredObjectQuery(_objects,
                                            String.format("%s", ConfiguredObject.ID),
                                            String.format("%s in (%s)", ENUM_ATTR, ENUM2_ATTR));
 
         results = _query.getResults();
-        assertEquals("Unexpected number of results - enumAttr with set including enum2Attr",
-                            (long) 1,
-                            (long) results.size());
+        assertEquals(1, (long) results.size(),
+                "Unexpected number of results - enumAttr with set including enum2Attr");
 
         _query = new ConfiguredObjectQuery(_objects,
                                            String.format("%s", ConfiguredObject.ID),
                                            String.format("'%s' in (%s)", Snakes.PYTHON, ENUM_ATTR));
 
         results = _query.getResults();
-        assertEquals("Unexpected number of results - attribute within the set", (long) 1, (long) results.size());
+        assertEquals(1, (long) results.size(),
+                "Unexpected number of results - attribute within the set");
     }
 
     @Test
@@ -557,14 +491,11 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
         for (int i = 0; i < NUMBER_OF_OBJECTS; ++i)
         {
             final int foo = (i + 1) % NUMBER_OF_OBJECTS;
-            ConfiguredObject object = createCO(new HashMap<String, Object>()
-            {{
-                put("foo", foo);
-            }});
+            ConfiguredObject object = createCO(Map.of("foo", foo));
             _objects.add(object);
         }
 
-        ConfiguredObject object = createCO(new HashMap<String, Object>()
+        ConfiguredObject object = createCO(new HashMap<>()
         {{
             put("foo", null);
         }});
@@ -589,20 +520,11 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
     @Test
     public void testAliasInOrderByClause()
     {
-        _objects.add(createCO(new HashMap<String, Object>()
-        {{
-            put("foo", 2);
-        }}));
+        _objects.add(createCO(Map.of("foo", 2)));
 
-        _objects.add(createCO(new HashMap<String, Object>()
-        {{
-            put("foo", 1);
-        }}));
+        _objects.add(createCO(Map.of("foo", 1)));
 
-        _objects.add(createCO(new HashMap<String, Object>()
-        {{
-            put("foo", 4);
-        }}));
+        _objects.add(createCO(Map.of("foo", 4)));
 
         _query = new ConfiguredObjectQuery(_objects, "foo AS bar", null, "bar ASC");
         assertQueryResults(new Object[][]{{1}, {2}, {4}}, _query.getResults());
@@ -611,17 +533,9 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
     @Test
     public void testExpressionToTermsOfAliasInOrderByClause()
     {
-        _objects.add(createCO(new HashMap<String, Object>()
-        {{
-            put("foo1", "A");
-            put("foo2", "B");
-        }}));
+        _objects.add(createCO(Map.of("foo1", "A", "foo2", "B")));
 
-        _objects.add(createCO(new HashMap<String, Object>()
-        {{
-            put("foo1", "A");
-            put("foo2", "A");
-        }}));
+        _objects.add(createCO(Map.of("foo1", "A", "foo2", "A")));
 
         _query = new ConfiguredObjectQuery(_objects, "foo1 AS bar1, foo2", null, "CONCAT(bar, foo2) ASC");
         assertQueryResults(new Object[][]{{"A", "A"}, {"A", "B"}}, _query.getResults());
@@ -630,20 +544,11 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
     @Test
     public void testDelimitedAliasInOrderByClause()
     {
-        _objects.add(createCO(new HashMap<String, Object>()
-        {{
-            put("foo", 2);
-        }}));
+        _objects.add(createCO(Map.of("foo", 2)));
 
-        _objects.add(createCO(new HashMap<String, Object>()
-        {{
-            put("foo", 1);
-        }}));
+        _objects.add(createCO(Map.of("foo", 1)));
 
-        _objects.add(createCO(new HashMap<String, Object>()
-        {{
-            put("foo", 4);
-        }}));
+        _objects.add(createCO(Map.of("foo", 4)));
 
         _query = new ConfiguredObjectQuery(_objects, "foo AS \"yogi bear\"", null, "\"yogi bear\" DESC");
         assertQueryResults(new Object[][]{{4}, {2}, {1}}, _query.getResults());
@@ -654,25 +559,13 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
     {
         ConfiguredObject object;
 
-        object = createCO(new HashMap<String, Object>()
-        {{
-            put("foo", 1);
-            put("bar", 1);
-        }});
+        object = createCO(Map.of("foo", 1, "bar", 1));
         _objects.add(object);
 
-        object = createCO(new HashMap<String, Object>()
-        {{
-            put("foo", 1);
-            put("bar", 2);
-        }});
+        object = createCO(Map.of("foo", 1, "bar", 2));
         _objects.add(object);
 
-        object = createCO(new HashMap<String, Object>()
-        {{
-            put("foo", 2);
-            put("bar", 0);
-        }});
+        object = createCO(Map.of("foo", 2, "bar", 0));
         _objects.add(object);
 
         _query = new ConfiguredObjectQuery(_objects, "foo,bar", null, "foo, bar");
@@ -744,10 +637,7 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
         for(int i=0;i<numberOfTestObjects;i++)
         {
             final String name = "test-" + i;
-            ConfiguredObject object = createCO(new HashMap<String, Object>()
-            {{
-                put("name", name);
-            }});
+            ConfiguredObject object = createCO(Map.of("name", name));
             _objects.add(object);
         }
 
@@ -780,27 +670,26 @@ public class ConfiguredObjectQueryTest extends UnitTestBase
                                     final List<List<Object>> results)
     {
         final int rows = expectedAttributes.length;
-        assertEquals("Unexpected number of result rows", (long) rows, (long) results.size());
+        assertEquals((long) rows, (long) results.size(), "Unexpected number of result rows");
         if (rows > 0)
         {
             final int cols = expectedAttributes[0].length;
             for (int row = 0; row < rows; ++row)
             {
-                assertEquals("Unexpected number of result columns", (long) cols, (long) results.get(row).size());
+                assertEquals((long) cols, (long) results.get(row).size(), "Unexpected number of result columns");
                 for (int col = 0; col < cols; ++col)
                 {
-                    assertEquals("Unexpected row order", expectedAttributes[row][col], results.get(row).get(col));
+                    assertEquals(expectedAttributes[row][col], results.get(row).get(col), "Unexpected row order");
                 }
             }
         }
     }
 
-    private ConfiguredObject createCO(final HashMap<String, Object> map)
+    private ConfiguredObject createCO(final Map<String, Object> map)
     {
         ConfiguredObject object = mock(ConfiguredObject.class);
 
-        Map<String, Object> orderedMap = Maps.newTreeMap();
-        orderedMap.putAll(map);
+        Map<String, Object> orderedMap = new TreeMap<>(map);
 
         when(object.getAttributeNames()).thenReturn(orderedMap.keySet());
         for(String attributeName : orderedMap.keySet())
