@@ -18,31 +18,19 @@
  */
 package org.apache.qpid.disttest.results.formatting;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+
 import java.io.BufferedReader;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 
-import org.junit.Assert;
-
 import org.apache.qpid.disttest.controller.ResultsForAllTests;
 import org.apache.qpid.disttest.results.ResultsTestFixture;
 
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.After;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.test.utils.UnitTestBase;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.fail;
-import static org.junit.Assert.assertNotNull;
-
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
 
 public class CSVFormatterTest extends UnitTestBase
 {
@@ -69,7 +57,7 @@ public class CSVFormatterTest extends UnitTestBase
         StringBuilder output = new StringBuilder();
 
         BufferedReader br = new BufferedReader(new InputStreamReader(is));
-        String line = null;
+        String line;
         while((line = br.readLine()) != null)
         {
             output.append(line);
