@@ -24,28 +24,15 @@ import static org.apache.qpid.disttest.charting.definition.SeriesDefinitionCreat
 import static org.apache.qpid.disttest.charting.definition.SeriesDefinitionCreator.SERIES_LEGEND_KEY_FORMAT;
 import static org.apache.qpid.disttest.charting.definition.SeriesDefinitionCreator.SERIES_STATEMENT_KEY_FORMAT;
 import static org.apache.qpid.disttest.charting.definition.SeriesDefinitionCreator.SERIES_STROKE_WIDTH_FORMAT;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
 import java.util.List;
 import java.util.Properties;
 
-import org.junit.Assert;
-
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.After;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.test.utils.UnitTestBase;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.fail;
-import static org.junit.Assert.assertNotNull;
-
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
 
 public class SeriesDefinitionCreatorTest extends UnitTestBase
 {
@@ -55,7 +42,7 @@ public class SeriesDefinitionCreatorTest extends UnitTestBase
     private static final String TEST_SERIES_1_LEGEND_WITH_SYSPROP = "SERIES_1_LEGEND ${SeriesDefinitionProp}";
     private static final String TEST_SERIES_1_DIR = "SERIES_1_DIR";
     private static final String TEST_SERIES_1_COLOUR_NAME = "seriesColourName";
-    private static final Integer TEST_SERIES_1_STROKE_WIDTH = 1;;
+    private static final Integer TEST_SERIES_1_STROKE_WIDTH = 1;
 
     private static final String TEST_SERIES_1_DIR_WITH_SYSPROP = "${SeriesDefinitionProp}/mydir";
 
@@ -63,22 +50,24 @@ public class SeriesDefinitionCreatorTest extends UnitTestBase
     private static final String TEST_SERIES_2_LEGEND = "SERIES_2_LEGEND";
     private static final String TEST_SERIES_2_DIR = "SERIES_2_DIR";
 
-    private final Properties _properties = new Properties();
+    private Properties _properties;
 
-    private final SeriesDefinitionCreator _seriesDefinitionLoader = new SeriesDefinitionCreator();
+    private SeriesDefinitionCreator _seriesDefinitionLoader;
 
-    @Before
-    public void setUp() throws Exception
+    @BeforeEach
+    public void setUp()
     {
+        _properties = new Properties();
+        _seriesDefinitionLoader = new SeriesDefinitionCreator();
     }
 
     @Test
-    public void testOneSeriesDefinition() throws Exception
+    public void testOneSeriesDefinition()
     {
         createTestProperties(1, TEST_SERIES_1_SELECT_STATEMENT, TEST_SERIES_1_LEGEND, TEST_SERIES_1_DIR, TEST_SERIES_1_COLOUR_NAME, TEST_SERIES_1_STROKE_WIDTH);
 
         List<SeriesDefinition> definitions = _seriesDefinitionLoader.createFromProperties(_properties);
-        assertEquals((long) 1, (long) definitions.size());
+        assertEquals(1, definitions.size());
 
         SeriesDefinition definition = definitions.get(0);
         assertEquals(TEST_SERIES_1_SELECT_STATEMENT, definition.getSeriesStatement());
@@ -89,13 +78,13 @@ public class SeriesDefinitionCreatorTest extends UnitTestBase
     }
 
     @Test
-    public void testTwoSeriesDefinitions() throws Exception
+    public void testTwoSeriesDefinitions()
     {
         createTestProperties(1, TEST_SERIES_1_SELECT_STATEMENT, TEST_SERIES_1_LEGEND, TEST_SERIES_1_DIR, TEST_SERIES_1_COLOUR_NAME, TEST_SERIES_1_STROKE_WIDTH);
         createTestProperties(2, TEST_SERIES_2_SELECT_STATEMENT, TEST_SERIES_2_LEGEND, TEST_SERIES_2_DIR, null, null);
 
         List<SeriesDefinition> definitions = _seriesDefinitionLoader.createFromProperties(_properties);
-        assertEquals((long) 2, (long) definitions.size());
+        assertEquals(2, definitions.size());
 
         SeriesDefinition seriesDefinition1 = definitions.get(0);
         assertEquals(TEST_SERIES_1_SELECT_STATEMENT, seriesDefinition1.getSeriesStatement());
@@ -109,30 +98,30 @@ public class SeriesDefinitionCreatorTest extends UnitTestBase
     }
 
     @Test
-    public void testNonSequentialSeriesDefinitionsIgnored() throws Exception
+    public void testNonSequentialSeriesDefinitionsIgnored()
     {
         createTestProperties(1, TEST_SERIES_1_SELECT_STATEMENT, TEST_SERIES_1_LEGEND, TEST_SERIES_1_DIR, TEST_SERIES_1_COLOUR_NAME, TEST_SERIES_1_STROKE_WIDTH);
         createTestProperties(3, TEST_SERIES_2_SELECT_STATEMENT, TEST_SERIES_2_LEGEND, TEST_SERIES_2_DIR, null, null);
 
         List<SeriesDefinition> definitions = _seriesDefinitionLoader.createFromProperties(_properties);
-        assertEquals((long) 1, (long) definitions.size());
+        assertEquals(1, definitions.size());
     }
 
     @Test
-    public void testSeriesDirectoryAndNameSubstitution() throws Exception
+    public void testSeriesDirectoryAndNameSubstitution()
     {
         setTestSystemProperty(SYSTEM_PROPERTY_NAME, "propValue");
         createTestProperties(1, TEST_SERIES_1_SELECT_STATEMENT, TEST_SERIES_1_LEGEND_WITH_SYSPROP, TEST_SERIES_1_DIR_WITH_SYSPROP, null, null);
 
         List<SeriesDefinition> definitions = _seriesDefinitionLoader.createFromProperties(_properties);
-        assertEquals((long) 1, (long) definitions.size());
+        assertEquals(1, definitions.size());
 
         SeriesDefinition seriesDefinition1 = definitions.get(0);
         assertEquals("propValue/mydir", seriesDefinition1.getSeriesDirectory());
         assertEquals("SERIES_1_LEGEND propValue", seriesDefinition1.getSeriesLegend());
     }
 
-    private void createTestProperties(int index, String selectStatement, String seriesLegend, String seriesDir, String seriesColourName, Integer seriesStrokeWidth) throws Exception
+    private void createTestProperties(int index, String selectStatement, String seriesLegend, String seriesDir, String seriesColourName, Integer seriesStrokeWidth)
     {
         _properties.setProperty(String.format(SERIES_STATEMENT_KEY_FORMAT, index), selectStatement);
         _properties.setProperty(String.format(SERIES_LEGEND_KEY_FORMAT, index), seriesLegend);
@@ -146,5 +135,4 @@ public class SeriesDefinitionCreatorTest extends UnitTestBase
             _properties.setProperty(String.format(SERIES_STROKE_WIDTH_FORMAT, index), seriesStrokeWidth.toString());
         }
     }
-
 }
