@@ -32,15 +32,12 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.List;
+import java.util.concurrent.CompletableFuture;
+import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.TimeUnit;
 import java.util.stream.Collectors;
 
-import com.google.common.collect.Lists;
-import com.google.common.util.concurrent.ListenableFuture;
-import com.google.common.util.concurrent.ListeningExecutorService;
-import com.google.common.util.concurrent.MoreExecutors;
-
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
@@ -68,12 +65,12 @@ public class EndToEndConversionTestBase extends BrokerAdminUsingTestBase
     private static final int SERVER_SOCKET_TIMEOUT = 30000;
     private static final Logger LOGGER = LoggerFactory.getLogger(EndToEndConversionTestBase.class);
     private static final Logger CLIENT_LOGGER = LoggerFactory.getLogger(Client.class);
-    private ListeningExecutorService _executorService;
+    private ExecutorService _executorService;
 
     @BeforeEach
     public void setupExecutor()
     {
-        _executorService = MoreExecutors.listeningDecorator(Executors.newCachedThreadPool());
+        _executorService = Executors.newCachedThreadPool();
     }
 
     @AfterEach
@@ -96,7 +93,7 @@ public class EndToEndConversionTestBase extends BrokerAdminUsingTestBase
         System.out.println("LQDEBUG: " + ClasspathQuery.getCacheStats());
     }
 
-    protected ListenableFuture<ClientResult> runPublisher(final List<ClientInstruction> clientInstructions)
+    protected CompletableFuture<ClientResult> runPublisher(final List<ClientInstruction> clientInstructions)
     {
         List<String> gavs = Arrays.asList(System.getProperty("qpid.systests.end_to_end_conversion.publisherGavs",
                                                              "org.apache.qpid:qpid-jms-client:LATEST")
@@ -105,13 +102,13 @@ public class EndToEndConversionTestBase extends BrokerAdminUsingTestBase
                 "qpid.systests.end_to_end_conversion.publisherAdditionalJavaArguments",
                 "").split(" ")).filter(s -> !s.isEmpty()).collect(Collectors.toList());
 
-        return _executorService.submit(() -> {
+        return CompletableFuture.supplyAsync(() -> {
             Thread.currentThread().setName("Publisher");
             return runClient(gavs, additionalJavaArgs, clientInstructions);
-        });
+        }, _executorService);
     }
 
-    protected ListenableFuture<ClientResult> runSubscriber(final List<ClientInstruction> clientInstructions)
+    protected CompletableFuture<ClientResult> runSubscriber(final List<ClientInstruction> clientInstructions)
     {
         List<String> gavs = Arrays.asList(System.getProperty("qpid.systests.end_to_end_conversion.subscriberGavs",
                                                              "org.apache.qpid:qpid-client:LATEST,org.apache.geronimo.specs:geronimo-jms_1.1_spec:1.1.1")
@@ -121,10 +118,10 @@ public class EndToEndConversionTestBase extends BrokerAdminUsingTestBase
                 "qpid.systests.end_to_end_conversion.subscriberAdditionalJavaArguments",
                 "-Dqpid.amqp.version=0-9-1").split(" ")).filter(s -> !s.isEmpty()).collect(Collectors.toList());
 
-        return _executorService.submit(() -> {
+        return CompletableFuture.supplyAsync(() -> {
             Thread.currentThread().setName("Subscriber");
             return runClient(gavs, additionalJavaArgs, clientInstructions);
-        });
+        }, _executorService);
     }
 
     private List<ClientInstruction> amendClientInstructions(List<ClientInstruction> clientInstructions,
@@ -141,7 +138,7 @@ public class EndToEndConversionTestBase extends BrokerAdminUsingTestBase
                 LOGGER.warn(String.format("first client instructions should be a 'ConfigureDestination' but is '%s'!",
                                           clientInstructions.get(0).getClass().getSimpleName()));
             }
-            if (clientInstructions.stream().filter(item -> item instanceof ConfigureJndiContext).count() != 0)
+            if (clientInstructions.stream().anyMatch(item -> item instanceof ConfigureJndiContext))
             {
                 LOGGER.warn("Test should not set a 'ConfigureContext' client instruction!"
                             + " This is set by the base class.");
@@ -237,14 +234,18 @@ public class EndToEndConversionTestBase extends BrokerAdminUsingTestBase
         {
             serverSocket.setSoTimeout(SERVER_SOCKET_TIMEOUT);
             String classPath = classpathQuery.getClasspath();
-            final List<String> arguments = Lists.newArrayList("java", "-showversion",
-                                                              "-cp", classPath);
+            final List<String> arguments = new ArrayList<>(List.of("java", "-showversion", "-cp", classPath));
+            if (System.getProperty("os.name").toLowerCase().contains("windows"))
+            {
+                arguments.add("-Djavax.net.ssl.trustStoreType=WINDOWS-ROOT");
+            }
             arguments.addAll(additionalJavaArguments);
             arguments.add(classpathQuery.getClientClass().getName());
             arguments.add(String.valueOf(serverSocket.getLocalPort()));
 
             LOGGER.debug("starting client process with arguments: {}", arguments);
             ProcessBuilder processBuilder = new ProcessBuilder(arguments);
+            processBuilder.redirectErrorStream(true);
             processBuilder.environment().put("PN_TRACE_FRM", "true");
             Process p = processBuilder.start();
             try (final InputStream pInputStream = p.getInputStream();
@@ -262,9 +263,8 @@ public class EndToEndConversionTestBase extends BrokerAdminUsingTestBase
                     clientSocket.setSoTimeout(CLIENT_SOCKET_TIMEOUT);
                     outputStream.writeObject(clientInstructions);
                     final Object result = inputStream.readObject();
-                    if (result instanceof ClientResult)
+                    if (result instanceof ClientResult clientResult)
                     {
-                        final ClientResult clientResult = (ClientResult) result;
                         if (clientResult.getException() != null)
                         {
                             throw clientResult.getException();
@@ -288,12 +288,12 @@ public class EndToEndConversionTestBase extends BrokerAdminUsingTestBase
         }
         catch (RuntimeException e)
         {
-            LOGGER.debug("client process finished with exception: {}", e);
+            LOGGER.debug("client process finished with exception:", e);
             throw e;
         }
         catch (Exception e)
         {
-            LOGGER.error("client process finished with exception: {}", e);
+            LOGGER.error("client process finished with exception:", e);
             throw new RuntimeException(e);
         }
         finally
