@@ -1,4 +1,5 @@
 /*
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -15,43 +16,33 @@
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
+ *
  */
+package org.apache.qpid.tests.protocol.v0_10;
 
-package org.apache.qpid.tests.protocol.v1_0;
-
-import org.apache.qpid.server.protocol.v1_0.type.FrameBody;
+import org.apache.qpid.server.protocol.v0_10.transport.Method;
 import org.apache.qpid.tests.protocol.Response;
 
-public class PerformativeResponse implements Response<FrameBody>
+public class PerformativeResponse implements Response<Method>
 {
-    private final short _channelId;
-    private final FrameBody _frameBody;
+    private final Method _method;
 
-    public PerformativeResponse(final short channelId,
-                                final FrameBody frameBody)
+    public PerformativeResponse(final Method method)
     {
-        _channelId = channelId;
-        _frameBody = frameBody;
+        _method = method;
     }
 
     @Override
-    public FrameBody getBody()
+    public Method getBody()
     {
-        return _frameBody;
-    }
-
-
-    public short getChannelId()
-    {
-        return _channelId;
+        return _method;
     }
 
     @Override
     public String toString()
     {
         return "PerformativeResponse{" +
-               "_channelId=" + _channelId +
-               ", _frameBody=" + _frameBody +
+               "_method=" + _method +
                '}';
     }
 }
