@@ -30,8 +30,8 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.protocol.v0_10.transport.ConnectionOpenOk;
 import org.apache.qpid.server.protocol.v0_10.transport.ConnectionTune;
@@ -48,7 +48,7 @@ import org.apache.qpid.tests.utils.BrokerAdminUsingTestBase;
 public class LargeApplicationHeadersTest extends BrokerAdminUsingTestBase
 {
 
-    @Before
+    @BeforeEach
     public void setUp()
     {
         getBrokerAdmin().createQueue(BrokerAdmin.TEST_QUEUE_NAME);
