@@ -27,8 +27,8 @@ import static org.hamcrest.MatcherAssert.assertThat;
 import java.util.stream.IntStream;
 
 import org.hamcrest.core.IsEqual;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.protocol.v0_10.transport.ExecutionErrorCode;
 import org.apache.qpid.server.protocol.v0_10.transport.ExecutionException;
@@ -46,7 +46,7 @@ import org.apache.qpid.tests.utils.ConfigItem;
 public class MaximumMessageSizeTest extends BrokerAdminUsingTestBase
 {
 
-    @Before
+    @BeforeEach
     public void setUp()
     {
         getBrokerAdmin().createQueue(BrokerAdmin.TEST_QUEUE_NAME);
