@@ -24,12 +24,11 @@ import static org.hamcrest.CoreMatchers.equalTo;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.MatcherAssert.assertThat;
 
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.protocol.v0_8.AMQShortString;
 import org.apache.qpid.server.protocol.v0_8.transport.BasicConsumeOkBody;
@@ -47,14 +46,14 @@ import org.apache.qpid.tests.utils.BrokerAdminUsingTestBase;
 public class LargeHeadersTest extends BrokerAdminUsingTestBase
 {
 
-    @Before
+    @BeforeEach
     public void setUp()
     {
         getBrokerAdmin().createQueue(BrokerAdmin.TEST_QUEUE_NAME);
     }
 
-    @Test
     /** Tests boundary case where headers exactly fill the content header frame */
+    @Test
     public void headersFillContentHeaderFrame() throws Exception
     {
 
@@ -69,7 +68,7 @@ public class LargeHeadersTest extends BrokerAdminUsingTestBase
             final String headerName = "test";
             final int headerValueSize = (int) (connTune.getFrameMax() - calculateContentHeaderFramingOverhead(headerName));
             final String headerValue = generateLongString(headerValueSize);
-            final Map<String, Object> messageHeaders = Collections.singletonMap(headerName, headerValue);
+            final Map<String, Object> messageHeaders = Map.of(headerName, headerValue);
 
             interaction.connection().tuneOk()
                        .connection().open()
@@ -108,7 +107,7 @@ public class LargeHeadersTest extends BrokerAdminUsingTestBase
     private String generateLongString(final int count)
     {
         String pattern = "abcde";
-        String str = String.join("", Collections.nCopies(count / pattern.length(), pattern)) + pattern.substring(0, count % pattern.length());
+        String str = pattern.repeat(count / pattern.length()) + pattern.substring(0, count % pattern.length());
         assertThat(str.length(), is(equalTo(count)));
         return str;
     }
