@@ -27,14 +27,13 @@ import static org.hamcrest.CoreMatchers.equalTo;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.greaterThan;
 import static org.hamcrest.Matchers.is;
-import static org.junit.Assume.assumeThat;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.bytebuffer.QpidByteBuffer;
 import org.apache.qpid.server.protocol.v1_0.codec.StringWriter;
@@ -77,8 +76,8 @@ public class DecodeErrorTest extends BrokerAdminUsingTestBase
                        .consumeResponse(Attach.class)
                        .consumeResponse(Flow.class)
                        .assertLatestResponse(Flow.class,
-                                             flow -> assumeThat(flow.getLinkCredit(),
-                                                                is(greaterThan(UnsignedInteger.ZERO))));
+                                             flow -> assumeTrue(is(greaterThan(UnsignedInteger.ZERO))
+                                                     .matches(flow.getLinkCredit())));
 
             try(final QpidByteBuffer payload = buildInvalidMessage())
             {
@@ -108,8 +107,7 @@ public class DecodeErrorTest extends BrokerAdminUsingTestBase
         {
             final Source source = new Source();
             source.setDynamic(Boolean.TRUE);
-            source.setDynamicNodeProperties(Collections.singletonMap(Symbol.valueOf("lifetime-policy"),
-                                                                     UnsignedInteger.MAX_VALUE));
+            source.setDynamicNodeProperties(Map.of(Symbol.valueOf("lifetime-policy"), UnsignedInteger.MAX_VALUE));
             final Interaction interaction = transport.newInteraction()
                                                         .negotiateOpen()
                                                         .begin().consumeResponse(Begin.class)
@@ -132,8 +130,7 @@ public class DecodeErrorTest extends BrokerAdminUsingTestBase
         {
             final Target target = new Target();
             target.setDynamic(Boolean.TRUE);
-            target.setDynamicNodeProperties(Collections.singletonMap(Symbol.valueOf("supported-dist-modes"),
-                                                                     UnsignedInteger.ZERO));
+            target.setDynamicNodeProperties(Map.of(Symbol.valueOf("supported-dist-modes"), UnsignedInteger.ZERO));
             final Interaction interaction = transport.newInteraction()
                                                         .negotiateOpen()
                                                         .begin().consumeResponse(Begin.class)
@@ -168,7 +165,7 @@ public class DecodeErrorTest extends BrokerAdminUsingTestBase
             encodedString.flip();
             payloads.add(encodedString);
 
-            final Map<Symbol, Object> annotationMap = Collections.singletonMap(Symbol.valueOf("foo"), "bar");
+            final Map<Symbol, Object> annotationMap = Map.of(Symbol.valueOf("foo"), "bar");
             final DeliveryAnnotations annotations = new DeliveryAnnotations(annotationMap);
             final DeliveryAnnotationsSection deliveryAnnotationsSection = annotations.createEncodingRetainingSection();
             try
