@@ -38,16 +38,14 @@ import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
 import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.List;
+import java.util.Set;
 import java.util.TreeSet;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.stream.Collectors;
 import java.util.stream.LongStream;
 import java.util.stream.Stream;
 
-import com.google.common.collect.Sets;
-
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Disabled;
 import org.junit.jupiter.api.Test;
@@ -1051,9 +1049,9 @@ public class TransferTest extends BrokerAdminUsingTestBase
                        .transferPayloadData(contents[2])
                        .transfer();
 
-            TreeSet<UnsignedInteger> expectedDeliveryIds = Sets.newTreeSet(Arrays.asList(UnsignedInteger.ZERO,
-                                                                                         UnsignedInteger.ONE,
-                                                                                         UnsignedInteger.valueOf(2)));
+            TreeSet<UnsignedInteger> expectedDeliveryIds = new TreeSet<>(Set.of(UnsignedInteger.ZERO,
+                    UnsignedInteger.ONE,
+                    UnsignedInteger.valueOf(2)));
             assertDeliveries(interaction, expectedDeliveryIds);
 
             // verify that no unexpected performative is received by closing
@@ -1099,10 +1097,10 @@ public class TransferTest extends BrokerAdminUsingTestBase
 
             interaction.txnSendDischarge(false);
 
-            assertDeliveries(interaction, Sets.newTreeSet(Arrays.asList(UnsignedInteger.ONE,
-                                                                        UnsignedInteger.valueOf(2),
-                                                                        UnsignedInteger.valueOf(3),
-                                                                        UnsignedInteger.valueOf(4))));
+            assertDeliveries(interaction, new TreeSet<>(Set.of(UnsignedInteger.ONE,
+                    UnsignedInteger.valueOf(2),
+                    UnsignedInteger.valueOf(3),
+                    UnsignedInteger.valueOf(4))));
         }
         assertTestQueueMessages(contents);
     }
