@@ -31,9 +31,9 @@ import static org.hamcrest.Matchers.is;
 import static org.hamcrest.Matchers.lessThan;
 import static org.hamcrest.Matchers.lessThanOrEqualTo;
 import static org.hamcrest.Matchers.notNullValue;
-import static org.junit.Assume.assumeThat;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.protocol.v1_0.type.UnsignedInteger;
 import org.apache.qpid.server.protocol.v1_0.type.UnsignedShort;
@@ -139,7 +139,7 @@ public class OpenTest extends BrokerAdminUsingTestBase
             final int timeout = peerIdleTimeOut == null || peerIdleTimeOut.intValue() == 0
                     ? idleTimeOut
                     : peerIdleTimeOut.intValue();
-            assumeThat(timeout, lessThan(30000));
+            assumeTrue(lessThan(30000).matches(timeout));
             Thread.sleep(timeout);
             interaction.consumeResponse(EmptyResponse.class);
         }
