@@ -21,9 +21,8 @@
 
 package org.apache.qpid.tests.http.v6_1;
 
-import static javax.servlet.http.HttpServletResponse.SC_CREATED;
-import static javax.servlet.http.HttpServletResponse.SC_NOT_FOUND;
-import static javax.servlet.http.HttpServletResponse.SC_OK;
+import static jakarta.servlet.http.HttpServletResponse.SC_CREATED;
+import static jakarta.servlet.http.HttpServletResponse.SC_OK;
 import static org.hamcrest.CoreMatchers.nullValue;
 import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.instanceOf;
@@ -31,13 +30,12 @@ import static org.hamcrest.Matchers.is;
 import static org.hamcrest.Matchers.notNullValue;
 import static org.hamcrest.MatcherAssert.assertThat;
 
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import org.apache.qpid.server.filter.AMQPFilterTypes;
 import org.apache.qpid.tests.http.HttpRequestConfig;
@@ -48,7 +46,7 @@ public class BindingTest extends HttpTestBase
 {
     private static final String QUEUE_NAME = "myqueue";
 
-    @Before
+    @BeforeEach
     public void setUp()
     {
         getBrokerAdmin().createQueue(QUEUE_NAME);
@@ -57,11 +55,10 @@ public class BindingTest extends HttpTestBase
     @Test
     public void bind() throws Exception
     {
-        Map<String, String> arguments = Collections.singletonMap(AMQPFilterTypes.JMS_SELECTOR.getValue(), "1<2");
+        Map<String, String> arguments = Map.of(AMQPFilterTypes.JMS_SELECTOR.getValue(), "1<2");
         getHelper().submitRequest("/api/v6.1/binding/amq.direct/myqueue/foo",
                                   "PUT",
-                                  Collections.singletonMap("arguments",
-                                                           arguments),
+                                  Map.of("arguments", arguments),
                                   SC_CREATED);
         List<Map<String, Object>> bindings = getHelper().getJsonAsList("queue/myqueue/getPublishingLinks");
         assertThat(bindings, is(notNullValue()));
@@ -85,7 +82,7 @@ public class BindingTest extends HttpTestBase
     @Test
     public void get() throws Exception
     {
-        Map<String, String> arguments = Collections.singletonMap(AMQPFilterTypes.JMS_SELECTOR.getValue(), "1<2");
+        Map<String, String> arguments = Map.of(AMQPFilterTypes.JMS_SELECTOR.getValue(), "1<2");
         Map<String, Object> bindOperationArguments = new HashMap<>();
         bindOperationArguments.put("destination", "myqueue");
         bindOperationArguments.put("bindingKey", "foo");
@@ -112,7 +109,7 @@ public class BindingTest extends HttpTestBase
     @Test
     public void delete() throws Exception
     {
-        Map<String, String> arguments = Collections.singletonMap(AMQPFilterTypes.JMS_SELECTOR.getValue(), "1<2");
+        Map<String, String> arguments = Map.of(AMQPFilterTypes.JMS_SELECTOR.getValue(), "1<2");
         Map<String, Object> bindOperationArguments = new HashMap<>();
         bindOperationArguments.put("destination", "myqueue");
         bindOperationArguments.put("bindingKey", "foo");
