@@ -32,10 +32,10 @@ import javax.jms.Connection;
 import javax.jms.Destination;
 import javax.jms.Session;
 
-import com.fasterxml.jackson.databind.ObjectMapper;
-
 import org.junit.jupiter.api.Test;
 
+import tools.jackson.databind.ObjectMapper;
+
 import org.apache.qpid.server.model.Binding;
 import org.apache.qpid.server.model.Protocol;
 import org.apache.qpid.systests.JmsTestBase;
