@@ -61,11 +61,12 @@ import javax.jms.JMSException;
 import javax.jms.Session;
 import javax.naming.NamingException;
 
-import com.fasterxml.jackson.core.JsonProcessingException;
-import com.fasterxml.jackson.databind.ObjectMapper;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import tools.jackson.core.JacksonException;
+import tools.jackson.databind.ObjectMapper;
+
 import org.apache.qpid.server.plugin.PluggableService;
 import org.apache.qpid.server.util.FileUtils;
 import org.apache.qpid.server.util.SystemUtils;
@@ -520,7 +521,7 @@ public class SpawnBrokerAdmin implements BrokerAdmin, Closeable
                     new ObjectMapper().writeValueAsString(Collections.singletonMap("virtualhostBlueprint",
                                                                                    blueprint));
         }
-        catch (JsonProcessingException e)
+        catch (JacksonException e)
         {
             throw new BrokerAdminException("Cannot create virtual host as context serialization failed", e);
         }
