@@ -32,7 +32,7 @@ public class BrokerAdminFactory
         BrokerAdmin brokerAdmin = adminFacades.get(type);
         if (brokerAdmin == null)
         {
-            throw new RuntimeException(String.format("Could not find BrokerAdmin implementation of type '%s'", type));
+            throw new BrokerAdminException(String.format("Could not find BrokerAdmin implementation of type '%s'", type));
         }
         return brokerAdmin;
     }
